searchData={"items":[{"type":"module","title":"Colorex","doc":"This module contains functions for creating and manipulating colors.","ref":"Colorex.html"},{"type":"module","title":"Color representations - Colorex","doc":"Colors are represented internally in any number of colorspaces: RGB, HSL, LAB, XYZ, or CMYK.\nThe `Colorex.Color` struct represents a general color with an opaque(type opaque) colorspace. It will also attempt to\npreserve whatever input format you used, but may standardize the format slightly.\n```\niex> \"#3355DD\" |> Colorex.parse!() |> to_string()\n\"#3355DD\"\niex> \"#3355DD43\" |> Colorex.parse!() |> to_string()\n\"#3355DD43\"\niex> \"rgba(51, 85, 221, 100%)\" |> Colorex.parse!() |> to_string()\n\"rgb(51 85 221)\"\niex> \"rgba(51, 85, 221, 0.67)\" |> Colorex.parse!() |> to_string()\n\"rgb(51 85 221 / 67%)\"\niex> \"hsl(228 71% 53% / 100%)\" |> Colorex.parse!() |> to_string()\n\"hsl(228 71% 53%)\"\niex> \"hsl(228 71% 53% / 67%)\" |> Colorex.parse!() |> to_string()\n\"hsl(228 71% 53% / 67%)\"\n```\nYou can access a specific colorspace by using the functions `rgb/1`, `hsl/1`, `lab/1`, `xyz/1`, `cmyk/1`, or `to_colorspace/2`\n\nIn general, most functions in this module will accept any of the following structs: `Colorex.Color`, `Colorex.RGB`, `Colorex.HSL`,`Colorex.LAB`, `Colorex.XYZ`, `Colorex.CMYK`\nHowever since the function may use a different colorspace to do its calculation, you may get back a different colorspace, except if you pass in a `Colorex.Color` struct, the return type will also be a `Colorex.Color` struct.\nYou can always explicitly cast the colorspace if you need a particular value, casting is a noop if the input is already in that colorspace.\n\n```\niex> hsl |> Colorex.update(:red, & &1 + 50) |> Colorex.hsl()\n```\n\nAll colorspaces contain an `alpha` channel for opacity.","ref":"Colorex.html#module-color-representations"},{"type":"module","title":"Parsing and printing - Colorex","doc":"Colorex can parse strings with any valid css color (hex, rgb, rgba, hsl, hsla and named colors).\n\nThe `Colorex.Color` struct implements the `Inspect` protocol as it's internals are private. The displayed value is code that will evaluate to current struct, and also shows a sample of the color(requires using a terminal with truecolor)\n\n```\niex> Colorex.parse!(\"#3355DD\")\nColorex.parse!(\"#3355DD\")\n```","ref":"Colorex.html#module-parsing-and-printing"},{"type":"function","title":"Colorex.average/1","doc":"Averages a list of colors together in the RGB colorspace.","ref":"Colorex.html#average/1"},{"type":"function","title":"Examples: - Colorex.average/1","doc":"```\n  iex> Colorex.average([Colorex.parse!(\"#3355FF\"), Colorex.parse!(\"#FF5533\")])\n  Colorex.parse!(\"#B855B8\")\n  ```","ref":"Colorex.html#average/1-examples"},{"type":"function","title":"Colorex.cmyk/1","doc":"Returns a `Colorex.CMYK` struct which represents a color in the CMYK colorspace","ref":"Colorex.html#cmyk/1"},{"type":"type","title":"Colorex.color/0","doc":"","ref":"Colorex.html#t:color/0"},{"type":"type","title":"Colorex.color_key/0","doc":"","ref":"Colorex.html#t:color_key/0"},{"type":"type","title":"Colorex.colorspace_color/0","doc":"","ref":"Colorex.html#t:colorspace_color/0"},{"type":"function","title":"Colorex.darken/2","doc":"Makes a color darker.\n\n  Takes a color and a number between 0 and 1, and returns a color with the lightness decreased by that amount.\n\n  The given amount is a percent of the distance to be closed between the current color and black, not a fixed amount to be added. The following shows a 30%(0.3) darkening.\n\n\n    black                color    white\n      |--------------------|-------|\n                    ^\n              color after darken(color, 0.3)\n\n    black       color             white\n      |----------|-----------------|\n             ^\n        color after darken(color, 0.3)\n\n    black color                     white\n      |---|-------------------------|\n        ^\n    color after darken(color, 0.3)\n\n  See also `lighten/2` for the opposite effect.\n\n  The function calls `update(color, :lightness, fun)`. If you want more control you can call that function directly.","ref":"Colorex.html#darken/2"},{"type":"function","title":"Colorex.darkmode/1","doc":"Adjusts a color to work better against a dark background.\n\n  Highly saturated colors tend to not look as good against a dark background.\n\n  This function will reduce the saturation of a color.\n\n  It will adjust relative to a color's saturation, so less saturated colors will be adjusted less than more saturated colors.","ref":"Colorex.html#darkmode/1"},{"type":"function","title":"Colorex.distance/3","doc":"Calculates the distance between two colors.\n\n  The default algorithm will convert to CIELAB colorspace and calculate the distance there.\n\n  This is generally accepted to be one of the most accurate ways to calculate color distance, as the LAB colorspace was designed to uniformally distribute human perception of color.\n\n  You can also pass in a `fast: true` option which will instead use a faster approximation in RGB space called \"redmean\". It'll typically return the same results as the LAB algorithm as long as the colors are similar.\n  i.e. which of 2 reds is closest to another red. But it tends to be less accurate the more different the colors are.\n\n  The fast distance algorithm is about 33x times faster than the LAB one(~6mil/s IPS vs ~180k/s on an M1 MBP)\n\n  The results for both algorithms by default are normalized to return a float between 0 and 1. 0 being identical colors, and 1.0 for the most different colors.\n\n  You can pass in the option `norm: false` if you want the raw results, but those numbers are pretty arbitrary as far as I know.","ref":"Colorex.html#distance/3"},{"type":"function","title":"Colorex.fast_distance/2","doc":"Caclulate distance using the fast algorithm.\n\n  This is an alias of `distance/3` with the options `[fast: true]`","ref":"Colorex.html#fast_distance/2"},{"type":"function","title":"Colorex.fast_similarity/2","doc":"Convenience function for `1 - fast_distance(color, color2)`","ref":"Colorex.html#fast_similarity/2"},{"type":"function","title":"Colorex.flatten_alpha/2","doc":"Flattens any alpha value to 1.0 against the passed in color or white.\n\n  Colors that contain an `alpha` value have some transparency to them, so their actual color would depend on what is behind them. This function converts a color with transparency, to a solid color based on the background color passed on, or the default of white\n\n  You can also set the background color in your config with `:colorex, :background_color`","ref":"Colorex.html#flatten_alpha/2"},{"type":"function","title":"Examples: - Colorex.flatten_alpha/2","doc":"```\n  iex> Colorex.flatten_alpha(Colorex.parse!(\"#3355FF7F\"), Colorex.parse!(\"#FF5533\"))\n  Colorex.parse!(\"#995599\")\n  iex> Colorex.flatten_alpha(Colorex.parse!(\"#3355FF7F\"), Colorex.parse!(\"#000000\"))\n  Colorex.parse!(\"#192A7F\")\n  iex> Colorex.flatten_alpha(Colorex.parse!(\"#3355FF7F\"))\n  Colorex.parse!(\"#99AAFF\")\n  iex> Application.put_env(:colorex, :background_color, \"#00FF00\")\n  iex> Colorex.flatten_alpha(Colorex.parse!(\"#3355FF7F\"))\n  Colorex.parse!(\"#19AA7F\")\n  ```","ref":"Colorex.html#flatten_alpha/2-examples"},{"type":"type","title":"Colorex.float_0_to_1/0","doc":"","ref":"Colorex.html#t:float_0_to_1/0"},{"type":"function","title":"Colorex.format/2","doc":"Update color format of a `Colorex.Color` struct\n\n  options: [:hex, :hex24, :hex32, :hsl, :hsla, :rgb, :rgba]\n\n  hsla is an alias of hsl, and rgba of rgb. Both will automatically include the alpha component, if neccessary.","ref":"Colorex.html#format/2"},{"type":"function","title":"Examples: - Colorex.format/2","doc":"```\n  iex> c = Colorex.parse!(\"#3355FF\")\n  iex> c = Colorex.format(c, :hsl)\n  Colorex.parse!(\"hsl(230 100% 60%)\")\n  iex> to_string(c)\n  \"hsl(230 100% 60%)\"\n  ```","ref":"Colorex.html#format/2-examples"},{"type":"function","title":"Colorex.get/2","doc":"Get any value from any colorspace\n\n  This function will fetch the requested key, automatically converting colorspace if neccessary.","ref":"Colorex.html#get/2"},{"type":"function","title":"Examples: - Colorex.get/2","doc":"```\n  iex> Colorex.parse!(\"#114466\") |> Colorex.rgb() |> Colorex.get(:saturation)\n  0.714285714285\n  ```","ref":"Colorex.html#get/2-examples"},{"type":"function","title":"Colorex.grayscale/1","doc":"Converts a color to grayscale.","ref":"Colorex.html#grayscale/1"},{"type":"function","title":"Colorex.grayscale?/2","doc":"Returns true if a color is grayscale\n\n  If a color has equal Red, Green, and Blue values this will return true, else false.\n\n  Because we may perceive colors that aren't exactly grayscale as grayscale, an optional second argument takes a threshold.\n\n  This is a number 0 to 255 that determines how much absolute difference between R, G, B should be considered grayscale.\n\n  Default threshold is 0, so R, G, and B must be exactly equal. A threshold of 3 would consider R:120, G:117, B:123 to be grayscale, because they're all within 3 points of the average.","ref":"Colorex.html#grayscale?/2"},{"type":"function","title":"Colorex.hsl/1","doc":"Returns a `Colorex.HSL` struct which represents a color in the HSL colorspace","ref":"Colorex.html#hsl/1"},{"type":"type","title":"Colorex.integer_0_to_255/0","doc":"","ref":"Colorex.html#t:integer_0_to_255/0"},{"type":"function","title":"Colorex.lab/1","doc":"Returns a `Colorex.LAB` struct which represents a color in the LAB colorspace","ref":"Colorex.html#lab/1"},{"type":"function","title":"Colorex.lighten/2","doc":"Makes a color lighter.\n\n  Takes a color and a number between 0 and 1, and returns a color with the lightness increased by that amount.\n\n  The given amount is a percent of the distance to be closed between the current color and white, not a fixed amount to be added. The following shows a 30%(0.3) lightening\n\n\n    black   color                 white\n      |-------|--------------------|\n                    ^\n          color after lighten(color, 0.3)\n\n    black             color       white\n      |-----------------|----------|\n                           ^\n                  color after lighten(color, 0.3)\n\n    black                   color  white\n      |------------------------|---|\n                                ^\n                        color after lighten(color, 0.3)\n\n  See also `darken/2` for the opposite effect.\n\n  The function calls `update(color, :lightness, fun)`. If you want more control you can call that function directly.","ref":"Colorex.html#lighten/2"},{"type":"function","title":"Colorex.mix/3","doc":"Mixes two colors together.\n\n  Specifically, takes the average of each of the RGB components, optionally weighted by the given percentage.\n  The opacity of the colors is also considered when weighting the components.\n\n  The weight specifies the amount of the first color that should be included in the returned color. The default, 0.5,\n  means that half the first color and half the second color should be used. 25% means that a quarter of the first\n  color and three quarters of the second color should be used.","ref":"Colorex.html#mix/3"},{"type":"function","title":"Examples: - Colorex.mix/3","doc":"iex> mix(parse!(\"#00f\"), parse!(\"#f00\"))\n      \"#800080\"\n      iex> mix(parse!(\"#00f\"), parse!(\"#f00\"), 0.25)\n      \"#BF0040\"\n      iex> mix(rgb(255, 0, 0, 0.5), parse!(\"#00f\"))\n      \"rgba(64, 0, 191, 0.75)\"","ref":"Colorex.html#mix/3-examples"},{"type":"function","title":"Colorex.most_similar/3","doc":"Returns the color in `colors` that is most similar to `color`\n\n  Options:\n\n  `fast`: Whether to use the faster or more accurate algorithm to compute similarity. Since the faster algorithms weakness is in more different colors, it should be fine for calculating most similar. Default `true`","ref":"Colorex.html#most_similar/3"},{"type":"function","title":"Colorex.parse/1","doc":"Parses a string into a Colorex struct\n\n  Returns `{:ok, color}` on successful parse, or `{:error, reason}` otherwise","ref":"Colorex.html#parse/1"},{"type":"function","title":"Colorex.parse!/1","doc":"Parses a string into a Colorex struct\n\n  Similar to `parse/1` but throws on invalid input.","ref":"Colorex.html#parse!/1"},{"type":"function","title":"Colorex.put/3","doc":"Set any value in any colorspace\n\n  Allows you to set the value of the given key. Colorspace will be automatically converted if needed","ref":"Colorex.html#put/3"},{"type":"function","title":"Examples: - Colorex.put/3","doc":"```\n  iex> Colorex.parse!(\"#3355DD\") |> Colorex.hsl() |> Colorex.put(:red, 55) |> Colorex.put(:saturation, 0.75)\n  %Colorex.HSL{\n    hue: 229.1566265060241,\n    saturation: 0.75,\n    lightness: 0.5411764705882354,\n    alpha: 1.0\n  }\n  ```\n\n  If you want to set a value based on the current value, see `update/3`","ref":"Colorex.html#put/3-examples"},{"type":"function","title":"Colorex.rgb/1","doc":"Returns a `Colorex.RGB` struct which represents a color in the RGB colorspace","ref":"Colorex.html#rgb/1"},{"type":"type","title":"Colorex.rgba_tuple/0","doc":"","ref":"Colorex.html#t:rgba_tuple/0"},{"type":"function","title":"Colorex.rgba_tuple/1","doc":"Returns a 4-element tuple `{red, green, blue, alpha}`.\n\n  red, green, and blue will be integers from 0 to 255 inclusive, alpha will be a float from 0.0 to 1.0 inclusive","ref":"Colorex.html#rgba_tuple/1"},{"type":"function","title":"Colorex.shade_number/1","doc":"Returns an integer 0-255 that represents how light/bright a color is.\n\n  Black returns 0. White returns 255.\n\n  This is different than just getting the HSL lightness value, as this will incorporate saturation too.\n\n  Here is an example of some colors where sorting by `shade_number/1` and `hsl/1` lightness give the most different results. Shade number is on the top. HSL lightness on the bottom. Both sorted darkest to lightest.","ref":"Colorex.html#shade_number/1"},{"type":"function","title":"Colorex.similarity/3","doc":"This is a convenience function for  1 - `distance/3`.\n\n  See that functions docs for a more in depth explanation\n\n  Results with a larger score from `distance/3` are more different, and results with a larger score from this function `similarity/3` are more similar.","ref":"Colorex.html#similarity/3"},{"type":"function","title":"Colorex.spectral_mix/3","doc":"Color mixing using Kubelka-Munk theory / pigment mixing.\n\n  This can often more closely resemble real-world color mixing(e.g. paint mixing).\n\n  For example, in school you learn mixing blue and yellow gives you green. If you mix them in traditional RGB color mixing, you'll get gray, instead of green.\n\n  `mix/3` will mix `#0000FF` and `#FFFF00` as `#808080`\n\n  `spectral_mix/3` will mix `#0000FF` and `#FFFF00` as `#388F54`\n\n  This function uses the algorithm from the Spectral.js Github library rather than the more popular Mixbox library, as Mixbox is not FOSS and while its source code is open, it's licensing(CC BY-NC) is too restrictive for me to include it in this library.\n\n  In some quick tests I did, though they often both yield similar results, the Mixbox library does better overall, so if a `CC BY-NC` license works for your needs and you like this type of color mixing effect, you might want to checkout Mixbox(though no Elixir library is available to my knowledge).\n\n  [Spectral.js - Lic: MIT](https://github.com/rvanwijnen/spectral.js)\n\n  [Mixbox - Lic: CC BY-NC](https://github.com/scrtwpns/mixbox)\n\n  Here is a comparison of `mix/3`(on the left) and `spectral_mix/3`(on the right).","ref":"Colorex.html#spectral_mix/3"},{"type":"function","title":"Colorex.text_color/2","doc":"Attempts to find the best color to use for displaying text on top of the given color.\n\n  It will return a `Colorex.Color.t()` struct representing either black or white.\n\n  If you want a different value returned, for example `\"text-gray-100\"` and `\"text-gray-900\"`, you can pass them in as options `[black: \"text-gray-900\", white: \"text-gray-100\"]`","ref":"Colorex.html#text_color/2"},{"type":"function","title":"Example: - Colorex.text_color/2","doc":"```\n  iex> Colorex.text_color(Colorex.black())\n  Colorex.parse!(\"#FFFFFF\")\n  iex> Colorex.text_color(Colorex.white(), white: \"text-gray-100\", black: \"text-gray-900\")\n  \"text-gray-900\"\n  ```","ref":"Colorex.html#text_color/2-example"},{"type":"function","title":"Colorex.to_colorspace/2","doc":"Converts any color/colorspace to the colorspace of the given atom.\n\n  This function is basically the same as calling `rgb/1`, `hsl/1`, `xyz/1`, `lab/1`, or `cmyk/1` except you can convert by using an atom rather than calling the specific function.","ref":"Colorex.html#to_colorspace/2"},{"type":"function","title":"Colorex.trunc_alpha/1","doc":"Sets the alpha channel to 100% without accounting for background color","ref":"Colorex.html#trunc_alpha/1"},{"type":"function","title":"Examples: - Colorex.trunc_alpha/1","doc":"```\n  iex> Colorex.trunc_alpha(Colorex.parse!(\"#3355FF7F\"))\n  Colorex.parse!(\"#3355FF\")\n  ```\n\n  If you want the color to be resolved taking into account a background color, use `flatten_alpha/1`/`flatten_alpha/2`","ref":"Colorex.html#trunc_alpha/1-examples"},{"type":"function","title":"Colorex.update/3","doc":"Update any attribute in any colorspace","ref":"Colorex.html#update/3"},{"type":"function","title":"Examples: - Colorex.update/3","doc":"```\n  iex> Colorex.parse!(\"#3355DD\") |> Colorex.update(:lightness, & &1 * 1.3) |> Colorex.update(:blue, & &1 - 40) |> Colorex.update(:hue, & &1 + 15) |> Colorex.update(:saturation, & &1 * 1.1)\n  Colorex.parse!(\"#7579C5\")\n  ```\n\n  There's also a 2-arity version which will receive `{min, max}` as the second argument.\n\n  So the following would bring the current color halfway between it's current red value, and the max red value.\n\n  ```\n  iex> Colorex.parse!(\"#3355DD\") |> Colorex.update(:red, fn val, {_, max} -> val + ((max - val) / 2) end)\n  ```\n\n  All values, except `hue` are clamped to their `{min, max}`.\n\n  ```\n  iex> Colorex.update(rgb_color, :red, fn _ -> 500 end) |> Map.get(:red)\n  255\n  iex> Colorex.update(hsl_color, :hue, fn _ -> 500 end) |> Map.get(:hue)\n  140 # Hue is a 0-360 degree measurement, so 500 - 360 == 140\n  ```","ref":"Colorex.html#update/3-examples"},{"type":"function","title":"Colorex.xyz/1","doc":"Returns a `Colorex.XYZ` struct which represents a color in the XYZ colorspace","ref":"Colorex.html#xyz/1"},{"type":"module","title":"Colorex.ANSI","doc":"Module for generating ANSI escape sequences, similar to `IO.ANSI`.\n\nGenerate ANSI escape sequences that display truecolor/24-bit color, or with truecolor mode off, it will find the closest 8-bit colors to match.","ref":"Colorex.ANSI.html"},{"type":"function","title":"Colorex.ANSI.ansi/2","doc":"Returns an ANSI escape sequence setting the foreground color.\n\n  See `IO.ANSI` for more information","ref":"Colorex.ANSI.html#ansi/2"},{"type":"function","title":"Options: - Colorex.ANSI.ansi/2","doc":"`truecolor` - whether to use the full 24-bit color spectrum, or just the standard 256 terminal colors. If you pass `truecolor: false` with a color that is not part of the 256 colors, the closest matching color will be chosen. Default: `true`\n\n  `fast` - uses the faster color comparison algorithm if true, or the more accurate one if false. See `distance/3` for more info. Default: `true`\n\n  ```\n  iex> IO.puts(Colorex.ansi(Colorex.parse!(\"#1188FF\")) <> \"Blue text\" <> IO.ANSI.reset())\n  ```","ref":"Colorex.ANSI.html#ansi/2-options"},{"type":"function","title":"Colorex.ANSI.ansi_background/2","doc":"Returns an ANSI escape sequence setting the background color.\n\n  See `IO.ANSI` for more information\n\n  Options:\n\n  `truecolor` - whether to use the full 24-bit color spectrum, or just the standard 256 terminal colors. If you pass `truecolor: false` with a color that is not part of the 256 colors, the closest matching color will be chosen. Default: `true`\n\n  `fast` - uses the faster color comparison algorithm if true, or the more accurate one if false. See `distance/3` for more info. Default: `true`\n\n  ```\n  iex> IO.puts(Colorex.ansi_background(Colorex.parse!(\"#1188FF\")) <> \"Blue background\" <> IO.ANSI.reset())\n  ```","ref":"Colorex.ANSI.html#ansi_background/2"},{"type":"type","title":"Colorex.ANSI.color/0","doc":"","ref":"Colorex.ANSI.html#t:color/0"},{"type":"type","title":"Colorex.ANSI.color_key/0","doc":"","ref":"Colorex.ANSI.html#t:color_key/0"},{"type":"type","title":"Colorex.ANSI.colorspace_color/0","doc":"","ref":"Colorex.ANSI.html#t:colorspace_color/0"},{"type":"type","title":"Colorex.ANSI.float_0_to_1/0","doc":"","ref":"Colorex.ANSI.html#t:float_0_to_1/0"},{"type":"type","title":"Colorex.ANSI.integer_0_to_255/0","doc":"","ref":"Colorex.ANSI.html#t:integer_0_to_255/0"},{"type":"type","title":"Colorex.ANSI.rgba_tuple/0","doc":"","ref":"Colorex.ANSI.html#t:rgba_tuple/0"},{"type":"module","title":"Colorex.CMYK","doc":"Struct that represents a color in the CMYK colorspace.","ref":"Colorex.CMYK.html"},{"type":"type","title":"Colorex.CMYK.t/0","doc":"","ref":"Colorex.CMYK.html#t:t/0"},{"type":"module","title":"Colorex.Color","doc":"Struct that represents a type opaque color. Automatically handles colorspace conversions and will keep the same color format as you used to create it.","ref":"Colorex.Color.html"},{"type":"type","title":"Colorex.Color.color/0","doc":"","ref":"Colorex.Color.html#t:color/0"},{"type":"type","title":"Colorex.Color.color_key/0","doc":"","ref":"Colorex.Color.html#t:color_key/0"},{"type":"type","title":"Colorex.Color.colorspace_color/0","doc":"","ref":"Colorex.Color.html#t:colorspace_color/0"},{"type":"type","title":"Colorex.Color.float_0_to_1/0","doc":"","ref":"Colorex.Color.html#t:float_0_to_1/0"},{"type":"type","title":"Colorex.Color.integer_0_to_255/0","doc":"","ref":"Colorex.Color.html#t:integer_0_to_255/0"},{"type":"type","title":"Colorex.Color.rgba_tuple/0","doc":"","ref":"Colorex.Color.html#t:rgba_tuple/0"},{"type":"opaque","title":"Colorex.Color.t/0","doc":"This struct encapsulates a color and handles it's internal colorspace representation/conversions.","ref":"Colorex.Color.html#t:t/0"},{"type":"module","title":"Colorex.HSL","doc":"Struct that represents a color in the HSL colorspace","ref":"Colorex.HSL.html"},{"type":"type","title":"Colorex.HSL.t/0","doc":"A representation of a color in hue, saturation, lightness and alpha.","ref":"Colorex.HSL.html#t:t/0"},{"type":"module","title":"Colorex.LAB","doc":"Struct that represents a color in the LAB/CIELAB colorspace","ref":"Colorex.LAB.html"},{"type":"type","title":"Colorex.LAB.t/0","doc":"","ref":"Colorex.LAB.html#t:t/0"},{"type":"module","title":"Colorex.Palette","doc":"Functions for working with or generating palettes of colors.","ref":"Colorex.Palette.html"},{"type":"function","title":"Colorex.Palette.analogous/2","doc":"Returns analogous colors for the input color\n\n  returns a tuple of two colors that are N degrees(default 30°) away","ref":"Colorex.Palette.html#analogous/2"},{"type":"function","title":"Example: - Colorex.Palette.analogous/2","doc":"```\n  iex> Colorex.analogous(Colorex.parse!(\"#3355FF\"))\n  {Colorex.parse!(\"#33BBFF\"), Colorex.parse!(\"#7733FF\")}\n  ```","ref":"Colorex.Palette.html#analogous/2-example"},{"type":"function","title":"Colorex.Palette.between/3","doc":"Returns n color(s) between the input colors\n\n  Returns a list of colors that bridge the gap between the two input colors.\n\n  N does not include the input colors, so if you want a total of 10 colors, you would call this function with n equal to 8.","ref":"Colorex.Palette.html#between/3"},{"type":"function","title":"Examples: - Colorex.Palette.between/3","doc":"```\n  iex> Colorex.between(Colorex.parse!(\"#3355FF\"), Colorex.parse!(\"#C27E70\"), 4)\n  [Colorex.parse!(\"#3FE1F3\"),\n   Colorex.parse!(\"#4BE785\"),\n   Colorex.parse!(\"#87DA58\"),\n   Colorex.parse!(\"#CEC464\")]\n  ```","ref":"Colorex.Palette.html#between/3-examples"},{"type":"function","title":"Colorex.Palette.complement/1","doc":"Returns the complement of a color in HSL colorspace.","ref":"Colorex.Palette.html#complement/1"},{"type":"function","title":"Examples: - Colorex.Palette.complement/1","doc":"```\n  iex> Colorex.complement(Colorex.parse!(\"#3355FF\"))\n  Colorex.parse!(\"#FFDD33\")\n  ```","ref":"Colorex.Palette.html#complement/1-examples"},{"type":"function","title":"Colorex.Palette.display_palettes/2","doc":"Displays a list of color palettes\n\n  The default inspecting of the color palettes from `get_palettes/2` isn't the easiest to see the colors.\n\n  Pass in the results from `get_palettes/2` and see each color palette printing in a row.\n\n  The optional second argument is the size of each color square.\n\n  Requires a terminal that supports truecolor/24-bit color.","ref":"Colorex.Palette.html#display_palettes/2"},{"type":"function","title":"Colorex.Palette.get_palettes/2","doc":"Generates N color palettes.\n\n  Pass in how many color palettes you want to see.\n\n  The optional second argument(pass in any string) is used to generate an offset so you can get some new color palettes.\n\n  Pass the result into `display_palettes/2` for a better viewing of the color palettes","ref":"Colorex.Palette.html#get_palettes/2"},{"type":"function","title":"Examples: - Colorex.Palette.get_palettes/2","doc":"```\niex> Colorex.Palette.get_palettes(2, \"random string\")\n[\n  [Colorex.parse!(\"#CADDEC\"), Colorex.parse!(\"#5F8CC0\"), Colorex.parse!(\"#143D86\"), Colorex.parse!(\"#F2F2DF\")],\n  [Colorex.parse!(\"#8978AF\"), Colorex.parse!(\"#FCA0A2\"), Colorex.parse!(\"#FCC4C6\"), Colorex.parse!(\"#367E72\")]\n]\n```","ref":"Colorex.Palette.html#get_palettes/2-examples"},{"type":"function","title":"Colorex.Palette.tetradic/1","doc":"Returns tetradic colors for the input color\n\n  returns a tuple of three colors that are 90°, 180°, and 270° away from the input color.","ref":"Colorex.Palette.html#tetradic/1"},{"type":"function","title":"Examples: - Colorex.Palette.tetradic/1","doc":"```\n  iex> Colorex.tetradic(Colorex.parse!(\"#3355FF\"))\n  {Colorex.parse!(\"#FF33BB\"), Colorex.parse!(\"#FFDD33\"), Colorex.parse!(\"#33FF77\")}\n  ```","ref":"Colorex.Palette.html#tetradic/1-examples"},{"type":"function","title":"Colorex.Palette.triadic/2","doc":"Returns triadic colors for the input color\n\n  returns a tuple of two colors that are N degrees(default 120°) away","ref":"Colorex.Palette.html#triadic/2"},{"type":"function","title":"Examples: - Colorex.Palette.triadic/2","doc":"```\n  iex> Colorex.triadic(Colorex.parse!(\"#3355FF\"))\n  {Colorex.parse!(\"#55FF33\"), Colorex.parse!(\"#FF3355\")}\n  ```","ref":"Colorex.Palette.html#triadic/2-examples"},{"type":"module","title":"Colorex.RGB","doc":"Struct that represents a color in the RGB colorspace","ref":"Colorex.RGB.html"},{"type":"function","title":"Colorex.RGB.rgb_percents/1","doc":"Returns R, G, and B values as percents rather than 0-255\n\n  Example:\n\n    iex> Colorex.parse!({51, 102, 153}) |> Colorex.rgb() |> Colorex.RGB.rgb_percents()\n    {0.2, 0.4, 0.6}","ref":"Colorex.RGB.html#rgb_percents/1"},{"type":"type","title":"Colorex.RGB.t/0","doc":"A representation of a color in red, green, blue and alpha.","ref":"Colorex.RGB.html#t:t/0"},{"type":"module","title":"Colorex.Utils","doc":"Some handy functions for working with colors","ref":"Colorex.Utils.html"},{"type":"function","title":"Colorex.Utils.black/0","doc":"Convienience function to get the color black","ref":"Colorex.Utils.html#black/0"},{"type":"type","title":"Colorex.Utils.color/0","doc":"","ref":"Colorex.Utils.html#t:color/0"},{"type":"type","title":"Colorex.Utils.color_key/0","doc":"","ref":"Colorex.Utils.html#t:color_key/0"},{"type":"type","title":"Colorex.Utils.colorspace_color/0","doc":"","ref":"Colorex.Utils.html#t:colorspace_color/0"},{"type":"type","title":"Colorex.Utils.float_0_to_1/0","doc":"","ref":"Colorex.Utils.html#t:float_0_to_1/0"},{"type":"type","title":"Colorex.Utils.integer_0_to_255/0","doc":"","ref":"Colorex.Utils.html#t:integer_0_to_255/0"},{"type":"function","title":"Colorex.Utils.print_color_mix/4","doc":"Print a visual of two colors being mixed.\n\n  Prints two overlapping squares that look like colors being mixed.\n\n  Arg 1 is the top right square. Arg 2 is the bottom left square. Arg 3 is the middle overlapping square. Arg 4 is an optional size parameter.\n\n \n \n        ┌──────────┐\n        │   Arg 1  │\n    ┌───│──────┐   │\n    │   │ Arg3 │   │\n    │   └──────────┘\n    │  Arg 2   │\n    └──────────┘\n\n \n \n\n  Requires a terminal that supports truecolor.","ref":"Colorex.Utils.html#print_color_mix/4"},{"type":"function","title":"Colorex.Utils.print_swatches/2","doc":"Print a row of color swatches.\n\n  Will print a colored square for each color in the list, all in a row.\n\n  The `size` argument is the size of each square.\n\n  Useful for debugging or seeing colors in the terminal. Requires a terminal that supports truecolor.","ref":"Colorex.Utils.html#print_swatches/2"},{"type":"function","title":"Colorex.Utils.random/0","doc":"Generates a random color.","ref":"Colorex.Utils.html#random/0"},{"type":"type","title":"Colorex.Utils.rgba_tuple/0","doc":"","ref":"Colorex.Utils.html#t:rgba_tuple/0"},{"type":"function","title":"Colorex.Utils.white/0","doc":"Convienience function to get the color white","ref":"Colorex.Utils.html#white/0"},{"type":"module","title":"Colorex.XYZ","doc":"Struct that represents a color in the XYZ colorspace","ref":"Colorex.XYZ.html"},{"type":"type","title":"Colorex.XYZ.t/0","doc":"","ref":"Colorex.XYZ.html#t:t/0"},{"type":"extras","title":"Colorex","doc":"# Colorex\n\nAn Elixir library for working with colors. Mixing, adjusting, converting(RGB, HSL, XYZ, LAB, CMYK), distance, and more.","ref":"readme.html"},{"type":"extras","title":"Installation - Colorex","doc":"The package can be installed by adding `colorex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:colorex, \"~> 1.0.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/colorex](https://hexdocs.pm/colorex).","ref":"readme.html#installation"},{"type":"extras","title":"Why Colorex? - Colorex","doc":"","ref":"readme.html#why-colorex"},{"type":"extras","title":"Implements Inspect Protocol - Colorex","doc":"Colors are a visual thing. Stop copy/pasting hex codes between your terminal and another app just to see what the colors look like. If you have a terminal that supports truecolor/24-bit color, then Colorex will show you exactly what the color looks like, right in the terminal.","ref":"readme.html#implements-inspect-protocol"},{"type":"extras","title":"More Colorspaces - Colorex","doc":"If you want a lighter color, doing it in the HSL colorspace makes the most sense. If you want the distance between two colors, then using the LAB/CIELAB colorspace is the most accurate. Or if you don't really care about colorspaces and just want it to work, then Colorex can abstract all that stuff away.","ref":"readme.html#more-colorspaces"},{"type":"extras","title":"Spectral Color Mixing - Colorex","doc":"I remember the first time I mixed yellow and blue together on a computer. As I sat there staring at the result, I couldn't figure out what was more gross, the ugly gray color in front of me(rather than the expected green), or the fact that my elementary school teacher had lied to me. But the good news is, it turns out she only _half_ lied to me, because most of the time yellow and blue **do** make green, but on the computer they usually don't. But Colorex implements a spectral mixing function that will give color mixing more like real life paint/pigment color mixing.","ref":"readme.html#spectral-color-mixing"},{"type":"extras","title":"Color Palettes - Colorex","doc":"Colorex has thousands of color palettes you can choose from, or if you prefer to make your own, Colorex has the tools to help.","ref":"readme.html#color-palettes"},{"type":"extras","title":"Acknowledgements - Colorex","doc":"This was originally a fork of the elixir [css_colors](https://github.com/alvinlindstam/css_colors) library. Though it has diverged quite a bit, I thank them for laying out the foundations.","ref":"readme.html#acknowledgements"},{"type":"extras","title":"License - Colorex","doc":"MIT","ref":"readme.html#license"},{"type":"extras","title":"Named Colors","doc":"# Named Colors","ref":"namedcolors.html"},{"type":"extras","title":"Below is a list of all 1362 named colors. - Named Colors","doc":"When using named colors with `Colorex.parse/1` or `Colorex.parse!/1` the text from the `Keyword` column is the value you want to use. It is always lowercase a-z letters.\n\n<!-- tabs-open -->","ref":"namedcolors.html#below-is-a-list-of-all-1362-named-colors"},{"type":"extras","title":"A-Z - Named Colors","doc":"Name \n         Keyword \n         RGB hex value \n         Source \n         Sample \n       \n     \n     \n        Absolute Zero   absolutezero    #0048BA   Wikipedia      Acid Green   acidgreen    #B0BF1A   Wikipedia      Aero   aero    #7CB9E8   Wikipedia      African Violet   africanviolet    #B284BE   Wikipedia      Agate Grey   agategrey    #B4B8B0   RAL      Air Superiority Blue   airsuperiorityblue    #72A0C1   Wikipedia      Alabaster   alabaster    #F2F0E6   Wikipedia      Alice Blue   aliceblue    #F0F8FF   CSS      Alizarin   alizarin    #DB2D43   Wikipedia      Alloy Orange   alloyorange    #C46210   Wikipedia      Almond   almond    #EED9C4   Crayola      Amaranth   amaranth    #E52B50   Wikipedia      Amaranth Deep Purple   amaranthdeeppurple    #9F2B68   Wikipedia      Amaranth Pink   amaranthpink    #F19CBB   Wikipedia      Amaranth Purple   amaranthpurple    #AB274F   Wikipedia      Amazon   amazon    #3B7A57   Wikipedia      Amber   amber    #FFBF00   Wikipedia      Amethyst   amethyst    #9966CC   Wikipedia      Android Green   androidgreen    #3DDC84   Wikipedia      Anthracite Grey   anthracitegrey    #373F43   RAL      Antique Brass   antiquebrass    #C88A65   Crayola      Antique Bronze   antiquebronze    #665D1E   Wikipedia      Antique Fuchsia   antiquefuchsia    #915C83   Wikipedia      Antique Pink   antiquepink    #D47479   RAL      Antique Ruby   antiqueruby    #841B2D   Wikipedia      Antique White   antiquewhite    #FAEBD7   CSS      Apricot   apricot    #FBCEB1   Crayola      Aqua   aqua    #00FFFF   CSS      Aquamarine   aquamarine    #7FFFD4   CSS      Arctic Lime   arcticlime    #D0FF14   Wikipedia      Artichoke Green   artichokegreen    #4B6F44   Wikipedia      Arylide Yellow   arylideyellow    #E9D66B   Wikipedia      Ash Gray   ashgray    #B2BEB5   Wikipedia      Asparagus   asparagus    #7BA05B   Crayola      Atomic Tangerine   atomictangerine    #FF9966   Wikipedia      Aureolin   aureolin    #FDEE00   Wikipedia      Aztec Gold   aztecgold    #C39953   Wikipedia      Azure   azure    #F0FFFF   CSS      Azure Blue   azureblue    #2E5978   RAL      B'dazzled Blue   bdazzledblue    #2E5894   Wikipedia      Baby Blue   babyblue    #89CFF0   Wikipedia      Baby Blue Eyes   babyblueeyes    #A1CAF1   Wikipedia      Baby Pink   babypink    #F4C2C2   Wikipedia      Baby Powder   babypowder    #FEFEFA   Wikipedia      Baker-Miller Pink   bakermillerpink    #FF91AF   Wikipedia      Banana Mania   bananamania    #FAE7B5   Crayola      Barbie Pink   barbiepink    #DA1884   Wikipedia      Barn Red   barnred    #7C0A02   Wikipedia      Basalt Grey   basaltgrey    #596163   RAL      Battleship Grey   battleshipgrey    #848482   Wikipedia      Beau Blue   beaublue    #BCD4E6   Wikipedia      Beaver   beaver    #9F8170   Crayola      Beige   beige    #F5F5DC   CSS      Beige Brown   beigebrown    #79553C   RAL      Beige Grey   beigegrey    #756F61   RAL      Beige Red   beigered    #CB8D73   RAL      Berry Parfait   berryparfait    #A43482   Wikipedia      Big Dip O'ruby   bigdiporuby    #9C2542   Wikipedia      Big Foot Feet   bigfootfeet    #E88E5A   Wikipedia      Bisque   bisque    #FFE4C4   CSS      Bistre   bistre    #3D2B1F   Wikipedia      Bistre Brown   bistrebrown    #967117   Wikipedia      Bitter Lemon   bitterlemon    #CAE00D   Wikipedia      Bittersweet   bittersweet    #FE6F5E   Crayola      Bittersweet Shimmer   bittersweetshimmer    #BF4F51   Wikipedia      Black   black    #000000   CSS      Black Bean   blackbean    #3D0C02   Wikipedia      Black Blue   blackblue    #1D1F2A   RAL      Black Brown   blackbrown    #211F20   RAL      Black Coral   blackcoral    #54626F   Wikipedia      Black Green   blackgreen    #31403D   RAL      Black Grey   blackgrey    #2E3234   RAL      Black Olive   blackolive    #3B3C36   RAL      Black Red   blackred    #402225   RAL      Black Shadows   blackshadows    #BFAFB2   Wikipedia      Blanched Almond   blanchedalmond    #FFEBCD   CSS      Blast-off Bronze   blastoffbronze    #A57164   Wikipedia      Bleu De France   bleudefrance    #318CE7   Wikipedia      Blizzard Blue   blizzardblue    #ACE5EE   Wikipedia      Blood Red   bloodred    #660000   Wikipedia      Blue   blue    #0000FF   CSS      Blue Bell   bluebell    #A2A2D0   Crayola      Blue Green   bluegreen    #0E4243   RAL      Blue Grey   bluegrey    #5D6970   RAL      Blue Jeans   bluejeans    #5DADEC   Wikipedia      Blue Lilac   bluelilac    #83639D   RAL      Blue Ribbon   blueribbon    #0B10A2   Wikipedia      Blue Sapphire   bluesapphire    #126180   Wikipedia      Blue Violet   blueviolet    #8A2BE2   CSS      Blue Yonder   blueyonder    #5072A7   Wikipedia      Blue-gray   bluegray    #6699CC   Crayola      Blue-violet   blueviolet    #8A2BE2   CSS      Blueberry   blueberry    #4F86F7   Wikipedia      Bluetiful   bluetiful    #3C69E7   Crayola      Blush   blush    #DE5D83   Crayola      Bole   bole    #79443B   Wikipedia      Bone   bone    #E3DAC9   Wikipedia      Booger Buster   boogerbuster    #DDE26A   Wikipedia      Bottle Green   bottlegreen    #283424   RAL      Brick Red   brickred    #CB4154   Crayola      Bright Green   brightgreen    #66FF00   Wikipedia      Bright Lilac   brightlilac    #D891EF   Wikipedia      Bright Maroon   brightmaroon    #C32148   Wikipedia      Bright Navy Blue   brightnavyblue    #1974D2   Wikipedia      Bright Pink   brightpink    #FF007F   Wikipedia      Bright Red Orange   brightredorange    #F3752C   RAL      Bright Turquoise   brightturquoise    #08E8DE   Wikipedia      Bright Yellow   brightyellow    #FFAA1D   Wikipedia      Brilliant Blue   brilliantblue    #41678D   RAL      Brilliant Rose   brilliantrose    #E667CE   Crayola      Brink Pink   brinkpink    #FB607F   Wikipedia      British Racing Green   britishracinggreen    #004225   Wikipedia      Bronze   bronze    #CD7F32   Wikipedia      Broom Yellow   broomyellow    #E2A300   RAL      Brown   brown    #A52A2A   CSS      Brown Beige   brownbeige    #AF804F   RAL      Brown Green   browngreen    #35382E   RAL      Brown Grey   browngrey    #555548   RAL      Brown Red   brownred    #7E292C   RAL      Brown Sugar   brownsugar    #AF6E4D   Wikipedia      Bud Green   budgreen    #7BB661   Wikipedia      Buff   buff    #FFC680   Wikipedia      Burgundy   burgundy    #800020   Wikipedia      Burlywood   burlywood    #DEB887   CSS      Burnished Brown   burnishedbrown    #A17A74   Wikipedia      Burnt Orange   burntorange    #CC5500   Crayola      Burnt Sienna   burntsienna    #E97451   Crayola      Burnt Umber   burntumber    #8A3324   Crayola      Byzantine   byzantine    #BD33A4   Wikipedia      Byzantium   byzantium    #702963   Wikipedia      Cadet   cadet    #536872   Wikipedia      Cadet Blue   cadetblue    #5F9EA0   CSS      Cadet Grey   cadetgrey    #91A3B0   Wikipedia      Cadmium Green   cadmiumgreen    #006B3C   Wikipedia      Cadmium Orange   cadmiumorange    #ED872D   Wikipedia      Cadmium Red   cadmiumred    #E30022   Wikipedia      Cadmium Yellow   cadmiumyellow    #FFF600   Wikipedia      Café Au Lait   cafeaulait    #A67B5B   Wikipedia      Café Noir   cafenoir    #4B3621   Wikipedia      Cambridge Blue   cambridgeblue    #A3C1AD   Wikipedia      Camel   camel    #C19A6B   Wikipedia      Cameo Pink   cameopink    #EFBBCC   Wikipedia      Canary   canary    #FFFF99   Crayola      Canary Yellow   canaryyellow    #FFEF00   Wikipedia      Candy Apple Red   candyapplered    #FF0800   Wikipedia      Candy Pink   candypink    #E4717A   Wikipedia      Capri Blue   capriblue    #1A5784   RAL      Cardinal   cardinal    #C41E3A   Wikipedia      Caribbean Green   caribbeangreen    #00CC99   Crayola      Carmine   carmine    #960018   Crayola      Carmine Red   carminered    #A1232B   RAL      Carnation Pink   carnationpink    #FFA6C9   Crayola      Carnelian   carnelian    #B31B1B   Wikipedia      Carolina Blue   carolinablue    #56A0D3   Wikipedia      Carrot Orange   carrotorange    #ED9121   Wikipedia      Catawba   catawba    #703642   Wikipedia      Cedar Chest   cedarchest    #C95A49   Wikipedia      Celadon   celadon    #ACE1AF   Wikipedia      Celeste   celeste    #B2FFFF   Wikipedia      Celestial Blue   celestialblue    #7070CC   Crayola      Cement Grey   cementgrey    #818979   RAL      Cerise   cerise    #DE3163   Crayola      Cerulean   cerulean    #007BA7   Crayola      Cerulean Blue   ceruleanblue    #2A52BE   Crayola      Cerulean Frost   ceruleanfrost    #6D9BC3   Wikipedia      Champagne   champagne    #F7E7CE   Wikipedia      Champagne Pink   champagnepink    #F1DDCF   Wikipedia      Charcoal   charcoal    #36454F   Wikipedia      Charcoal Gray   charcoalgray    #736A62   Crayola      Charleston Green   charlestongreen    #232B2B   Wikipedia      Charm Pink   charmpink    #E68FAC   Wikipedia      Chartreuse   chartreuse    #7FFF00   CSS      Cherry Blossom Pink   cherryblossompink    #FFB7C5   Wikipedia      Chestnut   chestnut    #954535   Crayola      Chestnut Brown   chestnutbrown    #633A34   RAL      Chili Red   chilired    #E23D28   Wikipedia      China Pink   chinapink    #DE6FA1   Wikipedia      Chinese Red   chinesered    #AA381E   Wikipedia      Chinese Violet   chineseviolet    #856088   Wikipedia      Chinese Yellow   chineseyellow    #FFB200   Wikipedia      Chocolate   chocolate    #D2691E   CSS      Chocolate Brown   chocolatebrown    #44322D   RAL      Chrome Green   chromegreen    #354733   RAL      Cinereous   cinereous    #98817B   Wikipedia      Cinnabar   cinnabar    #E34234   Wikipedia      Cinnamon Satin   cinnamonsatin    #CD607E   Wikipedia      Citrine   citrine    #E4D00A   Wikipedia      Citron   citron    #9FA91F   Wikipedia      Claret   claret    #7F1734   Wikipedia      Claret Violet   claretviolet    #691639   RAL      Clay Brown   claybrown    #80542F   RAL      Clean Room White   cleanroomwhite    #FFFDE6   RAL      Cobalt Blue   cobaltblue    #232D53   RAL      Cocoa Brown   cocoabrown    #D2691E   Wikipedia      Coconut   coconut    #965A3E   Wikipedia      Coffee   coffee    #6F4E37   Wikipedia      Columbia Blue   columbiablue    #B9D9EB   Wikipedia      Colza Yellow   colzayellow    #F6B600   RAL      Concrete Grey   concretegrey    #818479   RAL      Congo Pink   congopink    #F88379   Wikipedia      Cool Grey   coolgrey    #8C92AC   Wikipedia      Cool Mint   coolmint    #DDEBEC   Crayola      Copper   copper    #B87333   Crayola      Copper Brown   copperbrown    #8F4E35   RAL      Copper Penny   copperpenny    #AD6F69   Wikipedia      Copper Red   copperred    #CB6D51   Wikipedia      Copper Rose   copperrose    #996666   Wikipedia      Coquelicot   coquelicot    #FF3800   Wikipedia      Coral   coral    #FF7F50   CSS      Coral Pink   coralpink    #F88379   Wikipedia      Coral Red   coralred    #AC4034   RAL      Cordovan   cordovan    #893F45   Wikipedia      Corn   corn    #FBEC5D   Wikipedia      Cornflower   cornflower    #93CCEA   Crayola      Cornflower Blue   cornflowerblue    #6495ED   CSS      Cornsilk   cornsilk    #FFF8DC   CSS      Cosmic Cobalt   cosmiccobalt    #2E2D88   Wikipedia      Cosmic Latte   cosmiclatte    #FFF8E7   Wikipedia      Cotton Candy   cottoncandy    #FFBCD9   Crayola      Coyote Brown   coyotebrown    #81613C   Wikipedia      Crayellow   crayellow    #F1D651   Crayola      Cream   cream    #FFFDD0   RAL      Crimson   crimson    #DC143C   CSS      Cultured   cultured    #F5F5F5   Wikipedia      Cultured Pearl   culturedpearl    #F5F5F5   Wikipedia      Curry   curry    #A77F0E   RAL      Cyan   cyan    #00FFFF   CSS      Cyber Grape   cybergrape    #58427C   Wikipedia      Cyber Yellow   cyberyellow    #FFD300   Wikipedia      Cyclamen   cyclamen    #F56FA1   Wikipedia      Daffodil Yellow   daffodilyellow    #E88C00   RAL      Dahlia Yellow   dahliayellow    #F99A1C   RAL      Dandelion   dandelion    #FED85D   Crayola      Dark Blue   darkblue    #00008B   CSS      Dark Blue-gray   darkbluegray    #666699   Wikipedia      Dark Brown   darkbrown    #654321   Wikipedia      Dark Byzantium   darkbyzantium    #5D3954   Wikipedia      Dark Cyan   darkcyan    #008B8B   CSS      Dark Electric Blue   darkelectricblue    #536878   Wikipedia      Dark Fuchsia   darkfuchsia    #A00955   Wikipedia      Dark Goldenrod   darkgoldenrod    #B8860B   CSS      Dark Gray   darkgray    #A9A9A9   CSS      Dark Green   darkgreen    #006400   CSS      Dark Grey   darkgrey    #A9A9A9   CSS      Dark Jungle Green   darkjunglegreen    #1A2421   Wikipedia      Dark Khaki   darkkhaki    #BDB76B   CSS      Dark Lava   darklava    #483C32   Wikipedia      Dark Liver   darkliver    #543D37   Wikipedia      Dark Magenta   darkmagenta    #8B008B   CSS      Dark Midnight Blue   darkmidnightblue    #003366   Wikipedia      Dark Moss Green   darkmossgreen    #4A5D23   Wikipedia      Dark Olive Green   darkolivegreen    #556B2F   CSS      Dark Orange   darkorange    #FF8C00   CSS      Dark Orchid   darkorchid    #9932CC   CSS      Dark Pastel Green   darkpastelgreen    #03C03C   Wikipedia      Dark Purple   darkpurple    #301934   Wikipedia      Dark Raspberry   darkraspberry    #872657   Wikipedia      Dark Red   darkred    #8B0000   CSS      Dark Salmon   darksalmon    #E9967A   CSS      Dark Sea Green   darkseagreen    #8FBC8F   CSS      Dark Sienna   darksienna    #3C1414   Wikipedia      Dark Sky Blue   darkskyblue    #8CBED6   Wikipedia      Dark Slate Blue   darkslateblue    #483D8B   CSS      Dark Slate Gray   darkslategray    #2F4F4F   CSS      Dark Slate Grey   darkslategrey    #2F4F4F   CSS      Dark Spring Green   darkspringgreen    #177245   Wikipedia      Dark Tan   darktan    #918151   Wikipedia      Dark Turquoise   darkturquoise    #00CED1   CSS      Dark Vanilla   darkvanilla    #D1BEA8   Wikipedia      Dark Venetian Red   darkvenetianred    #B33B24   Crayola      Dark Violet   darkviolet    #9400D3   CSS      Dartmouth Green   dartmouthgreen    #00703C   Wikipedia      Davy's Grey   davysgrey    #555555   Wikipedia      Deep Cerise   deepcerise    #DA3287   Wikipedia      Deep Champagne   deepchampagne    #FAD6A5   Wikipedia      Deep Chestnut   deepchestnut    #B94E48   Wikipedia      Deep Fuchsia   deepfuchsia    #C154C1   Wikipedia      Deep Jungle Green   deepjunglegreen    #004B49   Wikipedia      Deep Lemon   deeplemon    #F5C71A   Wikipedia      Deep Mauve   deepmauve    #D473D4   Wikipedia      Deep Orange   deeporange    #EC7C25   RAL      Deep Pink   deeppink    #FF1493   CSS      Deep Saffron   deepsaffron    #FF9933   Wikipedia      Deep Sky Blue   deepskyblue    #00BFFF   CSS      Deep Space Sparkle   deepspacesparkle    #4A646C   Wikipedia      Deep Taupe   deeptaupe    #7E5E60   Wikipedia      Denim   denim    #1560BD   Crayola      Denim Blue   denimblue    #2243B6   Wikipedia      Desert   desert    #C19A6B   Wikipedia      Desert Sand   desertsand    #EDC9AF   Crayola      Dim Gray   dimgray    #696969   CSS      Dim Grey   dimgrey    #696969   CSS      Dingy Dungeon   dingydungeon    #C53151   Wikipedia      Dirt   dirt    #9B7653   Wikipedia      Distant Blue   distantblue    #4D668E   RAL      Dodger Blue   dodgerblue    #1E90FF   CSS      Dogwood Rose   dogwoodrose    #D71868   Wikipedia      Drab Dark Brown   drabdarkbrown    #4A412A   Wikipedia      Duke Blue   dukeblue    #00009C   Wikipedia      Dusty Grey   dustygrey    #7C7F7E   RAL      Dutch White   dutchwhite    #EFDFBB   Wikipedia      Earth Yellow   earthyellow    #E1A95F   Wikipedia      Ebony   ebony    #555D50   Wikipedia      Ecru   ecru    #C2B280   Wikipedia      Eerie Black   eerieblack    #1B1B1B   Wikipedia      Eggplant   eggplant    #614051   Crayola      Eggshell   eggshell    #F0EAD6   Wikipedia      Egyptian Blue   egyptianblue    #1034A6   Wikipedia      Electric Blue   electricblue    #7DF9FF   Wikipedia      Electric Indigo   electricindigo    #6F00FF   Wikipedia      Electric Lime   electriclime    #CCFF00   Wikipedia      Electric Purple   electricpurple    #BF00FF   Wikipedia      Electric Violet   electricviolet    #8F00FF   Wikipedia      Emerald   emerald    #50C878   Wikipedia      Emerald Green   emeraldgreen    #28713E   RAL      Eminence   eminence    #6C3082   Wikipedia      English Lavender   englishlavender    #B48395   Wikipedia      English Red   englishred    #AB4B52   Wikipedia      English Vermilion   englishvermilion    #CC474B   Crayola      English Vermillion   englishvermillion    #CC474B   Wikipedia      English Violet   englishviolet    #563C5C   Wikipedia      Erin   erin    #00FF40   Wikipedia      Eton Blue   etonblue    #96C8A2   Wikipedia      Eucalyptus   eucalyptus    #44D7A8   Wikipedia      Fallow   fallow    #C19A6B   Wikipedia      Falu Red   falured    #801818   Wikipedia      Fandango   fandango    #B53389   Wikipedia      Fandango Pink   fandangopink    #DE5285   Wikipedia      Fashion Fuchsia   fashionfuchsia    #F400A1   Wikipedia      Fawn   fawn    #E5AA70   Wikipedia      Fawn Brown   fawnbrown    #6F4A2F   RAL      Feldgrau   feldgrau    #4D5D53   Wikipedia      Fern   fern    #63B76C   Crayola      Fern Green   ferngreen    #4F7942   RAL      Field Drab   fielddrab    #6C541E   Wikipedia      Fiery Rose   fieryrose    #FF5470   Wikipedia      Finn   finn    #683068   Wikipedia      Fir Green   firgreen    #26392F   RAL      Fire Engine Red   fireenginered    #CE2029   Wikipedia      Fire Opal   fireopal    #E95C4B   Wikipedia      Firebrick   firebrick    #B22222   CSS      Flame   flame    #E25822   Wikipedia      Flame Red   flamered    #AB2524   RAL      Flax   flax    #EEDC82   Wikipedia      Flirt   flirt    #A2006D   Wikipedia      Floral White   floralwhite    #FFFAF0   CSS      Fluorescent Blue   fluorescentblue    #15F4EE   Wikipedia      Forest Green   forestgreen    #228B22   CSS      French Beige   frenchbeige    #A67B5B   Wikipedia      French Bistre   frenchbistre    #856D4D   Wikipedia      French Blue   frenchblue    #0072BB   Wikipedia      French Fuchsia   frenchfuchsia    #FD3F92   Wikipedia      French Lilac   frenchlilac    #86608E   Wikipedia      French Lime   frenchlime    #9EFD38   Wikipedia      French Mauve   frenchmauve    #D473D4   Wikipedia      French Pink   frenchpink    #FD6C9E   Wikipedia      French Raspberry   frenchraspberry    #C72C48   Wikipedia      French Rose   frenchrose    #F64A8A   Wikipedia      French Sky Blue   frenchskyblue    #77B5FE   Wikipedia      French Violet   frenchviolet    #8806CE   Wikipedia      Frostbite   frostbite    #E936A7   Wikipedia      Fuchsia   fuchsia    #FF00FF   CSS      Fuchsia Purple   fuchsiapurple    #CC397B   Wikipedia      Fuchsia Rose   fuchsiarose    #C74375   Wikipedia      Fulvous   fulvous    #E48400   Wikipedia      Fuzzy Wuzzy   fuzzywuzzy    #87421F   Crayola      Gainsboro   gainsboro    #DCDCDC   CSS      Gamboge   gamboge    #E49B0F   Wikipedia      Garnet   garnet    #733635   Wikipedia      Generic Viridian   genericviridian    #007F66   Wikipedia      Gentian Blue   gentianblue    #13447C   RAL      Ghost White   ghostwhite    #F8F8FF   CSS      Glaucous   glaucous    #6082B6   Wikipedia      Glossy Grape   glossygrape    #AB92B3   Wikipedia      GO Green   gogreen    #00AB66   Wikipedia      Gold   gold    #FFD700   CSS      Gold Fusion   goldfusion    #85754E   Wikipedia      Golden Brown   goldenbrown    #996515   Wikipedia      Golden Poppy   goldenpoppy    #FCC200   Wikipedia      Golden Yellow   goldenyellow    #FFDF00   RAL      Goldenrod   goldenrod    #DAA520   CSS      Gotham Green   gothamgreen    #00573F   Wikipedia      Granite Gray   granitegray    #676767   Wikipedia      Granite Grey   granitegrey    #374447   RAL      Granny Smith Apple   grannysmithapple    #A8E4A0   Crayola      Graphite Black   graphiteblack    #292C2F   RAL      Graphite Grey   graphitegrey    #474A50   RAL      Grass Green   grassgreen    #3E753B   RAL      Gray   gray    #808080   CSS      Green   green    #008000   CSS      Green Beige   greenbeige    #CDBA88   RAL      Green Brown   greenbrown    #887142   RAL      Green Grey   greengrey    #5B6259   RAL      Green Lizard   greenlizard    #A7F432   Wikipedia      Green Sheen   greensheen    #6EAEA1   Wikipedia      Green Yellow   greenyellow    #ADFF2F   CSS      Green-blue   greenblue    #1164B4   RAL      Green-cyan   greencyan    #009966   Wikipedia      Greenyellow   greenyellow    #ADFF2F   CSS      Grey   grey    #808080   CSS      Grey Aluminium   greyaluminium    #8F8F8C   RAL      Grey Beige   greybeige    #A48F7A   RAL      Grey Blue   greyblue    #313C48   RAL      Grey Brown   greybrown    #3F3A3A   RAL      Grey Olive   greyolive    #40433B   RAL      Grey White   greywhite    #DDDED4   RAL      Grullo   grullo    #A99A86   Wikipedia      Gunmetal   gunmetal    #2a3439   Wikipedia      Han Blue   hanblue    #446CCF   Wikipedia      Han Purple   hanpurple    #5218FA   Wikipedia      Hansa Yellow   hansayellow    #E9D66B   Wikipedia      Harlequin   harlequin    #3FFF00   Wikipedia      Harvest Gold   harvestgold    #DA9100   Wikipedia      Heat Wave   heatwave    #FF7A00   Wikipedia      Heather Violet   heatherviolet    #D15B8F   RAL      Heliotrope   heliotrope    #DF73FF   Wikipedia      Heliotrope Gray   heliotropegray    #AA98A9   Wikipedia      Hollywood Cerise   hollywoodcerise    #F400A1   Wikipedia      Honey Yellow   honeyyellow    #CB8E00   RAL      Honeydew   honeydew    #F0FFF0   CSS      Honolulu Blue   honolulublue    #006DB0   Wikipedia      Hooker's Green   hookersgreen    #49796B   Wikipedia      Hot Fuchsia   hotfuchsia    #FF00C6   Wikipedia      Hot Magenta   hotmagenta    #FF1DCE   Wikipedia      Hot Pink   hotpink    #FF69B4   CSS      Hotpink   hotpink    #FF69B4   CSS      Hunter Green   huntergreen    #355E3B   Wikipedia      Iceberg   iceberg    #71A6D2   Wikipedia      Icterine   icterine    #FCF75E   Wikipedia      Illuminating Emerald   illuminatingemerald    #319177   Wikipedia      Imperial Red   imperialred    #ED2939   Wikipedia      Inchworm   inchworm    #B2EC5D   Wikipedia      Independence   independence    #4C516D   Wikipedia      India Green   indiagreen    #138808   Wikipedia      Indian Red   indianred    #CD5C5C   CSS      Indian Yellow   indianyellow    #E3A857   Wikipedia      Indigo   indigo    #4B0082   CSS      Indigo Dye   indigodye    #00416A   Wikipedia      International Klein Blue   internationalkleinblue    #130a8f   Wikipedia      International Orange   internationalorange    #BA160C   Wikipedia      Iris   iris    #5A4FCF   Wikipedia      Iron Grey   irongrey    #555D61   RAL      Irresistible   irresistible    #B3446C   Wikipedia      Isabelline   isabelline    #F4F0EC   Wikipedia      Italian Sky Blue   italianskyblue    #B2FFFF   Wikipedia      Ivory   ivory    #FFFFF0   CSS      Jade   jade    #00A86B   Wikipedia      Japanese Carmine   japanesecarmine    #9D2933   Wikipedia      Japanese Violet   japaneseviolet    #5B3256   Wikipedia      Jasmine   jasmine    #F8DE7E   Wikipedia      Jazzberry Jam   jazzberryjam    #A50B5E   Crayola      Jet   jet    #343434   Wikipedia      Jet Black   jetblack    #0A0A0D   RAL      Jonquil   jonquil    #F4CA16   Wikipedia      June Bud   junebud    #BDDA57   Wikipedia      Jungle Green   junglegreen    #29AB87   Crayola      Kelly Green   kellygreen    #4CBB17   Wikipedia      Keppel   keppel    #3AB09E   Wikipedia      Key Lime   keylime    #E8F48C   Wikipedia      Khaki   khaki    #F0E68C   CSS      Khaki Grey   khakigrey    #746643   RAL      Kobe   kobe    #882D17   Wikipedia      Kobi   kobi    #E79FC4   Wikipedia      Kobicha   kobicha    #6B4423   Wikipedia      Kombu Green   kombugreen    #354230   Wikipedia      KSU Purple   ksupurple    #512888   Wikipedia      La Salle Green   lasallegreen    #087830   Wikipedia      Languid Lavender   languidlavender    #D6CADD   Wikipedia      Lanzones   lanzones    #E0BC5B   Wikipedia      Lapis Lazuli   lapislazuli    #26619C   Wikipedia      Laser Lemon   laserlemon    #FFFF66   Wikipedia      Laurel Green   laurelgreen    #A9BA9D   Wikipedia      Lava   lava    #CF1020   Wikipedia      Lavender   lavender    #E6E6FA   CSS      Lavender Blue   lavenderblue    #CCCCFF   Wikipedia      Lavender Blush   lavenderblush    #FFF0F5   CSS      Lavender Gray   lavendergray    #C4C3D0   Wikipedia      Lavender Indigo   lavenderindigo    #9457EB   Wikipedia      Lavender Magenta   lavendermagenta    #EE82EE   Wikipedia      Lavender Mist   lavendermist    #E6E6FA   Wikipedia      Lavender Purple   lavenderpurple    #967BB6   Wikipedia      Lavender Rose   lavenderrose    #FBA0E3   Wikipedia      Lawn Green   lawngreen    #7CFC00   CSS      Leaf Green   leafgreen    #276235   RAL      Lemon   lemon    #FFF700   Wikipedia      Lemon Chiffon   lemonchiffon    #FFFACD   CSS      Lemon Curry   lemoncurry    #CCA01D   Wikipedia      Lemon Glacier   lemonglacier    #FDFF00   Wikipedia      Lemon Iced Tea   lemonicedtea    #BD3000   Wikipedia      Lemon Lime   lemonlime    #E3FF00   Wikipedia      Lemon Meringue   lemonmeringue    #F6EABE   Wikipedia      Lemon Yellow   lemonyellow    #FFF44F   RAL      Liberty   liberty    #545AA7   Wikipedia      Licorice   licorice    #1A1110   Wikipedia      Light Blue   lightblue    #ADD8E6   CSS      Light Brown   lightbrown    #B5651D   Wikipedia      Light Carmine Pink   lightcarminepink    #E66771   Wikipedia      Light Chocolate Cosmos   lightchocolatecosmos    #551F2F   Wikipedia      Light Chrome Green   lightchromegreen    #BEE64B   Crayola      Light Cobalt Blue   lightcobaltblue    #88ACE0   Wikipedia      Light Coral   lightcoral    #F08080   CSS      Light Cornflower Blue   lightcornflowerblue    #93CCEA   Wikipedia      Light Crimson   lightcrimson    #F56991   Wikipedia      Light Cyan   lightcyan    #E0FFFF   CSS      Light French Beige   lightfrenchbeige    #C8AD7F   Wikipedia      Light Fuchsia Pink   lightfuchsiapink    #F984EF   Wikipedia      Light Gold   lightgold    #B29700   Wikipedia      Light Goldenrod Yellow   lightgoldenrodyellow    #FAFAD2   CSS      Light Gray   lightgray    #D3D3D3   CSS      Light Grayish Magenta   lightgrayishmagenta    #CC99CC   Wikipedia      Light Green   lightgreen    #90EE90   CSS      Light Grey   lightgrey    #D3D3D3   CSS      Light Ivory   lightivory    #E6D2B5   RAL      Light Medium Orchid   lightmediumorchid    #D39BCB   Wikipedia      Light Moss Green   lightmossgreen    #ADDFAD   Wikipedia      Light Orange   lightorange    #FED8B1   Wikipedia      Light Orchid   lightorchid    #E6A8D7   Wikipedia      Light Pastel Purple   lightpastelpurple    #B19CD9   Wikipedia      Light Periwinkle   lightperiwinkle    #C5CBE1   Wikipedia      Light Pink   lightpink    #FFB6C1   CSS      Light Red   lightred    #FFCCCB   Wikipedia      Light Red Ochre   lightredochre    #E97451   Wikipedia      Light Salmon   lightsalmon    #FFA07A   CSS      Light Salmon Pink   lightsalmonpink    #FF9999   Wikipedia      Light Sea Green   lightseagreen    #20B2AA   CSS      Light Silver   lightsilver    #D8D8D8   Wikipedia      Light Sky Blue   lightskyblue    #87CEFA   CSS      Light Slate Gray   lightslategray    #778899   CSS      Light Slate Grey   lightslategrey    #778899   CSS      Light Steel Blue   lightsteelblue    #B0C4DE   CSS      Light Thulian Pink   lightthulianpink    #E68FAC   Wikipedia      Light Venetian Red   lightvenetianred    #E6735C   Crayola      Light Yellow   lightyellow    #FFFFE0   CSS      Lightcoral   lightcoral    #F08080   CSS      Lightcyan   lightcyan    #E0FFFF   CSS      Lightgrey   lightgrey    #D3D3D3   CSS      Lightpink   lightpink    #FFB6C1   CSS      Lightsalmon   lightsalmon    #FFA07A   CSS      Lightsea Green   lightseagreen    #20B2AA   CSS      Lightsky Blue   lightskyblue    #87CEFA   CSS      Lightslate Gray   lightslategray    #778899   CSS      Lightslategrey   lightslategrey    #778899   CSS      Lightsteel Blue   lightsteelblue    #B0C4DE   CSS      Lilac   lilac    #C8A2C8   Wikipedia      Lilac Luster   lilacluster    #AE98AA   Wikipedia      Lime   lime    #00FF00   CSS      Lime Green   limegreen    #32CD32   CSS      Limerick   limerick    #9DC209   Wikipedia      Lincoln Green   lincolngreen    #195905   Wikipedia      Linen   linen    #FAF0E6   CSS      Lion   lion    #DECC9C   Wikipedia      Liseran Purple   liseranpurple    #DE6FA1   Wikipedia      Little Boy Blue   littleboyblue    #6CA0DC   Wikipedia      Little Girl Pink   littlegirlpink    #F8B9D4   Wikipedia      Liver   liver    #674C47   Wikipedia      Liver Chestnut   liverchestnut    #987456   Wikipedia      Livid   livid    #6699CC   Wikipedia      Lotion   lotion    #FEFDFA   Wikipedia      Lotion Blue   lotionblue    #15F2FD   Wikipedia      Lotion Pink   lotionpink    #ECCFCF   Wikipedia      Lumber   lumber    #FFE4CD   Wikipedia      Luminous Bright Orange   luminousbrightorange    #FFA421   RAL      Luminous Bright Red   luminousbrightred    #FF0000   RAL      Luminous Green   luminousgreen    #00F700   RAL      Luminous Orange   luminousorange    #FF2300   RAL      Luminous Red   luminousred    #F70000   RAL      Luminous Yellow   luminousyellow    #FFFF00   RAL      Lust   lust    #E62020   Wikipedia      Maastricht Blue   maastrichtblue    #001C3D   Wikipedia      Macaroni And Cheese   macaroniandcheese    #FFBD88   Crayola      Madder Lake   madderlake    #CC3336   Crayola      Magenta   magenta    #FF00FF   CSS      Magenta Haze   magentahaze    #9F4576   Wikipedia      Magic Mint   magicmint    #AAF0D1   Wikipedia      Magnolia   magnolia    #F2E8D7   Wikipedia      Mahogany   mahogany    #C04000   Crayola      Mahogany Brown   mahoganybrown    #4C2F26   RAL      Maize   maize    #FBEC5D   Crayola      Maize Yellow   maizeyellow    #E29000   RAL      Majorelle Blue   majorelleblue    #6050DC   Wikipedia      Malachite   malachite    #0BDA51   Wikipedia      Manatee   manatee    #979AAA   Crayola      Mandarin   mandarin    #F37A48   Wikipedia      Mango   mango    #FDBE02   Wikipedia      Mango Green   mangogreen    #96FF00   Wikipedia      Mango Tango   mangotango    #FF8243   Crayola      Mantis   mantis    #74C365   Wikipedia      Mardi Gras   mardigras    #880085   Wikipedia      Marigold   marigold    #EAA221   Wikipedia      Maroon   maroon    #800000   CSS      Mauve   mauve    #E0B0FF   Wikipedia      Mauve Taupe   mauvetaupe    #915F6D   Wikipedia      Mauvelous   mauvelous    #EF98AA   Crayola      Maximum Blue   maximumblue    #47ABCC   Crayola      Maximum Blue Green   maximumbluegreen    #30BFBF   Crayola      Maximum Blue Purple   maximumbluepurple    #ACACE6   Crayola      Maximum Green   maximumgreen    #5E8C31   Crayola      Maximum Green Yellow   maximumgreenyellow    #D9E650   Crayola      Maximum Orange   maximumorange    #FF5B00   Wikipedia      Maximum Pink   maximumpink    #F6A5F2   Wikipedia      Maximum Purple   maximumpurple    #733380   Crayola      Maximum Red   maximumred    #D92121   Crayola      Maximum Red Purple   maximumredpurple    #A63A79   Crayola      Maximum Violet   maximumviolet    #892F77   Wikipedia      Maximum Yellow   maximumyellow    #FAFA37   Crayola      Maximum Yellow Red   maximumyellowred    #F2BA49   Crayola      May Green   maygreen    #4C9141   RAL      Maya Blue   mayablue    #73C2FB   Wikipedia      Medium Aquamarine   mediumaquamarine    #66CDAA   CSS      Medium Blue   mediumblue    #0000CD   CSS      Medium Candy Apple Red   mediumcandyapplered    #E2062C   Wikipedia      Medium Carmine   mediumcarmine    #AF4035   Wikipedia      Medium Champagne   mediumchampagne    #F3E5AB   Wikipedia      Medium Chrome Green   mediumchromegreen    #6CA67C   Crayola      Medium Electric Blue   mediumelectricblue    #035096   Wikipedia      Medium Green   mediumgreen    #037949   Wikipedia      Medium Jungle Green   mediumjunglegreen    #1C352D   Wikipedia      Medium Lavender Magenta   mediumlavendermagenta    #DDA0DD   Wikipedia      Medium Orange   mediumorange    #FF7802   Wikipedia      Medium Orchid   mediumorchid    #BA55D3   CSS      Medium Persian Blue   mediumpersianblue    #0067A5   Wikipedia      Medium Pink   mediumpink    #FE6E9F   Wikipedia      Medium Purple   mediumpurple    #9370DB   CSS      Medium Red   mediumred    #B10304   Wikipedia      Medium Red-violet   mediumredviolet    #BB3385   Wikipedia      Medium Rose   mediumrose    #D96CBE   Crayola      Medium Ruby   mediumruby    #AA4069   Wikipedia      Medium Sea Green   mediumseagreen    #3CB371   CSS      Medium Sky Blue   mediumskyblue    #80DAEB   Wikipedia      Medium Slate Blue   mediumslateblue    #7B68EE   CSS      Medium Spring Bud   mediumspringbud    #C9DC87   Wikipedia      Medium Spring Green   mediumspringgreen    #00FA9A   CSS      Medium Taupe   mediumtaupe    #674C47   Wikipedia      Medium Turquoise   mediumturquoise    #48D1CC   CSS      Medium Tuscan Red   mediumtuscanred    #79443B   Wikipedia      Medium Vermilion   mediumvermilion    #D9603B   Wikipedia      Medium Violet   mediumviolet    #8F47B3   Crayola      Medium Violet Red   mediumvioletred    #C71585   CSS      Medium Violet-red   mediumvioletred    #C71585   CSS      Medium Yellow   mediumyellow    #FFE302   Wikipedia      Mediumorchid   mediumorchid    #BA55D3   CSS      Mediumpurple   mediumpurple    #9370DB   CSS      Mediumsea Green   mediumseagreen    #3CB371   CSS      Mediumslate Blue   mediumslateblue    #7B68EE   CSS      Mediumspring Green   mediumspringgreen    #00FA9A   CSS      Mediumturquoise   mediumturquoise    #48D1CC   CSS      Mellow Apricot   mellowapricot    #F8B878   Wikipedia      Mellow Yellow   mellowyellow    #F8DE7E   Wikipedia      Melon   melon    #FEBAAD   Crayola      Melon Yellow   melonyellow    #FF9B00   RAL      Menthol   menthol    #C1F9A2   Wikipedia      Metallic Blue   metallicblue    #32527B   Wikipedia      Metallic Bronze   metallicbronze    #A97142   Wikipedia      Metallic Brown   metallicbrown    #AC4313   Wikipedia      Metallic Gold   metallicgold    #D3AF37   Wikipedia      Metallic Green   metallicgreen    #296E01   Wikipedia      Metallic Orange   metallicorange    #DA680F   Wikipedia      Metallic Pink   metallicpink    #EDA6C4   Wikipedia      Metallic Red   metallicred    #A62C2B   Wikipedia      Metallic Seaweed   metallicseaweed    #0A7E8C   Wikipedia      Metallic Silver   metallicsilver    #A8A9AD   Wikipedia      Metallic Sunburst   metallicsunburst    #9C7C38   Wikipedia      Metallic Violet   metallicviolet    #5B0A91   Wikipedia      Metallic Yellow   metallicyellow    #FDCC0D   Wikipedia      Mexican Pink   mexicanpink    #E4007C   Wikipedia      Microsoft Blue   microsoftblue    #00A2ED   Wikipedia      Microsoft Edge Blue   microsoftedgeblue    #0078D7   Wikipedia      Microsoft Green   microsoftgreen    #7DB700   Wikipedia      Microsoft Red   microsoftred    #F04E1F   Wikipedia      Microsoft Yellow   microsoftyellow    #FDB900   Wikipedia      Middle Blue   middleblue    #7ED4E6   Crayola      Middle Blue Green   middlebluegreen    #8DD9CC   Crayola      Middle Blue Purple   middlebluepurple    #8B72BE   Crayola      Middle Green   middlegreen    #4D8C57   Crayola      Middle Green Yellow   middlegreenyellow    #ACBF60   Crayola      Middle Grey   middlegrey    #8B8680   Wikipedia      Middle Purple   middlepurple    #D982B5   Crayola      Middle Red   middlered    #E58E73   Crayola      Middle Red Purple   middleredpurple    #A55353   Crayola      Middle Yellow   middleyellow    #FFEB00   Crayola      Middle Yellow Red   middleyellowred    #ECB176   Crayola      Midnight   midnight    #702670   Wikipedia      Midnight Blue   midnightblue    #191970   CSS      Midnight Green   midnightgreen    #004953   Wikipedia      Mikado Yellow   mikadoyellow    #FFC40C   Wikipedia      Milk   milk    #FDFFF5   Wikipedia      Milk Chocolate   milkchocolate    #84563C   Wikipedia      Mimi Pink   mimipink    #FFDAE9   Wikipedia      Mindaro   mindaro    #E3F988   Wikipedia      Ming   ming    #36747D   Wikipedia      Minion Yellow   minionyellow    #F5E050   Wikipedia      Mint   mint    #3EB489   Wikipedia      Mint Cream   mintcream    #F5FFFA   CSS      Mint Green   mintgreen    #98FF98   RAL      Mint Turquoise   mintturquoise    #478A84   RAL      Misty Moss   mistymoss    #BBB477   Wikipedia      Misty Rose   mistyrose    #FFE4E1   CSS      Mistyrose   mistyrose    #FFE4E1   CSS      Moccasin   moccasin    #FFE4B5   CSS      Mocha   mocha    #BEA493   Wikipedia      Mode Beige   modebeige    #967117   Wikipedia      Mona Lisa   monalisa    #FF948E   Wikipedia      Moonstone   moonstone    #3AA8C1   Wikipedia      Moonstone Blue   moonstoneblue    #73A9C2   Wikipedia      Mordant Red 19   mordantred    #AE0C00   Wikipedia      Morning Blue   morningblue    #8DA399   Wikipedia      Moss Green   mossgreen    #8A9A5B   RAL      Moss Grey   mossgrey    #7A7B6D   RAL      Mountain Meadow   mountainmeadow    #30BA8F   Crayola      Mountbatten Pink   mountbattenpink    #997A8D   Wikipedia      Mouse Grey   mousegrey    #6B716F   RAL      MSU Green   msugreen    #18453B   Wikipedia      Mud   mud    #70543E   Wikipedia      Mughal Green   mughalgreen    #306030   Wikipedia      Mulberry   mulberry    #C54B8C   Crayola      Mummy's Tomb   mummystomb    #828E84   Wikipedia      Mustard   mustard    #FFDB58   Wikipedia      Mustard Brown   mustardbrown    #CD7A00   Wikipedia      Mustard Green   mustardgreen    #6E6E30   Wikipedia      Mustard Yellow   mustardyellow    #E1AD01   Wikipedia      Myrtle Green   myrtlegreen    #317873   Wikipedia      Mystic   mystic    #D65282   Wikipedia      Mystic Maroon   mysticmaroon    #AD4379   Wikipedia      Mystic Red   mysticred    #FF5500   Wikipedia      Nadeshiko Pink   nadeshikopink    #F6ADC6   Wikipedia      Napier Green   napiergreen    #2A8000   Wikipedia      Naples Yellow   naplesyellow    #FADA5E   Wikipedia      Navajo White   navajowhite    #FFDEAD   CSS      Navy   navy    #000080   CSS      Navy Blue   navyblue    #000080   Crayola      Navy Purple   navypurple    #9457EB   Wikipedia      Neon Blue   neonblue    #4666FF   Wikipedia      Neon Brown   neonbrown    #C3732A   Wikipedia      Neon Carrot   neoncarrot    #AAF0D1   Wikipedia      Neon Cyan   neoncyan    #00FEFC   Wikipedia      Neon Dark Green   neondarkgreen    #008443   Wikipedia      Neon Fuchsia   neonfuchsia    #FE4164   Wikipedia      Neon Gold   neongold    #CFAA01   Wikipedia      Neon Gray   neongray    #808080   Wikipedia      Neon Green   neongreen    #39FF14   Wikipedia      Neon Pink   neonpink    #FE347E   Wikipedia      Neon Purple   neonpurple    #9457EB   Wikipedia      Neon Red   neonred    #FF1818   Wikipedia      Neon Scarlet   neonscarlet    #FF2603   Wikipedia      Neon Silver   neonsilver    #CCCCCC   Wikipedia      Neon Tangerine   neontangerine    #F6890A   Wikipedia      Neon Yellow   neonyellow    #FFF700   Wikipedia      New Car   newcar    #214FC6   Wikipedia      New York Pink   newyorkpink    #D7837F   Wikipedia      Nickel   nickel    #727472   Wikipedia      Night Blue   nightblue    #2F2A5A   RAL      Nintendo Red   nintendored    #E4000F   Wikipedia      Non-photo Blue   nonphotoblue    #A4DDED   Wikipedia      Nut Brown   nutbrown    #5A3A29   RAL      Nyanza   nyanza    #E9FFDB   Wikipedia      Oatmeal   oatmeal    #D9DAD2   Crayola      Ocean Blue   oceanblue    #0B4151   RAL      Ocean Boat Blue   oceanboatblue    #0077BE   Wikipedia      Ochre   ochre    #CC7722   Wikipedia      Ochre Brown   ochrebrown    #9C6B30   RAL      Ochre Yellow   ochreyellow    #BA8F4C   RAL      Office Green   officegreen    #008000   Wikipedia      Old Burgundy   oldburgundy    #43302E   Wikipedia      Old Gold   oldgold    #CFB53B   Wikipedia      Old Heliotrope   oldheliotrope    #563C5C   Wikipedia      Old Lace   oldlace    #FDF5E6   CSS      Old Lavender   oldlavender    #796878   Wikipedia      Old Mauve   oldmauve    #673147   Wikipedia      Old Moss Green   oldmossgreen    #867E36   Wikipedia      Old Rose   oldrose    #C08081   Wikipedia      Old Silver   oldsilver    #848482   Wikipedia      Oldlace   oldlace    #FDF5E6   CSS      Olive   olive    #808000   CSS      Olive Brown   olivebrown    #6F4F28   RAL      Olive Drab   olivedrab    #6B8E23   CSS      Olive Green   olivegreen    #B5B35C   RAL      Olive Grey   olivegrey    #817F68   RAL      Olive Yellow   oliveyellow    #A08F65   RAL      Olive-drab/brown Olive   brownolive    #3E3C32   RAL      Olivedrab   olivedrab    #6B8E23   CSS      Olivine   olivine    #9AB973   Wikipedia      Onyx   onyx    #353839   Wikipedia      Opal   opal    #A8C3BC   Wikipedia      Opal Green   opalgreen    #005D52   RAL      Opera Mauve   operamauve    #B784A7   Wikipedia      Orange   orange    #FFA500   CSS      Orange Brown   orangebrown    #A65E2F   RAL      Orange Iced Tea   orangeicedtea    #FF6700   Wikipedia      Orange Peel   orangepeel    #FF9F00   Wikipedia      Orange Red   orangered    #FF4500   CSS      Orange Soda   orangesoda    #FA5B3D   Wikipedia      Orange-yellow   orangeyellow    #F5BD1F   Crayola      Orchid   orchid    #DA70D6   CSS      Orchid Pink   orchidpink    #F2BDCD   Wikipedia      Orient Red   orientred    #AC323B   RAL      Orioles Orange   oriolesorange    #FB4F14   Wikipedia      Otter Brown   otterbrown    #654321   Wikipedia      OU Crimson Red   oucrimsonred    #841617   Wikipedia      Outer Space   outerspace    #2D383A   Crayola      Outrageous Orange   outrageousorange    #FF6E4A   Wikipedia      Oxblood   oxblood    #4A0000   Wikipedia      Oxford Blue   oxfordblue    #002147   Wikipedia      Oxide Red   oxidered    #703731   RAL      Oxley   oxley    #6D9A79   Wikipedia      Oyster White   oysterwhite    #E3D9C6   RAL      Pacific Blue   pacificblue    #1CA9C9   Crayola      Pakistan Green   pakistangreen    #006600   Wikipedia      Palatinate Blue   palatinateblue    #273BE2   Wikipedia      Palatinate Purple   palatinatepurple    #682860   Wikipedia      Pale Aqua   paleaqua    #BED3E5   Wikipedia      Pale Blue   paleblue    #AFEEEE   Wikipedia      Pale Brown   palebrown    #755C49   RAL      Pale Carmine   palecarmine    #AF4035   Wikipedia      Pale Cerulean   palecerulean    #9BC4E2   Wikipedia      Pale Chestnut   palechestnut    #DDADAF   Wikipedia      Pale Copper   palecopper    #DA8A67   Wikipedia      Pale Cornflower Blue   palecornflowerblue    #ABCDEF   Wikipedia      Pale Cyan   palecyan    #87D3F8   Wikipedia      Pale Dogwood   paledogwood    #ED7A9B   Wikipedia      Pale Gold   palegold    #E6BE8A   Wikipedia      Pale Goldenrod   palegoldenrod    #EEE8AA   CSS      Pale Green   palegreen    #98FB98   CSS      Pale Lavender   palelavender    #DCD0FF   Wikipedia      Pale Magenta   palemagenta    #F984E5   Wikipedia      Pale Pink   palepink    #FADADD   Wikipedia      Pale Plum   paleplum    #DDA0DD   Wikipedia      Pale Purple   palepurple    #FAE6FA   Wikipedia      Pale Robin Egg Blue   palerobineggblue    #96DED1   Wikipedia      Pale Silver   palesilver    #C9C0BB   Wikipedia      Pale Spring Bud   palespringbud    #ECEBBD   Wikipedia      Pale Taupe   paletaupe    #BC987E   Wikipedia      Pale Turquoise   paleturquoise    #AFEEEE   CSS      Pale Violet   paleviolet    #CC99FF   Wikipedia      Pale Violet Red   palevioletred    #DB7093   CSS      Palegoldenrod   palegoldenrod    #EEE8AA   CSS      Paleturquoise   paleturquoise    #AFEEEE   CSS      Pansy Purple   pansypurple    #78184A   Wikipedia      Paolo Veronese Green   paoloveronesegreen    #009B7D   Wikipedia      Papaya Whip   papayawhip    #FFEFD5   CSS      Papyrus White   papyruswhite    #CFD3CD   RAL      Paradise Pink   paradisepink    #E63E62   Wikipedia      Parchment   parchment    #F1E9D2   Wikipedia      Paris Green   parisgreen    #50C878   Wikipedia      Pastel Blue   pastelblue    #6A93B0   RAL      Pastel Brown   pastelbrown    #836953   Wikipedia      Pastel Gray   pastelgray    #CFCFC4   Wikipedia      Pastel Green   pastelgreen    #B7D9B1   RAL      Pastel Magenta   pastelmagenta    #F49AC2   Wikipedia      Pastel Orange   pastelorange    #FA842B   RAL      Pastel Pink   pastelpink    #DEA5A4   Wikipedia      Pastel Purple   pastelpurple    #B39EB5   Wikipedia      Pastel Red   pastelred    #FF6961   Wikipedia      Pastel Turquoise   pastelturquoise    #7FB0B2   RAL      Pastel Violet   pastelviolet    #A38995   RAL      Pastel Yellow   pastelyellow    #EB9C52   RAL      Patina Green   patinagreen    #327662   RAL      Patriarch   patriarch    #800080   Wikipedia      Paua   paua    #1F005E   Wikipedia      Payne's Grey   paynesgrey    #536878   Wikipedia      Peach   peach    #FFE5B4   Crayola      Peach Puff   peachpuff    #FFDAB9   CSS      Peachpuff   peachpuff    #FFDAB9   CSS      Pear   pear    #D1E231   Wikipedia      Pearl   pearl    #EAE0C8   Wikipedia      Pearl Aqua   pearlaqua    #88D8C0   Wikipedia      Pearl Beige   pearlbeige    #908370   RAL      Pearl Blackberry   pearlblackberry    #6B6880   RAL      Pearl Copper   pearlcopper    #773C27   RAL      Pearl Dark Grey   pearldarkgrey    #7E8182   RAL      Pearl Gentian Blue   pearlgentianblue    #296478   RAL      Pearl Gold   pearlgold    #80643F   RAL      Pearl Green   pearlgreen    #1B542C   RAL      Pearl Light Grey   pearllightgrey    #9C9C9C   RAL      Pearl Mouse Grey   pearlmousegrey    #888175   RAL      Pearl Night Blue   pearlnightblue    #102C54   RAL      Pearl Opal Green   pearlopalgreen    #005D4C   RAL      Pearl Orange   pearlorange    #954527   RAL      Pearl Pink   pearlpink    #B24C43   RAL      Pearl Ruby Red   pearlrubyred    #711521   RAL      Pearl Violet   pearlviolet    #8773A1   RAL      Pearly Purple   pearlypurple    #B768A2   Wikipedia      Pebble Grey   pebblegrey    #B9B9A8   RAL      Peridot   peridot    #E6E200   Wikipedia      Periwinkle   periwinkle    #CCCCFF   Crayola      Permanent Geranium Lake   permanentgeraniumlake    #E12C2C   Crayola      Persian Blue   persianblue    #1C39BB   Wikipedia      Persian Green   persiangreen    #00A693   Wikipedia      Persian Indigo   persianindigo    #32127A   Wikipedia      Persian Orange   persianorange    #D99058   Wikipedia      Persian Pink   persianpink    #F77FBE   Wikipedia      Persian Plum   persianplum    #701C1C   Wikipedia      Persian Red   persianred    #CC3333   Wikipedia      Persian Rose   persianrose    #FE28A2   Wikipedia      Persimmon   persimmon    #EC5800   Wikipedia      Peru   peru    #CD853F   CSS      Petal   petal    #F5E2E2   Wikipedia      Pewter Blue   pewterblue    #8BA8B7   Wikipedia      Philippine Blue   philippineblue    #0038A7   Wikipedia      Philippine Bronze   philippinebronze    #6E3A07   Wikipedia      Philippine Brown   philippinebrown    #5D1916   Wikipedia      Philippine Gold   philippinegold    #B17304   Wikipedia      Philippine Golden Yellow   philippinegoldenyellow    #FFDF00   Wikipedia      Philippine Gray   philippinegray    #8C8C8C   Wikipedia      Philippine Green   philippinegreen    #008543   Wikipedia      Philippine Indigo   philippineindigo    #00416A   Wikipedia      Philippine Orange   philippineorange    #FF7300   Wikipedia      Philippine Pink   philippinepink    #FA1A8E   Wikipedia      Philippine Red   philippinered    #CE1127   Wikipedia      Philippine Silver   philippinesilver    #B3B3B3   Wikipedia      Philippine Sky Blue   philippineskyblue    #0066FF   Wikipedia      Philippine Violet   philippineviolet    #81007F   Wikipedia      Philippine Yellow   philippineyellow    #FECB00   Wikipedia      Phlox   phlox    #DF00FF   Wikipedia      Phthalo Blue   phthaloblue    #000F89   Wikipedia      Phthalo Green   phthalogreen    #123524   Wikipedia      Picotee Blue   picoteeblue    #2E2787   Wikipedia      Picton Blue   pictonblue    #45B1E8   Wikipedia      Pictorial Carmine   pictorialcarmine    #C30B4E   Wikipedia      Pigeon Blue   pigeonblue    #6C7C98   RAL      Piggy Pink   piggypink    #FDDDE6   Crayola      Pine Green   pinegreen    #01796F   RAL      Pineapple   pineapple    #563C0D   Wikipedia      Pink   pink    #FFC0CB   CSS      Pink Flamingo   pinkflamingo    #FC74FD   Crayola      Pink Lace   pinklace    #FFDDF4   Wikipedia      Pink Lavender   pinklavender    #D8B2D1   Wikipedia      Pink Pearl   pinkpearl    #E7ACCF   Wikipedia      Pink Sherbert   pinksherbert    #F7A38E   Crayola      Pink Sherbet   pinksherbet    #F78FA7   Wikipedia      Pistachio   pistachio    #93C572   Wikipedia      Platinum   platinum    #E5E4E2   Wikipedia      Platinum Grey   platinumgrey    #9A9697   RAL      Plum   plum    #DDA0DD   CSS      Plump Purple   plumppurple    #5946B2   Wikipedia      Poison Purple   poisonpurple    #7F01FE   Wikipedia      Police Blue   policeblue    #374F6B   Wikipedia      Polished Pine   polishedpine    #5DA493   Wikipedia      Pomp And Power   pompandpower    #86608E   Wikipedia      Popstar   popstar    #BE4F62   Wikipedia      Portland Orange   portlandorange    #FF5A36   Wikipedia      Powder Blue   powderblue    #B0E0E6   CSS      Prairie Gold   prairiegold    #E1CA7A   Wikipedia      Princeton Orange   princetonorange    #F58025   Wikipedia      Prune   prune    #701C1C   Wikipedia      Prussian Blue   prussianblue    #003153   Wikipedia      Psychedelic Purple   psychedelicpurple    #DF00FF   Wikipedia      Puce   puce    #CC8899   Wikipedia      Puce Red   pucered    #722F37   Wikipedia      Pullman Brown   pullmanbrown    #644117   Wikipedia      Pumpkin   pumpkin    #FF7518   Wikipedia      Pure Green   puregreen    #25E712   RAL      Pure Orange   pureorange    #E75B12   RAL      Pure Red   purered    #E72512   RAL      Pure White   purewhite    #F7F9EF   RAL      Purple   purple    #800080   CSS      Purple Heart   purpleheart    #652DC1   Crayola      Purple Mountain Majesty   purplemountainmajesty    #9678B6   Wikipedia      Purple Mountains' Majesty   purplemountainsmajesty    #D6AEDD   Crayola      Purple Navy   purplenavy    #4E5180   Wikipedia      Purple Pizzazz   purplepizzazz    #FE4EDA   Wikipedia      Purple Plum   purpleplum    #9C51B6   Wikipedia      Purple Red   purplered    #701F29   RAL      Purple Taupe   purpletaupe    #50404D   Wikipedia      Purple Violet   purpleviolet    #4A203B   RAL      Purpureus   purpureus    #9A4EAE   Wikipedia      Quartz   quartz    #51484F   Wikipedia      Quartz Grey   quartzgrey    #6B695F   RAL      Queen Blue   queenblue    #436B95   Wikipedia      Queen Pink   queenpink    #E8CCD7   Wikipedia      Quick Silver   quicksilver    #A6A6A6   Wikipedia      Quinacridone Magenta   quinacridonemagenta    #8E3A59   Wikipedia      Quincy   quincy    #6A5445   Wikipedia      Rackley   rackley    #5D8AA8   Wikipedia      Radical Red   radicalred    #FF355E   Wikipedia      Raisin Black   raisinblack    #242124   Wikipedia      Rajah   rajah    #FBAB60   Wikipedia      RAL Orange   ralorange    #FA4402   RAL      Raspberry   raspberry    #E30B5D   Wikipedia      Raspberry Glacé   raspberryglace    #915F6D   Wikipedia      Raspberry Red   raspberryred    #B42041   RAL      Raspberry Rose   raspberryrose    #B3446C   Wikipedia      Raw Sienna   rawsienna    #D68A59   Crayola      Raw Umber   rawumber    #826644   Crayola      Razzle Dazzle Rose   razzledazzlerose    #FF33CC   Wikipedia      Razzmatazz   razzmatazz    #E3256B   Crayola      Razzmic Berry   razzmicberry    #8D4E85   Wikipedia      Rebecca Purple   rebeccapurple    #663399   CSS      Red   red    #FF0000   CSS      Red Brown   redbrown    #673831   RAL      Red Cola   redcola    #DF0118   Wikipedia      Red Lilac   redlilac    #8A5A83   RAL      Red Rum   redrum    #973A4A   Wikipedia      Red Salsa   redsalsa    #FD3A4A   Wikipedia      Red Strawberry   redstrawberry    #EC0304   Wikipedia      Red-orange   redorange    #FF5349   RAL      Red-purple   redpurple    #E40078   Wikipedia      Red-violet   redviolet    #C71585   RAL      Redwood   redwood    #A45A52   Wikipedia      Reed Green   reedgreen    #797C5A   RAL      Registration Black   registrationblack    #000000   Wikipedia      Reseda Green   resedagreen    #68825B   RAL      Resolution Blue   resolutionblue    #002387   Wikipedia      Rhythm   rhythm    #777696   Wikipedia      Rich Black   richblack    #004040   Wikipedia      Rich Brilliant Lavender   richbrilliantlavender    #F1A7FE   Wikipedia      Rich Carmine   richcarmine    #D70040   Wikipedia      Rich Electric Blue   richelectricblue    #0892D0   Wikipedia      Rich Lavender   richlavender    #A76BCF   Wikipedia      Rich Lilac   richlilac    #B666D2   Wikipedia      Rich Maroon   richmaroon    #B03060   Wikipedia      Rifle Green   riflegreen    #444C38   Wikipedia      Ripe Mango   ripemango    #FFC324   Wikipedia      Roast Coffee   roastcoffee    #704241   Wikipedia      Robin Egg Blue   robineggblue    #00CCCC   Wikipedia      Robin's Egg Blue   robinseggblue    #00CCCC   Crayola      Rocket Metallic   rocketmetallic    #8A7F80   Wikipedia      Rojo Spanish Red   rojospanishred    #A91101   Wikipedia      Roman Silver   romansilver    #838996   Wikipedia      Root Beer   rootbeer    #290E05   Wikipedia      Rose   rose    #FF007F   RAL      Rose Bonbon   rosebonbon    #F9429E   Wikipedia      Rose Dust   rosedust    #9E5E6F   Wikipedia      Rose Ebony   roseebony    #674846   Wikipedia      Rose Madder   rosemadder    #E32636   Wikipedia      Rose Pink   rosepink    #FF66CC   Wikipedia      Rose Pompadour   rosepompadour    #ED7A9B   Wikipedia      Rose Red   rosered    #C21E56   Wikipedia      Rose Taupe   rosetaupe    #905D5D   Wikipedia      Rose Vale   rosevale    #AB4E52   Wikipedia      Rosewood   rosewood    #65000B   Wikipedia      Rosso Corsa   rossocorsa    #D40000   Wikipedia      Rosy Brown   rosybrown    #BC8F8F   CSS      Royal Azure   royalazure    #0038A8   Wikipedia      Royal Blue   royalblue    #4169E1   CSS      Royal Brown   royalbrown    #523B35   Wikipedia      Royal Fuchsia   royalfuchsia    #CA2C92   Wikipedia      Royal Green   royalgreen    #136207   Wikipedia      Royal Orange   royalorange    #F99245   Wikipedia      Royal Pink   royalpink    #E73895   Wikipedia      Royal Purple   royalpurple    #7851A9   Crayola      Royal Red   royalred    #9B1C31   Wikipedia      Royal Yellow   royalyellow    #FADA5E   Wikipedia      Ruber   ruber    #CE4676   Wikipedia      Rubine Red   rubinered    #D10056   Wikipedia      Ruby   ruby    #E0115F   Wikipedia      Ruby Red   rubyred    #9B111E   RAL      Rufous   rufous    #A81C07   Wikipedia      Rum   rum    #9A4E40   Wikipedia      Russet   russet    #80461B   Wikipedia      Russian Green   russiangreen    #679267   Wikipedia      Russian Violet   russianviolet    #32174D   Wikipedia      Rust   rust    #B7410E   Wikipedia      Rusty Red   rustyred    #DA2C43   Wikipedia      Sacramento State Green   sacramentostategreen    #043927   Wikipedia      Saddle Brown   saddlebrown    #8B4513   CSS      Safety Orange   safetyorange    #FF7800   Wikipedia      Safety Yellow   safetyyellow    #EED202   Wikipedia      Saffron   saffron    #F4C430   Wikipedia      Saffron Yellow   saffronyellow    #F6A950   RAL      Sage   sage    #BCB88A   Wikipedia      Salem   salem    #177B4D   Wikipedia      Salmon   salmon    #FA8072   CSS      Salmon Orange   salmonorange    #DB6A50   RAL      Salmon Pink   salmonpink    #FF91A4   RAL      Salmon Rose   salmonrose    #E7968B   Wikipedia      Samsung Blue   samsungblue    #12279E   Wikipedia      Sand   sand    #C2B280   Wikipedia      Sand Dune   sanddune    #967117   Wikipedia      Sand Yellow   sandyellow    #D2AA6D   RAL      Sandy Brown   sandybrown    #F4A460   CSS      Sandy Taupe   sandytaupe    #967117   Wikipedia      Sap Green   sapgreen    #507D2A   Wikipedia      Sapphire   sapphire    #0F52BA   Wikipedia      Sapphire Blue   sapphireblue    #0067A5   RAL      Satin Sheen Gold   satinsheengold    #CBA135   Wikipedia      Scarlet   scarlet    #FF2400   Crayola      Schauss Pink   schausspink    #FF91AF   Wikipedia      School Bus Yellow   schoolbusyellow    #FFD800   Wikipedia      Screamin' Green   screamingreen    #66FF66   Wikipedia      Sea Blue   seablue    #006994   Wikipedia      Sea Green   seagreen    #2E8B57   CSS      Seal Brown   sealbrown    #59260B   Wikipedia      Seance   seance    #612086   Wikipedia      Seashell   seashell    #FFF5EE   CSS      Secret   secret    #764374   Wikipedia      Selective Yellow   selectiveyellow    #FFBA00   Wikipedia      Sepia   sepia    #704214   Crayola      Sepia Brown   sepiabrown    #49392D   RAL      Shadow   shadow    #8A795D   Crayola      Shadow Blue   shadowblue    #778BA5   Wikipedia      Shampoo   shampoo    #FFCFF1   Wikipedia      Shamrock   shamrock    #33CC99   Crayola      Shamrock Green   shamrockgreen    #009E60   Wikipedia      Shandy   shandy    #FFE670   Wikipedia      Sheen Green   sheengreen    #8FD400   Wikipedia      Shimmering Blush   shimmeringblush    #D98695   Wikipedia      Shiny Shamrock   shinyshamrock    #5FA778   Wikipedia      Shocking Pink   shockingpink    #FC0FC0   Wikipedia      Sienna   sienna    #A0522D   CSS      Signal Black   signalblack    #2E3032   RAL      Signal Blue   signalblue    #154889   RAL      Signal Brown   signalbrown    #7B5141   RAL      Signal Green   signalgreen    #0F8558   RAL      Signal Grey   signalgrey    #9EA0A1   RAL      Signal Orange   signalorange    #D4652F   RAL      Signal Red   signalred    #A02128   RAL      Signal Violet   signalviolet    #904684   RAL      Signal White   signalwhite    #F4F8F4   RAL      Signal Yellow   signalyellow    #F9A800   RAL      Silk Grey   silkgrey    #BDBDB2   RAL      Silver   silver    #C0C0C0   CSS      Silver Chalice   silverchalice    #ACACAC   Wikipedia      Silver Foil   silverfoil    #AFB1AE   Wikipedia      Silver Grey   silvergrey    #8F999F   RAL      Silver Lake Blue   silverlakeblue    #5D89BA   Wikipedia      Silver Pink   silverpink    #C4AEAD   Wikipedia      Silver Sand   silversand    #BFC1C2   Wikipedia      Sinopia   sinopia    #CB410B   Wikipedia      Sizzling Red   sizzlingred    #FF3855   Wikipedia      Sizzling Sunrise   sizzlingsunrise    #FFDB00   Wikipedia      Skobeloff   skobeloff    #007474   Wikipedia      Sky Blue   skyblue    #87CEEB   CSS      Sky Magenta   skymagenta    #CF71AF   Wikipedia      Slate Blue   slateblue    #6A5ACD   CSS      Slate Gray   slategray    #708090   CSS      Slate Grey   slategrey    #708090   CSS      Slategrey   slategrey    #708090   CSS      Slimy Green   slimygreen    #299617   Wikipedia      Smitten   smitten    #C84186   Wikipedia      Smoke   smoke    #738276   Wikipedia      Smokey Topaz   smokeytopaz    #832A0D   Wikipedia      Smoky Black   smokyblack    #100C08   Wikipedia      Snow   snow    #FFFAFA   CSS      Soap   soap    #CEC8EF   Wikipedia      Solid Pink   solidpink    #893843   Wikipedia      Sonic Silver   sonicsilver    #757575   Wikipedia      Space Cadet   spacecadet    #1D2951   Wikipedia      Spanish Bistre   spanishbistre    #807532   Wikipedia      Spanish Blue   spanishblue    #0070B8   Wikipedia      Spanish Carmine   spanishcarmine    #D10047   Wikipedia      Spanish Crimson   spanishcrimson    #E51A4C   Wikipedia      Spanish Gray   spanishgray    #989898   Wikipedia      Spanish Green   spanishgreen    #009150   Wikipedia      Spanish Orange   spanishorange    #E86100   Wikipedia      Spanish Pink   spanishpink    #F7BFBE   Wikipedia      Spanish Purple   spanishpurple    #66033C   Wikipedia      Spanish Red   spanishred    #E60026   Wikipedia      Spanish Sky Blue   spanishskyblue    #00FFFE   Wikipedia      Spanish Violet   spanishviolet    #4C2882   Wikipedia      Spanish Viridian   spanishviridian    #007F5C   Wikipedia      Spanish Yellow   spanishyellow    #F6B511   Wikipedia      Spartan Crimson   spartancrimson    #9E1316   Wikipedia      Spicy Mix   spicymix    #8B5f4D   Wikipedia      Spring Bud   springbud    #A7FC00   Wikipedia      Spring Frost   springfrost    #87FF2A   Wikipedia      Spring Green   springgreen    #00FF7F   CSS      Squirrel Grey   squirrelgrey    #7E8B92   RAL      St. Patrick's Blue   stpatricksblue    #23297A   Wikipedia      Star Command Blue   starcommandblue    #007BB8   Wikipedia      Steel Blue   steelblue    #4682B4   CSS      Steel Pink   steelpink    #CC33CC   Wikipedia      Steel Teal   steelteal    #5F8A8F   Wikipedia      Stil De Grain Yellow   stildegrainyellow    #FADA5E   Wikipedia      Stone Grey   stonegrey    #939388   RAL      Stop Red   stopred    #CF142B   Wikipedia      Straw   straw    #E4D96F   Wikipedia      Strawberry   strawberry    #FA5053   Wikipedia      Strawberry Blonde   strawberryblonde    #FF9361   Wikipedia      Strawberry Iced Tea   strawberryicedtea    #FC5A8D   Wikipedia      Strawberry Red   strawberryred    #D14152   RAL      Strong Lime Green   stronglimegreen    #33CC33   Wikipedia      Sugar Plum   sugarplum    #914E75   Wikipedia      Sulfur Yellow   sulfuryellow    #F1DD38   RAL      Sun Yellow   sunyellow    #F09200   RAL      Sunglow   sunglow    #FFCC33   Wikipedia      Sunray   sunray    #E3AB57   Wikipedia      Sunset   sunset    #FAD6A5   Wikipedia      Sunset Orange   sunsetorange    #FE4C40   Crayola      Super Pink   superpink    #CF6BA9   Wikipedia      Sweet Brown   sweetbrown    #A83731   Wikipedia      Syracuse Orange   syracuseorange    #D44500   Wikipedia      Tan   tan    #D2B48C   CSS      Tangelo   tangelo    #F94D00   Wikipedia      Tangerine   tangerine    #F28500   Wikipedia      Tangerine Yellow   tangerineyellow    #FFCC00   Wikipedia      Tango Pink   tangopink    #E4717A   Wikipedia      Tarpaulin Grey   tarpaulingrey    #575D57   RAL      Tart Orange   tartorange    #FB4D46   Wikipedia      Taupe   taupe    #483C32   Wikipedia      Taupe Gray   taupegray    #8B8589   Wikipedia      Tawny   tawny    #CD5700   Wikipedia      Tea Green   teagreen    #D0F0C0   Wikipedia      Tea Rose   tearose    #F4C2C2   Wikipedia      Teal   teal    #008080   CSS      Teal Blue   tealblue    #367588   Crayola      Teal Deer   tealdeer    #99E6B3   Wikipedia      Teal Green   tealgreen    #00827F   Wikipedia      Technobotanica   technobotanica    #00FFBF   Wikipedia      Telegrey 1   telegreyone    #91969A   RAL      Telegrey 2   telegreytwo    #82898E   RAL      Telegrey 4   telegreyfour    #CFD0CF   RAL      Telemagenta   telemagenta    #CF3476   RAL      Temptress   temptress    #3C2126   Wikipedia      Tenné   tenne    #CD5700   Wikipedia      Terra Brown   terrabrown    #4E3B2B   RAL      Terra Cotta   terracotta    #E2725B   Wikipedia      Thistle   thistle    #D8BFD8   CSS      Thulian Pink   thulianpink    #DE6FA1   Wikipedia      Tickle Me Pink   ticklemepink    #FC89AC   Crayola      Tiffany Blue   tiffanyblue    #0ABAB5   Wikipedia      Tiger's Eye   tigerseye    #E08D3C   Wikipedia      Timberwolf   timberwolf    #DBD7D2   Crayola      Titanium   titanium    #878681   Wikipedia      Titanium Yellow   titaniumyellow    #EEE600   Wikipedia      Tomato   tomato    #FF6347   CSS      Tomato Red   tomatored    #9C322E   RAL      Tomato Sauce   tomatosauce    #B21807   Wikipedia      Tooth   tooth    #FFFAFA   Wikipedia      Topaz   topaz    #FFC87C   Wikipedia      Tourmaline   tourmaline    #86A1A9   Wikipedia      Tractor Red   tractorred    #FD0E35   Wikipedia      Traffic Black   trafficblack    #2A2D2F   RAL      Traffic Blue   trafficblue    #0E518D   RAL      Traffic Green   trafficgreen    #008754   RAL      Traffic Grey A   trafficgreya    #8F9695   RAL      Traffic Grey B   trafficgreyb    #4E5451   RAL      Traffic Orange   trafficorange    #E15501   RAL      Traffic Purple   trafficpurple    #992572   RAL      Traffic Red   trafficred    #C1121C   RAL      Traffic White   trafficwhite    #F7FBF5   RAL      Traffic Yellow   trafficyellow    #F7B500   RAL      Trolley Grey   trolleygrey    #808080   Wikipedia      Tropical Rainforest   tropicalrainforest    #00755E   Crayola      True Blue   trueblue    #2D68C4   Wikipedia      Trypan Blue   trypanblue    #1C05B3   Wikipedia      Tufts Blue   tuftsblue    #3E8EDE   Wikipedia      Tulip   tulip    #FF878D   Wikipedia      Tumbleweed   tumbleweed    #DEAA88   Crayola      Turkish Rose   turkishrose    #B57281   Wikipedia      Turquoise   turquoise    #40E0D0   CSS      Turquoise Blue   turquoiseblue    #00FFEF   RAL      Turquoise Green   turquoisegreen    #A0D6B4   RAL      Turtle Green   turtlegreen    #8A9A5B   Wikipedia      Tuscan   tuscan    #FAD6A5   Wikipedia      Tuscan Brown   tuscanbrown    #6F4E37   Wikipedia      Tuscan Red   tuscanred    #7C4848   Wikipedia      Tuscan Tan   tuscantan    #A67B5B   Wikipedia      Tuscany   tuscany    #C09999   Wikipedia      Twilight Lavender   twilightlavender    #8A496B   Wikipedia      Twitter Blue   twitterblue    #26A7DE   Wikipedia      Tyrian Purple   tyrianpurple    #66023C   Wikipedia      UA Blue   uablue    #0033AA   Wikipedia      UA Red   uared    #D9004C   Wikipedia      Ultra Pink   ultrapink    #FF6FFF   Wikipedia      Ultra Red   ultrared    #FC6C85   Wikipedia      Ultramarine   ultramarine    #3F00FF   Wikipedia      Ultramarine Blue   ultramarineblue    #4166F5   RAL      Umber   umber    #635147   Wikipedia      Umbra Grey   umbragrey    #4B4D46   RAL      Unbleached Silk   unbleachedsilk    #FFDDCA   Wikipedia      United Nations Blue   unitednationsblue    #009EDB   Wikipedia      University Of Pennsylvania Red   universityofpennsylvaniared    #A50021   Wikipedia      Unmellow Yellow   unmellowyellow    #FFFF66   Wikipedia      UP Forest Green   upforestgreen    #014421   Wikipedia      UP Maroon   upmaroon    #7B1113   Wikipedia      UPS Brown   upsbrown    #644117   Wikipedia      Upsdell Red   upsdellred    #AE2029   Wikipedia      Uranian Blue   uranianblue    #AFDBF5   Wikipedia      Urobilin   urobilin    #E1AD21   Wikipedia      USAFA Blue   usafablue    #004F98   Wikipedia      Van Dyke Brown   vandykebrown    #664228   Crayola      Vanilla   vanilla    #F3E5AB   Wikipedia      Vanilla Ice   vanillaice    #F38FA9   Wikipedia      Vegas Gold   vegasgold    #C5B358   Wikipedia      Venetian Red   venetianred    #C80815   Crayola      Verdigris   verdigris    #43B3AE   Wikipedia      Vermilion   vermilion    #E34234   RAL      Veronica   veronica    #A020F0   Wikipedia      Very Light Azure   verylightazure    #74BBFB   Wikipedia      Very Light Blue   verylightblue    #6666FF   Wikipedia      Very Light Malachite Green   verylightmalachitegreen    #64E986   Wikipedia      Very Light Tangelo   verylighttangelo    #FFB077   Wikipedia      Very Pale Orange   verypaleorange    #FFDFBF   Wikipedia      Very Pale Yellow   verypaleyellow    #FFFFBF   Wikipedia      Vine Green   vinegreen    #164010   Wikipedia      Violet   violet    #EE82EE   CSS      Violet-blue   violetblue    #324AB2   RAL      Violet-red   violetred    #F75394   Crayola      Violin Brown   violinbrown    #674403   Wikipedia      Viridian   viridian    #40826D   Wikipedia      Viridian Green   viridiangreen    #009698   Wikipedia      Vista Blue   vistablue    #7C9ED9   Wikipedia      Vivid Amber   vividamber    #cc9900   Wikipedia      Vivid Auburn   vividauburn    #922724   Wikipedia      Vivid Burgundy   vividburgundy    #9F1D35   Wikipedia      Vivid Cerise   vividcerise    #DA1D81   Wikipedia      Vivid Cerulean   vividcerulean    #00AAEE   Wikipedia      Vivid Crimson   vividcrimson    #CC0033   Wikipedia      Vivid Gamboge   vividgamboge    #FF9900   Wikipedia      Vivid Lime Green   vividlimegreen    #a6d608   Wikipedia      Vivid Mulberry   vividmulberry    #B80CE3   Wikipedia      Vivid Orange   vividorange    #FF5F00   Wikipedia      Vivid Orange Peel   vividorangepeel    #FFA000   Wikipedia      Vivid Orchid   vividorchid    #CC00FF   Wikipedia      Vivid Raspberry   vividraspberry    #FF006C   Wikipedia      Vivid Red   vividred    #F70D1A   Wikipedia      Vivid Red-tangelo   vividredtangelo    #DF6124   Wikipedia      Vivid Sky Blue   vividskyblue    #00CCFF   Wikipedia      Vivid Tangelo   vividtangelo    #F07427   Wikipedia      Vivid Tangerine   vividtangerine    #FFA089   Crayola      Vivid Vermilion   vividvermilion    #e56024   Wikipedia      Vivid Violet   vividviolet    #9F00FF   Crayola      Vivid Yellow   vividyellow    #FFE302   Wikipedia      Volt   volt    #CEFF00   Wikipedia      Warm Black   warmblack    #004242   Wikipedia      Water   water    #D4F1F9   Wikipedia      Water Blue   waterblue    #07737A   RAL      Watermelon   watermelon    #F05C85   Wikipedia      Watermelon Red   watermelonred    #BF4147   Wikipedia      Watermelon Yellow   watermelonyellow    #EEFF1B   Wikipedia      Waterspout   waterspout    #A4F4F9   Wikipedia      Weezy Blue   weezyblue    #189BCC   Wikipedia      Wenge   wenge    #645452   Wikipedia      Wheat   wheat    #F5DEB3   CSS      White   white    #FFFFFF   CSS      White Aluminium   whitealuminium    #A5A8A6   RAL      White Chocolate   whitechocolate    #EDE6D6   Wikipedia      White Coffee   whitecoffee    #E6E0D4   Wikipedia      White Smoke   whitesmoke    #F5F5F5   CSS      Wild Blue Yonder   wildblueyonder    #A2ADD0   Wikipedia      Wild Orchid   wildorchid    #D470A2   Wikipedia      Wild Strawberry   wildstrawberry    #FF43A4   Crayola      Wild Watermelon   wildwatermelon    #FC6C85   Wikipedia      Willpower Orange   willpowerorange    #FD5800   Wikipedia      Window Grey   windowgrey    #9DA3A6   RAL      Windsor Tan   windsortan    #A75502   Wikipedia      Wine   wine    #722F37   Wikipedia      Wine Dregs   winedregs    #673147   Wikipedia      Wine Red   winered    #5E2028   RAL      Winter Sky   wintersky    #FF007C   Wikipedia      Wintergreen Dream   wintergreendream    #56887D   Wikipedia      Wisteria   wisteria    #C9A0DC   Crayola      Wood Brown   woodbrown    #C19A6B   Wikipedia      Xanadu   xanadu    #738678   Wikipedia      Xanthic   xanthic    #EEED09   Wikipedia      Xanthous   xanthous    #F1B42F   Wikipedia      Yale Blue   yaleblue    #00356B   Wikipedia      Yellow   yellow    #FFFF00   CSS      Yellow Green   yellowgreen    #9ACD32   CSS      Yellow Grey   yellowgrey    #939176   RAL      Yellow Olive   yellowolive    #444337   RAL      Yellow Orange   yelloworange    #FFAE42   RAL      Yellow Rose   yellowrose    #FFF000   Wikipedia      Yellow Sunshine   yellowsunshine    #FFF700   Wikipedia      Yellow-green   yellowgreen    #9ACD32   CSS      YInMn Blue   yinmnblue    #2E5090   Wikipedia      Zaffre   zaffre    #0014A8   Wikipedia      Zebra White   zebrawhite    #F5F5F5   Wikipedia      Zinc Yellow   zincyellow    #FACA30   RAL      Zinnwaldite   zinnwaldite    #2C1608   Wikipedia      Zinnwaldite Brown   zinnwalditebrown    #2C1608   Wikipedia      Zomp   zomp    #39A78E   Wikipedia","ref":"namedcolors.html#a-z"},{"type":"extras","title":"Hue - Named Colors","doc":"Name \n         Keyword \n         RGB hex value \n         Source \n         Sample \n       \n     \n     \n        Dark Sienna   darksienna    #3C1414   Wikipedia      Oxblood   oxblood    #4A0000   Wikipedia      Philippine Brown   philippinebrown    #5D1916   Wikipedia      Blood Red   bloodred    #660000   Wikipedia      Grey Brown   greybrown    #3F3A3A   RAL      Persian Plum   persianplum    #701C1C   Wikipedia      Prune   prune    #701C1C   Wikipedia      Maroon   maroon    #800000   CSS      Falu Red   falured    #801818   Wikipedia      Dark Red   darkred    #8B0000   CSS      Garnet   garnet    #733635   Wikipedia      Roast Coffee   roastcoffee    #704241   Wikipedia      Vivid Auburn   vividauburn    #922724   Wikipedia      Tuscan Red   tuscanred    #7C4848   Wikipedia      Tomato Red   tomatored    #9C322E   RAL      Brown   brown    #A52A2A   CSS      Flame Red   flamered    #AB2524   RAL      Metallic Red   metallicred    #A62C2B   Wikipedia      Carnelian   carnelian    #B31B1B   Wikipedia      Firebrick   firebrick    #B22222   CSS      Rose Taupe   rosetaupe    #905D5D   Wikipedia      Middle Red Purple   middleredpurple    #A55353   Crayola      Rosso Corsa   rossocorsa    #D40000   Wikipedia      Persian Red   persianred    #CC3333   Wikipedia      Copper Rose   copperrose    #996666   Wikipedia      Maximum Red   maximumred    #D92121   Crayola      Permanent Geranium Lake   permanentgeraniumlake    #E12C2C   Crayola      Lust   lust    #E62020   Wikipedia      Luminous Red   luminousred    #F70000   RAL      Indian Red   indianred    #CD5C5C   CSS      Luminous Bright Red   luminousbrightred    #FF0000   RAL      Red   red    #FF0000   CSS      Candy Apple Red   candyapplered    #FF0800   Wikipedia      Neon Red   neonred    #FF1818   Wikipedia      Tart Orange   tartorange    #FB4D46   Wikipedia      Rosy Brown   rosybrown    #BC8F8F   CSS      New York Pink   newyorkpink    #D7837F   Wikipedia      Tuscany   tuscany    #C09999   Wikipedia      Light Coral   lightcoral    #F08080   CSS      Lightcoral   lightcoral    #F08080   CSS      Silver Pink   silverpink    #C4AEAD   Wikipedia      Pastel Pink   pastelpink    #DEA5A4   Wikipedia      Light Salmon Pink   lightsalmonpink    #FF9999   Wikipedia      Spanish Pink   spanishpink    #F7BFBE   Wikipedia      Baby Pink   babypink    #F4C2C2   Wikipedia      Tea Rose   tearose    #F4C2C2   Wikipedia      Lotion Pink   lotionpink    #ECCFCF   Wikipedia      Light Red   lightred    #FFCCCB   Wikipedia      Petal   petal    #F5E2E2   Wikipedia      Snow   snow    #FFFAFA   CSS      Tooth   tooth    #FFFAFA   Wikipedia      Licorice   licorice    #1A1110   Wikipedia      Old Burgundy   oldburgundy    #43302E   Wikipedia      Barn Red   barnred    #7C0A02   Wikipedia      Chestnut Brown   chestnutbrown    #633A34   RAL      Red Brown   redbrown    #673831   RAL      Oxide Red   oxidered    #703731   RAL      Rose Ebony   roseebony    #674846   Wikipedia      Burnt Umber   burntumber    #8A3324   Crayola      Bole   bole    #79443B   Wikipedia      Medium Tuscan Red   mediumtuscanred    #79443B   Wikipedia      Wenge   wenge    #645452   Wikipedia      Rojo Spanish Red   rojospanishred    #A91101   Wikipedia      Rufous   rufous    #A81C07   Wikipedia      Mordant Red 19   mordantred    #AE0C00   Wikipedia      Tomato Sauce   tomatosauce    #B21807   Wikipedia      Sweet Brown   sweetbrown    #A83731   Wikipedia      International Orange   internationalorange    #BA160C   Wikipedia      Coral Red   coralred    #AC4034   RAL      Medium Carmine   mediumcarmine    #AF4035   Wikipedia      Pale Carmine   palecarmine    #AF4035   Wikipedia      Pearl Pink   pearlpink    #B24C43   RAL      Redwood   redwood    #A45A52   Wikipedia      Deep Chestnut   deepchestnut    #B94E48   Wikipedia      Pure Red   purered    #E72512   RAL      Cedar Chest   cedarchest    #C95A49   Wikipedia      Copper Penny   copperpenny    #AD6F69   Wikipedia      Chili Red   chilired    #E23D28   Wikipedia      Burnished Brown   burnishedbrown    #A17A74   Wikipedia      Cinnabar   cinnabar    #E34234   Wikipedia      Vermilion   vermilion    #E34234   RAL      Luminous Orange   luminousorange    #FF2300   RAL      Neon Scarlet   neonscarlet    #FF2603   Wikipedia      Scarlet   scarlet    #FF2400   Crayola      Fire Opal   fireopal    #E95C4B   Wikipedia      Sunset Orange   sunsetorange    #FE4C40   Crayola      Red-orange   redorange    #FF5349   RAL      Pastel Red   pastelred    #FF6961   Wikipedia      Bittersweet   bittersweet    #FE6F5E   Crayola      Salmon   salmon    #FA8072   CSS      Congo Pink   congopink    #F88379   Wikipedia      Coral Pink   coralpink    #F88379   Wikipedia      Salmon Rose   salmonrose    #E7968B   Wikipedia      Mona Lisa   monalisa    #FF948E   Wikipedia      Misty Rose   mistyrose    #FFE4E1   CSS      Mistyrose   mistyrose    #FFE4E1   CSS      Black Bean   blackbean    #3D0C02   Wikipedia      Chocolate Brown   chocolatebrown    #44322D   RAL      Mahogany Brown   mahoganybrown    #4C2F26   RAL      Royal Brown   royalbrown    #523B35   Wikipedia      Dark Liver   darkliver    #543D37   Wikipedia      Smokey Topaz   smokeytopaz    #832A0D   Wikipedia      Kobe   kobe    #882D17   Wikipedia      Liver   liver    #674C47   Wikipedia      Medium Taupe   mediumtaupe    #674C47   Wikipedia      Chestnut   chestnut    #954535   Crayola      Chinese Red   chinesered    #AA381E   Wikipedia      Rum   rum    #9A4E40   Wikipedia      Dark Venetian Red   darkvenetianred    #B33B24   Crayola      Blast-off Bronze   blastoffbronze    #A57164   Wikipedia      Cinereous   cinereous    #98817B   Wikipedia      Medium Vermilion   mediumvermilion    #D9603B   Wikipedia      Copper Red   copperred    #CB6D51   Wikipedia      Microsoft Red   microsoftred    #F04E1F   Wikipedia      Coquelicot   coquelicot    #FF3800   Wikipedia      Salmon Orange   salmonorange    #DB6A50   RAL      Terra Cotta   terracotta    #E2725B   Wikipedia      Orange Soda   orangesoda    #FA5B3D   Wikipedia      Light Venetian Red   lightvenetianred    #E6735C   Crayola      Portland Orange   portlandorange    #FF5A36   Wikipedia      Burnt Sienna   burntsienna    #E97451   Crayola      Light Red Ochre   lightredochre    #E97451   Wikipedia      Tomato   tomato    #FF6347   CSS      Outrageous Orange   outrageousorange    #FF6E4A   Wikipedia      Middle Red   middlered    #E58E73   Crayola      Pink Sherbert   pinksherbert    #F7A38E   Crayola      Vivid Tangerine   vividtangerine    #FFA089   Crayola      Melon   melon    #FEBAAD   Crayola      Root Beer   rootbeer    #290E05   Wikipedia      Seal Brown   sealbrown    #59260B   Wikipedia      Nut Brown   nutbrown    #5A3A29   RAL      Pearl Copper   pearlcopper    #773C27   RAL      Fuzzy Wuzzy   fuzzywuzzy    #87421F   Crayola      Signal Brown   signalbrown    #7B5141   RAL      Pearl Orange   pearlorange    #954527   RAL      Copper Brown   copperbrown    #8F4E35   RAL      Metallic Brown   metallicbrown    #AC4313   Wikipedia      Spicy Mix   spicymix    #8B5f4D   Wikipedia      Coconut   coconut    #965A3E   Wikipedia      Sienna   sienna    #A0522D   CSS      Lemon Iced Tea   lemonicedtea    #BD3000   Wikipedia      Rust   rust    #B7410E   Wikipedia      Mahogany   mahogany    #C04000   Crayola      Sinopia   sinopia    #CB410B   Wikipedia      Syracuse Orange   syracuseorange    #D44500   Wikipedia      Brown Sugar   brownsugar    #AF6E4D   Wikipedia      Signal Orange   signalorange    #D4652F   RAL      Flame   flame    #E25822   Wikipedia      Vivid Red-tangelo   vividredtangelo    #DF6124   Wikipedia      Pure Orange   pureorange    #E75B12   RAL      RAL Orange   ralorange    #FA4402   RAL      Vivid Vermilion   vividvermilion    #e56024   Wikipedia      Tangelo   tangelo    #F94D00   Wikipedia      Orange Red   orangered    #FF4500   CSS      Orioles Orange   oriolesorange    #FB4F14   Wikipedia      Mystic Red   mysticred    #FF5500   Wikipedia      Willpower Orange   willpowerorange    #FD5800   Wikipedia      Beige Red   beigered    #CB8D73   RAL      Pale Copper   palecopper    #DA8A67   Wikipedia      Mandarin   mandarin    #F37A48   Wikipedia      Coral   coral    #FF7F50   CSS      Mango Tango   mangotango    #FF8243   Crayola      Dark Salmon   darksalmon    #E9967A   CSS      Strawberry Blonde   strawberryblonde    #FF9361   Wikipedia      Atomic Tangerine   atomictangerine    #FF9966   Wikipedia      Light Salmon   lightsalmon    #FFA07A   CSS      Lightsalmon   lightsalmon    #FFA07A   CSS      Zinnwaldite   zinnwaldite    #2C1608   Wikipedia      Zinnwaldite Brown   zinnwalditebrown    #2C1608   Wikipedia      Bistre   bistre    #3D2B1F   Wikipedia      Sepia Brown   sepiabrown    #49392D   RAL      Van Dyke Brown   vandykebrown    #664228   Crayola      Fawn Brown   fawnbrown    #6F4A2F   RAL      Umber   umber    #635147   Wikipedia      Coffee   coffee    #6F4E37   Wikipedia      Tuscan Brown   tuscanbrown    #6F4E37   Wikipedia      Russet   russet    #80461B   Wikipedia      Quincy   quincy    #6A5445   Wikipedia      Mud   mud    #70543E   Wikipedia      Saddle Brown   saddlebrown    #8B4513   CSS      Beige Brown   beigebrown    #79553C   RAL      Pale Brown   palebrown    #755C49   RAL      Milk Chocolate   milkchocolate    #84563C   Wikipedia      Orange Brown   orangebrown    #A65E2F   RAL      Burnt Orange   burntorange    #CC5500   Crayola      Tawny   tawny    #CD5700   Wikipedia      Tenné   tenne    #CD5700   Wikipedia      Café Au Lait   cafeaulait    #A67B5B   Wikipedia      French Beige   frenchbeige    #A67B5B   Wikipedia      Tuscan Tan   tuscantan    #A67B5B   Wikipedia      Beaver   beaver    #9F8170   Crayola      Traffic Orange   trafficorange    #E15501   RAL      Chocolate   chocolate    #D2691E   CSS      Cocoa Brown   cocoabrown    #D2691E   Wikipedia      Metallic Orange   metallicorange    #DA680F   Wikipedia      Persimmon   persimmon    #EC5800   Wikipedia      Spanish Orange   spanishorange    #E86100   Wikipedia      Antique Brass   antiquebrass    #C88A65   Crayola      Maximum Orange   maximumorange    #FF5B00   Wikipedia      Vivid Orange   vividorange    #FF5F00   Wikipedia      Vivid Tangelo   vividtangelo    #F07427   Wikipedia      Orange Iced Tea   orangeicedtea    #FF6700   Wikipedia      Bright Red Orange   brightredorange    #F3752C   RAL      Deep Orange   deeporange    #EC7C25   RAL      Pale Taupe   paletaupe    #BC987E   Wikipedia      Raw Sienna   rawsienna    #D68A59   Crayola      Persian Orange   persianorange    #D99058   Wikipedia      Princeton Orange   princetonorange    #F58025   Wikipedia      Pumpkin   pumpkin    #FF7518   Wikipedia      Big Foot Feet   bigfootfeet    #E88E5A   Wikipedia      Mocha   mocha    #BEA493   Wikipedia      Pastel Orange   pastelorange    #FA842B   RAL      Royal Orange   royalorange    #F99245   Wikipedia      Tumbleweed   tumbleweed    #DEAA88   Crayola      Pale Silver   palesilver    #C9C0BB   Wikipedia      Very Light Tangelo   verylighttangelo    #FFB077   Wikipedia      Macaroni And Cheese   macaroniandcheese    #FFBD88   Crayola      Desert Sand   desertsand    #EDC9AF   Crayola      Apricot   apricot    #FBCEB1   Crayola      Champagne Pink   champagnepink    #F1DDCF   Wikipedia      Unbleached Silk   unbleachedsilk    #FFDDCA   Wikipedia      Seashell   seashell    #FFF5EE   CSS      Smoky Black   smokyblack    #100C08   Wikipedia      Café Noir   cafenoir    #4B3621   Wikipedia      Dark Lava   darklava    #483C32   Wikipedia      Taupe   taupe    #483C32   Wikipedia      Terra Brown   terrabrown    #4E3B2B   RAL      Pullman Brown   pullmanbrown    #644117   Wikipedia      UPS Brown   upsbrown    #644117   Wikipedia      Philippine Bronze   philippinebronze    #6E3A07   Wikipedia      Dark Brown   darkbrown    #654321   Wikipedia      Otter Brown   otterbrown    #654321   Wikipedia      Kobicha   kobicha    #6B4423   Wikipedia      Sepia   sepia    #704214   Crayola      Olive Brown   olivebrown    #6F4F28   RAL      Clay Brown   claybrown    #80542F   RAL      Coyote Brown   coyotebrown    #81613C   Wikipedia      Charcoal Gray   charcoalgray    #736A62   Crayola      Raw Umber   rawumber    #826644   Crayola      Pastel Brown   pastelbrown    #836953   Wikipedia      Windsor Tan   windsortan    #A75502   Wikipedia      Ochre Brown   ochrebrown    #9C6B30   RAL      Liver Chestnut   liverchestnut    #987456   Wikipedia      Light Brown   lightbrown    #B5651D   Wikipedia      Dirt   dirt    #9B7653   Wikipedia      Metallic Bronze   metallicbronze    #A97142   Wikipedia      Alloy Orange   alloyorange    #C46210   Wikipedia      Copper   copper    #B87333   Crayola      Middle Grey   middlegrey    #8B8680   Wikipedia      Neon Brown   neonbrown    #C3732A   Wikipedia      Brown Beige   brownbeige    #AF804F   RAL      Ochre   ochre    #CC7722   Wikipedia      Grey Beige   greybeige    #A48F7A   RAL      Bronze   bronze    #CD7F32   Wikipedia      Peru   peru    #CD853F   CSS      Camel   camel    #C19A6B   Wikipedia      Desert   desert    #C19A6B   Wikipedia      Fallow   fallow    #C19A6B   Wikipedia      Wood Brown   woodbrown    #C19A6B   Wikipedia      Philippine Orange   philippineorange    #FF7300   Wikipedia      Tiger's Eye   tigerseye    #E08D3C   Wikipedia      Cadmium Orange   cadmiumorange    #ED872D   Wikipedia      Medium Orange   mediumorange    #FF7802   Wikipedia      Safety Orange   safetyorange    #FF7800   Wikipedia      Tangerine   tangerine    #F28500   Wikipedia      Heat Wave   heatwave    #FF7A00   Wikipedia      Carrot Orange   carrotorange    #ED9121   Wikipedia      Neon Tangerine   neontangerine    #F6890A   Wikipedia      Dark Orange   darkorange    #FF8C00   CSS      Pastel Yellow   pastelyellow    #EB9C52   RAL      Deep Saffron   deepsaffron    #FF9933   Wikipedia      Fawn   fawn    #E5AA70   Wikipedia      Sandy Brown   sandybrown    #F4A460   CSS      Saffron Yellow   saffronyellow    #F6A950   RAL      Middle Yellow Red   middleyellowred    #ECB176   Crayola      Rajah   rajah    #FBAB60   Wikipedia      Dark Vanilla   darkvanilla    #D1BEA8   Wikipedia      Mellow Apricot   mellowapricot    #F8B878   Wikipedia      Almond   almond    #EED9C4   Crayola      Light Orange   lightorange    #FED8B1   Wikipedia      Peach Puff   peachpuff    #FFDAB9   CSS      Peachpuff   peachpuff    #FFDAB9   CSS      Very Pale Orange   verypaleorange    #FFDFBF   Wikipedia      Bisque   bisque    #FFE4C4   CSS      Lumber   lumber    #FFE4CD   Wikipedia      Isabelline   isabelline    #F4F0EC   Wikipedia      Linen   linen    #FAF0E6   CSS      Pineapple   pineapple    #563C0D   Wikipedia      Violin Brown   violinbrown    #674403   Wikipedia      Pearl Gold   pearlgold    #80643F   RAL      French Bistre   frenchbistre    #856D4D   Wikipedia      Golden Brown   goldenbrown    #996515   Wikipedia      Shadow   shadow    #8A795D   Crayola      Pearl Mouse Grey   pearlmousegrey    #888175   RAL      Philippine Gold   philippinegold    #B17304   Wikipedia      Pearl Beige   pearlbeige    #908370   RAL      Mustard Brown   mustardbrown    #CD7A00   Wikipedia      Ochre Yellow   ochreyellow    #BA8F4C   RAL      Grullo   grullo    #A99A86   Wikipedia      Aztec Gold   aztecgold    #C39953   Wikipedia      Fulvous   fulvous    #E48400   Wikipedia      Daffodil Yellow   daffodilyellow    #E88C00   RAL      Maize Yellow   maizeyellow    #E29000   RAL      Sun Yellow   sunyellow    #F09200   RAL      Light French Beige   lightfrenchbeige    #C8AD7F   Wikipedia      Sand Yellow   sandyellow    #D2AA6D   RAL      Marigold   marigold    #EAA221   Wikipedia      Dahlia Yellow   dahliayellow    #F99A1C   RAL      Earth Yellow   earthyellow    #E1A95F   Wikipedia      Indian Yellow   indianyellow    #E3A857   Wikipedia      Vivid Gamboge   vividgamboge    #FF9900   Wikipedia      Melon Yellow   melonyellow    #FF9B00   RAL      Sunray   sunray    #E3AB57   Wikipedia      Orange Peel   orangepeel    #FF9F00   Wikipedia      Tan   tan    #D2B48C   CSS      Vivid Orange Peel   vividorangepeel    #FFA000   Wikipedia      Luminous Bright Orange   luminousbrightorange    #FFA421   RAL      Orange   orange    #FFA500   CSS      Bright Yellow   brightyellow    #FFAA1D   Wikipedia      Burlywood   burlywood    #DEB887   CSS      Yellow Orange   yelloworange    #FFAE42   RAL      Pale Gold   palegold    #E6BE8A   Wikipedia      Buff   buff    #FFC680   Wikipedia      Topaz   topaz    #FFC87C   Wikipedia      Light Ivory   lightivory    #E6D2B5   RAL      Timberwolf   timberwolf    #DBD7D2   Crayola      Deep Champagne   deepchampagne    #FAD6A5   Wikipedia      Sunset   sunset    #FAD6A5   Wikipedia      Tuscan   tuscan    #FAD6A5   Wikipedia      Navajo White   navajowhite    #FFDEAD   CSS      Moccasin   moccasin    #FFE4B5   CSS      Champagne   champagne    #F7E7CE   Wikipedia      Magnolia   magnolia    #F2E8D7   Wikipedia      Antique White   antiquewhite    #FAEBD7   CSS      Blanched Almond   blanchedalmond    #FFEBCD   CSS      Papaya Whip   papayawhip    #FFEFD5   CSS      Drab Dark Brown   drabdarkbrown    #4A412A   Wikipedia      Field Drab   fielddrab    #6C541E   Wikipedia      Khaki Grey   khakigrey    #746643   RAL      Beige Grey   beigegrey    #756F61   RAL      Green Brown   greenbrown    #887142   RAL      Gold Fusion   goldfusion    #85754E   Wikipedia      Bistre Brown   bistrebrown    #967117   Wikipedia      Mode Beige   modebeige    #967117   Wikipedia      Sand Dune   sanddune    #967117   Wikipedia      Sandy Taupe   sandytaupe    #967117   Wikipedia      Metallic Sunburst   metallicsunburst    #9C7C38   Wikipedia      Curry   curry    #A77F0E   RAL      Dark Goldenrod   darkgoldenrod    #B8860B   CSS      Olive Yellow   oliveyellow    #A08F65   RAL      Honey Yellow   honeyyellow    #CB8E00   RAL      Vivid Amber   vividamber    #cc9900   Wikipedia      Harvest Gold   harvestgold    #DA9100   Wikipedia      Lemon Curry   lemoncurry    #CCA01D   Wikipedia      Satin Sheen Gold   satinsheengold    #CBA135   Wikipedia      Gamboge   gamboge    #E49B0F   Wikipedia      Goldenrod   goldenrod    #DAA520   CSS      Broom Yellow   broomyellow    #E2A300   RAL      Urobilin   urobilin    #E1AD21   Wikipedia      Green Beige   greenbeige    #CDBA88   RAL      Signal Yellow   signalyellow    #F9A800   RAL      Xanthous   xanthous    #F1B42F   Wikipedia      Lanzones   lanzones    #E0BC5B   Wikipedia      Spanish Yellow   spanishyellow    #F6B511   Wikipedia      Colza Yellow   colzayellow    #F6B600   RAL      Traffic Yellow   trafficyellow    #F7B500   RAL      Chinese Yellow   chineseyellow    #FFB200   Wikipedia      Maximum Yellow Red   maximumyellowred    #F2BA49   Crayola      Microsoft Yellow   microsoftyellow    #FDB900   Wikipedia      Orange-yellow   orangeyellow    #F5BD1F   Crayola      Selective Yellow   selectiveyellow    #FFBA00   Wikipedia      Mango   mango    #FDBE02   Wikipedia      Amber   amber    #FFBF00   Wikipedia      Lion   lion    #DECC9C   Wikipedia      Ripe Mango   ripemango    #FFC324   Wikipedia      Oyster White   oysterwhite    #E3D9C6   RAL      Bone   bone    #E3DAC9   Wikipedia      Dutch White   dutchwhite    #EFDFBB   Wikipedia      Pearl   pearl    #EAE0C8   Wikipedia      White Coffee   whitecoffee    #E6E0D4   Wikipedia      Wheat   wheat    #F5DEB3   CSS      White Chocolate   whitechocolate    #EDE6D6   Wikipedia      Banana Mania   bananamania    #FAE7B5   Crayola      Peach   peach    #FFE5B4   Crayola      Parchment   parchment    #F1E9D2   Wikipedia      Old Lace   oldlace    #FDF5E6   CSS      Oldlace   oldlace    #FDF5E6   CSS      Cosmic Latte   cosmiclatte    #FFF8E7   Wikipedia      Floral White   floralwhite    #FFFAF0   CSS      Olive-drab/brown Olive   brownolive    #3E3C32   RAL      Quartz Grey   quartzgrey    #6B695F   RAL      Dark Tan   darktan    #918151   Wikipedia      Titanium   titanium    #878681   Wikipedia      Light Gold   lightgold    #B29700   Wikipedia      Neon Gold   neongold    #CFAA01   Wikipedia      Vegas Gold   vegasgold    #C5B358   Wikipedia      Ecru   ecru    #C2B280   Wikipedia      Metallic Gold   metallicgold    #D3AF37   Wikipedia      Sand   sand    #C2B280   Wikipedia      Old Gold   oldgold    #CFB53B   Wikipedia      Mustard Yellow   mustardyellow    #E1AD01   Wikipedia      Prairie Gold   prairiegold    #E1CA7A   Wikipedia      Saffron   saffron    #F4C430   Wikipedia      Deep Lemon   deeplemon    #F5C71A   Wikipedia      Golden Poppy   goldenpoppy    #FCC200   Wikipedia      Jonquil   jonquil    #F4CA16   Wikipedia      Mikado Yellow   mikadoyellow    #FFC40C   Wikipedia      Zinc Yellow   zincyellow    #FACA30   RAL      Metallic Yellow   metallicyellow    #FDCC0D   Wikipedia      Philippine Yellow   philippineyellow    #FECB00   Wikipedia      Tangerine Yellow   tangerineyellow    #FFCC00   Wikipedia      Sunglow   sunglow    #FFCC33   Wikipedia      Arylide Yellow   arylideyellow    #E9D66B   Wikipedia      Hansa Yellow   hansayellow    #E9D66B   Wikipedia      Crayellow   crayellow    #F1D651   Crayola      Cyber Yellow   cyberyellow    #FFD300   Wikipedia      Gold   gold    #FFD700   CSS      School Bus Yellow   schoolbusyellow    #FFD800   Wikipedia      Flax   flax    #EEDC82   Wikipedia      Dandelion   dandelion    #FED85D   Crayola      Naples Yellow   naplesyellow    #FADA5E   Wikipedia      Royal Yellow   royalyellow    #FADA5E   Wikipedia      Stil De Grain Yellow   stildegrainyellow    #FADA5E   Wikipedia      Mustard   mustard    #FFDB58   Wikipedia      Jasmine   jasmine    #F8DE7E   Wikipedia      Mellow Yellow   mellowyellow    #F8DE7E   Wikipedia      Medium Champagne   mediumchampagne    #F3E5AB   Wikipedia      Shandy   shandy    #FFE670   Wikipedia      Vanilla   vanilla    #F3E5AB   Wikipedia      Lemon Meringue   lemonmeringue    #F6EABE   Wikipedia      Eggshell   eggshell    #F0EAD6   Wikipedia      Alabaster   alabaster    #F2F0E6   Wikipedia      Cornsilk   cornsilk    #FFF8DC   CSS      Yellow Olive   yellowolive    #444337   RAL      Antique Bronze   antiquebronze    #665D1E   Wikipedia      Spanish Bistre   spanishbistre    #807532   Wikipedia      Old Moss Green   oldmossgreen    #867E36   Wikipedia      Olive Grey   olivegrey    #817F68   RAL      Yellow Grey   yellowgrey    #939176   RAL      Misty Moss   mistymoss    #BBB477   Wikipedia      Dark Khaki   darkkhaki    #BDB76B   CSS      Sage   sage    #BCB88A   Wikipedia      Citrine   citrine    #E4D00A   Wikipedia      Safety Yellow   safetyyellow    #EED202   Wikipedia      Straw   straw    #E4D96F   Wikipedia      Sulfur Yellow   sulfuryellow    #F1DD38   RAL      Sizzling Sunrise   sizzlingsunrise    #FFDB00   Wikipedia      Minion Yellow   minionyellow    #F5E050   Wikipedia      Golden Yellow   goldenyellow    #FFDF00   RAL      Philippine Golden Yellow   philippinegoldenyellow    #FFDF00   Wikipedia      Medium Yellow   mediumyellow    #FFE302   Wikipedia      Vivid Yellow   vividyellow    #FFE302   Wikipedia      Khaki   khaki    #F0E68C   CSS      Middle Yellow   middleyellow    #FFEB00   Crayola      Pale Goldenrod   palegoldenrod    #EEE8AA   CSS      Palegoldenrod   palegoldenrod    #EEE8AA   CSS      Aureolin   aureolin    #FDEE00   Wikipedia      Corn   corn    #FBEC5D   Wikipedia      Maize   maize    #FBEC5D   Crayola      Canary Yellow   canaryyellow    #FFEF00   Wikipedia      Yellow Rose   yellowrose    #FFF000   Wikipedia      Lemon Yellow   lemonyellow    #FFF44F   RAL      Lemon Chiffon   lemonchiffon    #FFFACD   CSS      Clean Room White   cleanroomwhite    #FFFDE6   RAL      Brown Grey   browngrey    #555548   RAL      Mustard Green   mustardgreen    #6E6E30   Wikipedia      Olive   olive    #808000   CSS      Stone Grey   stonegrey    #939388   RAL      Olive Green   olivegreen    #B5B35C   RAL      Pebble Grey   pebblegrey    #B9B9A8   RAL      Silk Grey   silkgrey    #BDBDB2   RAL      Pastel Gray   pastelgray    #CFCFC4   Wikipedia      Booger Buster   boogerbuster    #DDE26A   Wikipedia      Peridot   peridot    #E6E200   Wikipedia      Titanium Yellow   titaniumyellow    #EEE600   Wikipedia      Xanthic   xanthic    #EEED09   Wikipedia      Pale Spring Bud   palespringbud    #ECEBBD   Wikipedia      Cadmium Yellow   cadmiumyellow    #FFF600   Wikipedia      Lemon   lemon    #FFF700   Wikipedia      Neon Yellow   neonyellow    #FFF700   Wikipedia      Yellow Sunshine   yellowsunshine    #FFF700   Wikipedia      Icterine   icterine    #FCF75E   Wikipedia      Maximum Yellow   maximumyellow    #FAFA37   Crayola      Lemon Glacier   lemonglacier    #FDFF00   Wikipedia      Luminous Yellow   luminousyellow    #FFFF00   RAL      Yellow   yellow    #FFFF00   CSS      Beige   beige    #F5F5DC   CSS      Laser Lemon   laserlemon    #FFFF66   Wikipedia      Unmellow Yellow   unmellowyellow    #FFFF66   Wikipedia      Canary   canary    #FFFF99   Crayola      Light Goldenrod Yellow   lightgoldenrodyellow    #FAFAD2   CSS      Cream   cream    #FFFDD0   RAL      Very Pale Yellow   verypaleyellow    #FFFFBF   Wikipedia      Light Yellow   lightyellow    #FFFFE0   CSS      Ivory   ivory    #FFFFF0   CSS      Reed Green   reedgreen    #797C5A   RAL      Moss Grey   mossgrey    #7A7B6D   RAL      Citron   citron    #9FA91F   Wikipedia      Acid Green   acidgreen    #B0BF1A   Wikipedia      Bitter Lemon   bitterlemon    #CAE00D   Wikipedia      Pear   pear    #D1E231   Wikipedia      Maximum Green Yellow   maximumgreenyellow    #D9E650   Crayola      Oatmeal   oatmeal    #D9DAD2   Crayola      Grey White   greywhite    #DDDED4   RAL      Key Lime   keylime    #E8F48C   Wikipedia      Lemon Lime   lemonlime    #E3FF00   Wikipedia      Watermelon Yellow   watermelonyellow    #EEFF1B   Wikipedia      Black Olive   blackolive    #3B3C36   RAL      Limerick   limerick    #9DC209   Wikipedia      Middle Green Yellow   middlegreenyellow    #ACBF60   Crayola      Vivid Lime Green   vividlimegreen    #a6d608   Wikipedia      June Bud   junebud    #BDDA57   Wikipedia      Medium Spring Bud   mediumspringbud    #C9DC87   Wikipedia      Electric Lime   electriclime    #CCFF00   Wikipedia      Arctic Lime   arcticlime    #D0FF14   Wikipedia      Volt   volt    #CEFF00   Wikipedia      Mindaro   mindaro    #E3F988   Wikipedia      Pure White   purewhite    #F7F9EF   RAL      Milk   milk    #FDFFF5   Wikipedia      Brown Green   browngreen    #35382E   RAL      Umbra Grey   umbragrey    #4B4D46   RAL      Dark Moss Green   darkmossgreen    #4A5D23   Wikipedia      Olive Drab   olivedrab    #6B8E23   CSS      Olivedrab   olivedrab    #6B8E23   CSS      Concrete Grey   concretegrey    #818479   RAL      Moss Green   mossgreen    #8A9A5B   RAL      Turtle Green   turtlegreen    #8A9A5B   Wikipedia      Microsoft Green   microsoftgreen    #7DB700   Wikipedia      Yellow Green   yellowgreen    #9ACD32   CSS      Yellow-green   yellowgreen    #9ACD32   CSS      Sheen Green   sheengreen    #8FD400   Wikipedia      Light Chrome Green   lightchromegreen    #BEE64B   Crayola      Spring Bud   springbud    #A7FC00   Wikipedia      Grey Olive   greyolive    #40433B   RAL      Rifle Green   riflegreen    #444C38   Wikipedia      Dark Olive Green   darkolivegreen    #556B2F   CSS      Olivine   olivine    #9AB973   Wikipedia      Inchworm   inchworm    #B2EC5D   Wikipedia      Green Lizard   greenlizard    #A7F432   Wikipedia      Mango Green   mangogreen    #96FF00   Wikipedia      Green Yellow   greenyellow    #ADFF2F   CSS      Greenyellow   greenyellow    #ADFF2F   CSS      Sap Green   sapgreen    #507D2A   Wikipedia      Maximum Green   maximumgreen    #5E8C31   Crayola      Cement Grey   cementgrey    #818979   RAL      Asparagus   asparagus    #7BA05B   Crayola      Agate Grey   agategrey    #B4B8B0   RAL      Lawn Green   lawngreen    #7CFC00   CSS      Chartreuse   chartreuse    #7FFF00   CSS      French Lime   frenchlime    #9EFD38   Wikipedia      Metallic Green   metallicgreen    #296E01   Wikipedia      Ebony   ebony    #555D50   Wikipedia      Pistachio   pistachio    #93C572   Wikipedia      Laurel Green   laurelgreen    #A9BA9D   Wikipedia      Bright Green   brightgreen    #66FF00   Wikipedia      Spring Frost   springfrost    #87FF2A   Wikipedia      Menthol   menthol    #C1F9A2   Wikipedia      Nyanza   nyanza    #E9FFDB   Wikipedia      Kombu Green   kombugreen    #354230   Wikipedia      Napier Green   napiergreen    #2A8000   Wikipedia      Reseda Green   resedagreen    #68825B   RAL      Kelly Green   kellygreen    #4CBB17   Wikipedia      Bud Green   budgreen    #7BB661   Wikipedia      Papyrus White   papyruswhite    #CFD3CD   RAL      Tea Green   teagreen    #D0F0C0   Wikipedia      Traffic White   trafficwhite    #F7FBF5   RAL      Bottle Green   bottlegreen    #283424   RAL      Lincoln Green   lincolngreen    #195905   Wikipedia      Green Grey   greengrey    #5B6259   RAL      Artichoke Green   artichokegreen    #4B6F44   Wikipedia      Fern Green   ferngreen    #4F7942   RAL      Mantis   mantis    #74C365   Wikipedia      Harlequin   harlequin    #3FFF00   Wikipedia      Neon Green   neongreen    #39FF14   Wikipedia      Pastel Green   pastelgreen    #B7D9B1   RAL      Vine Green   vinegreen    #164010   Wikipedia      Chrome Green   chromegreen    #354733   RAL      Royal Green   royalgreen    #136207   Wikipedia      Grass Green   grassgreen    #3E753B   RAL      India Green   indiagreen    #138808   Wikipedia      Slimy Green   slimygreen    #299617   Wikipedia      May Green   maygreen    #4C9141   RAL      Pure Green   puregreen    #25E712   RAL      Granny Smith Apple   grannysmithapple    #A8E4A0   Crayola      Dark Green   darkgreen    #006400   CSS      Pakistan Green   pakistangreen    #006600   Wikipedia      Mughal Green   mughalgreen    #306030   Wikipedia      Tarpaulin Grey   tarpaulingrey    #575D57   RAL      Green   green    #008000   CSS      Office Green   officegreen    #008000   Wikipedia      Forest Green   forestgreen    #228B22   CSS      Russian Green   russiangreen    #679267   Wikipedia      Lime Green   limegreen    #32CD32   CSS      Strong Lime Green   stronglimegreen    #33CC33   Wikipedia      Dark Sea Green   darkseagreen    #8FBC8F   CSS      Luminous Green   luminousgreen    #00F700   RAL      Lime   lime    #00FF00   CSS      Light Green   lightgreen    #90EE90   CSS      Light Moss Green   lightmossgreen    #ADDFAD   Wikipedia      Screamin' Green   screamingreen    #66FF66   Wikipedia      Pale Green   palegreen    #98FB98   CSS      Mint Green   mintgreen    #98FF98   RAL      Honeydew   honeydew    #F0FFF0   CSS      Hunter Green   huntergreen    #355E3B   Wikipedia      Fern   fern    #63B76C   Crayola      Celadon   celadon    #ACE1AF   Wikipedia      Leaf Green   leafgreen    #276235   RAL      Middle Green   middlegreen    #4D8C57   Crayola      Smoke   smoke    #738276   Wikipedia      Mummy's Tomb   mummystomb    #828E84   Wikipedia      Eton Blue   etonblue    #96C8A2   Wikipedia      Pearl Green   pearlgreen    #1B542C   RAL      Emerald Green   emeraldgreen    #28713E   RAL      Xanadu   xanadu    #738678   Wikipedia      Oxley   oxley    #6D9A79   Wikipedia      Shiny Shamrock   shinyshamrock    #5FA778   Wikipedia      Medium Chrome Green   mediumchromegreen    #6CA67C   Crayola      Dark Pastel Green   darkpastelgreen    #03C03C   Wikipedia      Emerald   emerald    #50C878   Wikipedia      Paris Green   parisgreen    #50C878   Wikipedia      Malachite   malachite    #0BDA51   Wikipedia      Cambridge Blue   cambridgeblue    #A3C1AD   Wikipedia      Ash Gray   ashgray    #B2BEB5   Wikipedia      Very Light Malachite Green   verylightmalachitegreen    #64E986   Wikipedia      Erin   erin    #00FF40   Wikipedia      Teal Deer   tealdeer    #99E6B3   Wikipedia      Feldgrau   feldgrau    #4D5D53   Wikipedia      La Salle Green   lasallegreen    #087830   Wikipedia      Amazon   amazon    #3B7A57   Wikipedia      Sea Green   seagreen    #2E8B57   CSS      Medium Sea Green   mediumseagreen    #3CB371   CSS      Mediumsea Green   mediumseagreen    #3CB371   CSS      Android Green   androidgreen    #3DDC84   Wikipedia      Turquoise Green   turquoisegreen    #A0D6B4   RAL      Phthalo Green   phthalogreen    #123524   Wikipedia      Fir Green   firgreen    #26392F   RAL      UP Forest Green   upforestgreen    #014421   Wikipedia      Dartmouth Green   dartmouthgreen    #00703C   Wikipedia      Dark Spring Green   darkspringgreen    #177245   Wikipedia      Salem   salem    #177B4D   Wikipedia      Neon Dark Green   neondarkgreen    #008443   Wikipedia      Philippine Green   philippinegreen    #008543   Wikipedia      Morning Blue   morningblue    #8DA399   Wikipedia      Spring Green   springgreen    #00FF7F   CSS      Mint Cream   mintcream    #F5FFFA   CSS      British Racing Green   britishracinggreen    #004225   Wikipedia      Cadmium Green   cadmiumgreen    #006B3C   Wikipedia      Medium Green   mediumgreen    #037949   Wikipedia      Signal Green   signalgreen    #0F8558   RAL      Traffic Green   trafficgreen    #008754   RAL      Spanish Green   spanishgreen    #009150   Wikipedia      Shamrock Green   shamrockgreen    #009E60   Wikipedia      Jade   jade    #00A86B   Wikipedia      GO Green   gogreen    #00AB66   Wikipedia      Mint   mint    #3EB489   Wikipedia      Medium Spring Green   mediumspringgreen    #00FA9A   CSS      Mediumspring Green   mediumspringgreen    #00FA9A   CSS      Magic Mint   magicmint    #AAF0D1   Wikipedia      Neon Carrot   neoncarrot    #AAF0D1   Wikipedia      Dark Jungle Green   darkjunglegreen    #1A2421   Wikipedia      Medium Jungle Green   mediumjunglegreen    #1C352D   Wikipedia      Sacramento State Green   sacramentostategreen    #043927   Wikipedia      Gotham Green   gothamgreen    #00573F   Wikipedia      Patina Green   patinagreen    #327662   RAL      Spanish Viridian   spanishviridian    #007F5C   Wikipedia      Hooker's Green   hookersgreen    #49796B   Wikipedia      Mouse Grey   mousegrey    #6B716F   RAL      Viridian   viridian    #40826D   Wikipedia      Illuminating Emerald   illuminatingemerald    #319177   Wikipedia      Green-cyan   greencyan    #009966   Wikipedia      Jungle Green   junglegreen    #29AB87   Crayola      Mountain Meadow   mountainmeadow    #30BA8F   Crayola      Shamrock   shamrock    #33CC99   Crayola      Medium Aquamarine   mediumaquamarine    #66CDAA   CSS      Eucalyptus   eucalyptus    #44D7A8   Wikipedia      Opal   opal    #A8C3BC   Wikipedia      Pearl Aqua   pearlaqua    #88D8C0   Wikipedia      Technobotanica   technobotanica    #00FFBF   Wikipedia      Aquamarine   aquamarine    #7FFFD4   CSS      MSU Green   msugreen    #18453B   Wikipedia      Black Green   blackgreen    #31403D   RAL      Pearl Opal Green   pearlopalgreen    #005D4C   RAL      Tropical Rainforest   tropicalrainforest    #00755E   Crayola      Generic Viridian   genericviridian    #007F66   Wikipedia      Wintergreen Dream   wintergreendream    #56887D   Wikipedia      Paolo Veronese Green   paoloveronesegreen    #009B7D   Wikipedia      Zomp   zomp    #39A78E   Wikipedia      Polished Pine   polishedpine    #5DA493   Wikipedia      Keppel   keppel    #3AB09E   Wikipedia      Green Sheen   greensheen    #6EAEA1   Wikipedia      Caribbean Green   caribbeangreen    #00CC99   Crayola      Middle Blue Green   middlebluegreen    #8DD9CC   Crayola      Pale Robin Egg Blue   palerobineggblue    #96DED1   Wikipedia      Opal Green   opalgreen    #005D52   RAL      Pine Green   pinegreen    #01796F   RAL      Myrtle Green   myrtlegreen    #317873   Wikipedia      Mint Turquoise   mintturquoise    #478A84   RAL      Persian Green   persiangreen    #00A693   Wikipedia      Traffic Grey A   trafficgreya    #8F9695   RAL      Light Sea Green   lightseagreen    #20B2AA   CSS      Lightsea Green   lightseagreen    #20B2AA   CSS      Turquoise   turquoise    #40E0D0   CSS      Turquoise Blue   turquoiseblue    #00FFEF   RAL      Charleston Green   charlestongreen    #232B2B   Wikipedia      Rich Black   richblack    #004040   Wikipedia      Warm Black   warmblack    #004242   Wikipedia      Blue Green   bluegreen    #0E4243   RAL      Deep Jungle Green   deepjunglegreen    #004B49   Wikipedia      Dark Slate Gray   darkslategray    #2F4F4F   CSS      Dark Slate Grey   darkslategrey    #2F4F4F   CSS      Skobeloff   skobeloff    #007474   Wikipedia      Teal   teal    #008080   CSS      Teal Green   tealgreen    #00827F   Wikipedia      Dark Cyan   darkcyan    #008B8B   CSS      Viridian Green   viridiangreen    #009698   Wikipedia      Cadet Blue   cadetblue    #5F9EA0   CSS      Verdigris   verdigris    #43B3AE   Wikipedia      Tiffany Blue   tiffanyblue    #0ABAB5   Wikipedia      Maximum Blue Green   maximumbluegreen    #30BFBF   Crayola      Pastel Turquoise   pastelturquoise    #7FB0B2   RAL      Robin Egg Blue   robineggblue    #00CCCC   Wikipedia      Robin's Egg Blue   robinseggblue    #00CCCC   Crayola      Dark Turquoise   darkturquoise    #00CED1   CSS      Medium Turquoise   mediumturquoise    #48D1CC   CSS      Mediumturquoise   mediumturquoise    #48D1CC   CSS      Bright Turquoise   brightturquoise    #08E8DE   Wikipedia      Fluorescent Blue   fluorescentblue    #15F4EE   Wikipedia      Lotion Blue   lotionblue    #15F2FD   Wikipedia      Neon Cyan   neoncyan    #00FEFC   Wikipedia      Spanish Sky Blue   spanishskyblue    #00FFFE   Wikipedia      Aqua   aqua    #00FFFF   CSS      Cyan   cyan    #00FFFF   CSS      Electric Blue   electricblue    #7DF9FF   Wikipedia      Pale Blue   paleblue    #AFEEEE   Wikipedia      Pale Turquoise   paleturquoise    #AFEEEE   CSS      Paleturquoise   paleturquoise    #AFEEEE   CSS      Celeste   celeste    #B2FFFF   Wikipedia      Italian Sky Blue   italianskyblue    #B2FFFF   Wikipedia      Light Cyan   lightcyan    #E0FFFF   CSS      Lightcyan   lightcyan    #E0FFFF   CSS      Azure   azure    #F0FFFF   CSS      Midnight Green   midnightgreen    #004953   Wikipedia      Water Blue   waterblue    #07737A   RAL      Ming   ming    #36747D   Wikipedia      Metallic Seaweed   metallicseaweed    #0A7E8C   Wikipedia      Steel Teal   steelteal    #5F8A8F   Wikipedia      Powder Blue   powderblue    #B0E0E6   CSS      Blizzard Blue   blizzardblue    #ACE5EE   Wikipedia      Waterspout   waterspout    #A4F4F9   Wikipedia      Cool Mint   coolmint    #DDEBEC   Crayola      Outer Space   outerspace    #2D383A   Crayola      Ocean Blue   oceanblue    #0B4151   RAL      Granite Grey   granitegrey    #374447   RAL      Deep Space Sparkle   deepspacesparkle    #4A646C   Wikipedia      Basalt Grey   basaltgrey    #596163   RAL      Teal Blue   tealblue    #367588   Crayola      Pacific Blue   pacificblue    #1CA9C9   Crayola      Moonstone   moonstone    #3AA8C1   Wikipedia      Maximum Blue   maximumblue    #47ABCC   Crayola      Tourmaline   tourmaline    #86A1A9   Wikipedia      Vivid Sky Blue   vividskyblue    #00CCFF   Wikipedia      Middle Blue   middleblue    #7ED4E6   Crayola      Medium Sky Blue   mediumskyblue    #80DAEB   Wikipedia      Light Blue   lightblue    #ADD8E6   CSS      Non-photo Blue   nonphotoblue    #A4DDED   Wikipedia      Water   water    #D4F1F9   Wikipedia      Black Grey   blackgrey    #2E3234   RAL      Gunmetal   gunmetal    #2a3439   Wikipedia      Anthracite Grey   anthracitegrey    #373F43   RAL      Blue Sapphire   bluesapphire    #126180   Wikipedia      Pearl Gentian Blue   pearlgentianblue    #296478   RAL      Iron Grey   irongrey    #555D61   RAL      Sea Blue   seablue    #006994   Wikipedia      Cadet   cadet    #536872   Wikipedia      Cerulean   cerulean    #007BA7   Crayola      Star Command Blue   starcommandblue    #007BB8   Wikipedia      Rich Electric Blue   richelectricblue    #0892D0   Wikipedia      Weezy Blue   weezyblue    #189BCC   Wikipedia      United Nations Blue   unitednationsblue    #009EDB   Wikipedia      Microsoft Blue   microsoftblue    #00A2ED   Wikipedia      Twitter Blue   twitterblue    #26A7DE   Wikipedia      Vivid Cerulean   vividcerulean    #00AAEE   Wikipedia      Moonstone Blue   moonstoneblue    #73A9C2   Wikipedia      Picton Blue   pictonblue    #45B1E8   Wikipedia      Pewter Blue   pewterblue    #8BA8B7   Wikipedia      Window Grey   windowgrey    #9DA3A6   RAL      Deep Sky Blue   deepskyblue    #00BFFF   CSS      Dark Sky Blue   darkskyblue    #8CBED6   Wikipedia      Sky Blue   skyblue    #87CEEB   CSS      Baby Blue   babyblue    #89CFF0   Wikipedia      Cornflower   cornflower    #93CCEA   Crayola      Light Cornflower Blue   lightcornflowerblue    #93CCEA   Wikipedia      Pale Cyan   palecyan    #87D3F8   Wikipedia      Prussian Blue   prussianblue    #003153   Wikipedia      Indigo Dye   indigodye    #00416A   Wikipedia      Philippine Indigo   philippineindigo    #00416A   Wikipedia      Charcoal   charcoal    #36454F   Wikipedia      Capri Blue   capriblue    #1A5784   RAL      Azure Blue   azureblue    #2E5978   RAL      Medium Persian Blue   mediumpersianblue    #0067A5   Wikipedia      Sapphire Blue   sapphireblue    #0067A5   RAL      Dark Electric Blue   darkelectricblue    #536878   Wikipedia      Payne's Grey   paynesgrey    #536878   Wikipedia      Blue Grey   bluegrey    #5D6970   RAL      Honolulu Blue   honolulublue    #006DB0   Wikipedia      Spanish Blue   spanishblue    #0070B8   Wikipedia      French Blue   frenchblue    #0072BB   Wikipedia      Ocean Boat Blue   oceanboatblue    #0077BE   Wikipedia      Microsoft Edge Blue   microsoftedgeblue    #0078D7   Wikipedia      Rackley   rackley    #5D8AA8   Wikipedia      Squirrel Grey   squirrelgrey    #7E8B92   RAL      Telegrey 2   telegreytwo    #82898E   RAL      Pastel Blue   pastelblue    #6A93B0   RAL      Carolina Blue   carolinablue    #56A0D3   Wikipedia      Telegrey 1   telegreyone    #91969A   RAL      Silver Grey   silvergrey    #8F999F   RAL      Air Superiority Blue   airsuperiorityblue    #72A0C1   Wikipedia      Cadet Grey   cadetgrey    #91A3B0   Wikipedia      Blue Jeans   bluejeans    #5DADEC   Wikipedia      Aero   aero    #7CB9E8   Wikipedia      Maya Blue   mayablue    #73C2FB   Wikipedia      Pale Cerulean   palecerulean    #9BC4E2   Wikipedia      Light Sky Blue   lightskyblue    #87CEFA   CSS      Lightsky Blue   lightskyblue    #87CEFA   CSS      Beau Blue   beaublue    #BCD4E6   Wikipedia      Columbia Blue   columbiablue    #B9D9EB   Wikipedia      Uranian Blue   uranianblue    #AFDBF5   Wikipedia      Maastricht Blue   maastrichtblue    #001C3D   Wikipedia      Oxford Blue   oxfordblue    #002147   Wikipedia      Dark Midnight Blue   darkmidnightblue    #003366   Wikipedia      Yale Blue   yaleblue    #00356B   Wikipedia      Grey Blue   greyblue    #313C48   RAL      Gentian Blue   gentianblue    #13447C   RAL      Police Blue   policeblue    #374F6B   Wikipedia      Traffic Blue   trafficblue    #0E518D   RAL      USAFA Blue   usafablue    #004F98   Wikipedia      Medium Electric Blue   mediumelectricblue    #035096   Wikipedia      Lapis Lazuli   lapislazuli    #26619C   Wikipedia      Black Coral   blackcoral    #54626F   Wikipedia      Green-blue   greenblue    #1164B4   RAL      Brilliant Blue   brilliantblue    #41678D   RAL      Queen Blue   queenblue    #436B95   Wikipedia      Bright Navy Blue   brightnavyblue    #1974D2   Wikipedia      Steel Blue   steelblue    #4682B4   CSS      Slate Gray   slategray    #708090   CSS      Slate Grey   slategrey    #708090   CSS      Slategrey   slategrey    #708090   CSS      Silver Lake Blue   silverlakeblue    #5D89BA   Wikipedia      Light Slate Gray   lightslategray    #778899   CSS      Light Slate Grey   lightslategrey    #778899   CSS      Lightslate Gray   lightslategray    #778899   CSS      Lightslategrey   lightslategrey    #778899   CSS      Bleu De France   bleudefrance    #318CE7   Wikipedia      Tufts Blue   tuftsblue    #3E8EDE   Wikipedia      Dodger Blue   dodgerblue    #1E90FF   CSS      Blue-gray   bluegray    #6699CC   Crayola      Livid   livid    #6699CC   Wikipedia      Cerulean Frost   ceruleanfrost    #6D9BC3   Wikipedia      Little Boy Blue   littleboyblue    #6CA0DC   Wikipedia      Iceberg   iceberg    #71A6D2   Wikipedia      French Sky Blue   frenchskyblue    #77B5FE   Wikipedia      Very Light Azure   verylightazure    #74BBFB   Wikipedia      Baby Blue Eyes   babyblueeyes    #A1CAF1   Wikipedia      Pale Cornflower Blue   palecornflowerblue    #ABCDEF   Wikipedia      Pale Aqua   paleaqua    #BED3E5   Wikipedia      Alice Blue   aliceblue    #F0F8FF   CSS      Pearl Night Blue   pearlnightblue    #102C54   RAL      Signal Blue   signalblue    #154889   RAL      Metallic Blue   metallicblue    #32527B   Wikipedia      Absolute Zero   absolutezero    #0048BA   Wikipedia      B'dazzled Blue   bdazzledblue    #2E5894   Wikipedia      Sapphire   sapphire    #0F52BA   Wikipedia      Denim   denim    #1560BD   Crayola      Distant Blue   distantblue    #4D668E   RAL      True Blue   trueblue    #2D68C4   Wikipedia      Blue Yonder   blueyonder    #5072A7   Wikipedia      Philippine Sky Blue   philippineskyblue    #0066FF   Wikipedia      Pigeon Blue   pigeonblue    #6C7C98   RAL      Glaucous   glaucous    #6082B6   Wikipedia      Shadow Blue   shadowblue    #778BA5   Wikipedia      Cornflower Blue   cornflowerblue    #6495ED   CSS      Vista Blue   vistablue    #7C9ED9   Wikipedia      Light Cobalt Blue   lightcobaltblue    #88ACE0   Wikipedia      Light Steel Blue   lightsteelblue    #B0C4DE   CSS      Lightsteel Blue   lightsteelblue    #B0C4DE   CSS      Resolution Blue   resolutionblue    #002387   Wikipedia      UA Blue   uablue    #0033AA   Wikipedia      Philippine Blue   philippineblue    #0038A7   Wikipedia      Royal Azure   royalazure    #0038A8   Wikipedia      Graphite Grey   graphitegrey    #474A50   RAL      YInMn Blue   yinmnblue    #2E5090   Wikipedia      New Car   newcar    #214FC6   Wikipedia      Cerulean Blue   ceruleanblue    #2A52BE   Crayola      Han Blue   hanblue    #446CCF   Wikipedia      Bluetiful   bluetiful    #3C69E7   Crayola      Roman Silver   romansilver    #838996   Wikipedia      Blueberry   blueberry    #4F86F7   Wikipedia      Black Blue   blackblue    #1D1F2A   RAL      Space Cadet   spacecadet    #1D2951   Wikipedia      Cobalt Blue   cobaltblue    #232D53   RAL      Egyptian Blue   egyptianblue    #1034A6   Wikipedia      Persian Blue   persianblue    #1C39BB   Wikipedia      Denim Blue   denimblue    #2243B6   Wikipedia      Independence   independence    #4C516D   Wikipedia      Violet-blue   violetblue    #324AB2   RAL      Royal Blue   royalblue    #4169E1   CSS      Ultramarine Blue   ultramarineblue    #4166F5   RAL      Neon Blue   neonblue    #4666FF   Wikipedia      Cool Grey   coolgrey    #8C92AC   Wikipedia      Manatee   manatee    #979AAA   Crayola      Wild Blue Yonder   wildblueyonder    #A2ADD0   Wikipedia      Light Periwinkle   lightperiwinkle    #C5CBE1   Wikipedia      Phthalo Blue   phthaloblue    #000F89   Wikipedia      St. Patrick's Blue   stpatricksblue    #23297A   Wikipedia      Zaffre   zaffre    #0014A8   Wikipedia      Samsung Blue   samsungblue    #12279E   Wikipedia      Purple Navy   purplenavy    #4E5180   Wikipedia      Palatinate Blue   palatinateblue    #273BE2   Wikipedia      Liberty   liberty    #545AA7   Wikipedia      Navy   navy    #000080   CSS      Navy Blue   navyblue    #000080   Crayola      Midnight Blue   midnightblue    #191970   CSS      Dark Blue   darkblue    #00008B   CSS      Duke Blue   dukeblue    #00009C   Wikipedia      Blue Ribbon   blueribbon    #0B10A2   Wikipedia      Cosmic Cobalt   cosmiccobalt    #2E2D88   Wikipedia      Medium Blue   mediumblue    #0000CD   CSS      Blue   blue    #0000FF   CSS      Dark Blue-gray   darkbluegray    #666699   Wikipedia      Rhythm   rhythm    #777696   Wikipedia      Celestial Blue   celestialblue    #7070CC   Crayola      Very Light Blue   verylightblue    #6666FF   Wikipedia      Blue Bell   bluebell    #A2A2D0   Crayola      Maximum Blue Purple   maximumbluepurple    #ACACE6   Crayola      Lavender Blue   lavenderblue    #CCCCFF   Wikipedia      Periwinkle   periwinkle    #CCCCFF   Crayola      Lavender   lavender    #E6E6FA   CSS      Lavender Mist   lavendermist    #E6E6FA   Wikipedia      Ghost White   ghostwhite    #F8F8FF   CSS      International Klein Blue   internationalkleinblue    #130a8f   Wikipedia      Night Blue   nightblue    #2F2A5A   RAL      Picotee Blue   picoteeblue    #2E2787   Wikipedia      Trypan Blue   trypanblue    #1C05B3   Wikipedia      Dark Slate Blue   darkslateblue    #483D8B   CSS      Iris   iris    #5A4FCF   Wikipedia      Pearl Blackberry   pearlblackberry    #6B6880   RAL      Majorelle Blue   majorelleblue    #6050DC   Wikipedia      Slate Blue   slateblue    #6A5ACD   CSS      Medium Slate Blue   mediumslateblue    #7B68EE   CSS      Mediumslate Blue   mediumslateblue    #7B68EE   CSS      Lavender Gray   lavendergray    #C4C3D0   Wikipedia      Ultramarine   ultramarine    #3F00FF   Wikipedia      Plump Purple   plumppurple    #5946B2   Wikipedia      Soap   soap    #CEC8EF   Wikipedia      Paua   paua    #1F005E   Wikipedia      Persian Indigo   persianindigo    #32127A   Wikipedia      Han Purple   hanpurple    #5218FA   Wikipedia      Middle Blue Purple   middlebluepurple    #8B72BE   Crayola      Medium Purple   mediumpurple    #9370DB   CSS      Mediumpurple   mediumpurple    #9370DB   CSS      Light Pastel Purple   lightpastelpurple    #B19CD9   Wikipedia      Pale Lavender   palelavender    #DCD0FF   Wikipedia      Spanish Violet   spanishviolet    #4C2882   Wikipedia      KSU Purple   ksupurple    #512888   Wikipedia      Cyber Grape   cybergrape    #58427C   Wikipedia      Purple Heart   purpleheart    #652DC1   Crayola      Electric Indigo   electricindigo    #6F00FF   Wikipedia      Royal Purple   royalpurple    #7851A9   Crayola      Pearl Violet   pearlviolet    #8773A1   RAL      Lavender Indigo   lavenderindigo    #9457EB   Wikipedia      Navy Purple   navypurple    #9457EB   Wikipedia      Neon Purple   neonpurple    #9457EB   Wikipedia      Russian Violet   russianviolet    #32174D   Wikipedia      Rebecca Purple   rebeccapurple    #663399   CSS      Poison Purple   poisonpurple    #7F01FE   Wikipedia      Blue Violet   blueviolet    #8A2BE2   CSS      Blue-violet   blueviolet    #8A2BE2   CSS      Amethyst   amethyst    #9966CC   Wikipedia      Purple Mountain Majesty   purplemountainmajesty    #9678B6   Wikipedia      Lavender Purple   lavenderpurple    #967BB6   Wikipedia      Pale Violet   paleviolet    #CC99FF   Wikipedia      Indigo   indigo    #4B0082   CSS      Metallic Violet   metallicviolet    #5B0A91   Wikipedia      Seance   seance    #612086   Wikipedia      Electric Violet   electricviolet    #8F00FF   Wikipedia      Blue Lilac   bluelilac    #83639D   RAL      Veronica   veronica    #A020F0   Wikipedia      Vivid Violet   vividviolet    #9F00FF   Crayola      Rich Lavender   richlavender    #A76BCF   Wikipedia      Mauve   mauve    #E0B0FF   Wikipedia      Languid Lavender   languidlavender    #D6CADD   Wikipedia      Eminence   eminence    #6C3082   Wikipedia      French Violet   frenchviolet    #8806CE   Wikipedia      Dark Violet   darkviolet    #9400D3   CSS      Medium Violet   mediumviolet    #8F47B3   Crayola      Dark Orchid   darkorchid    #9932CC   CSS      Purple Plum   purpleplum    #9C51B6   Wikipedia      Electric Purple   electricpurple    #BF00FF   Wikipedia      Rich Lilac   richlilac    #B666D2   Wikipedia      Wisteria   wisteria    #C9A0DC   Crayola      English Violet   englishviolet    #563C5C   Wikipedia      Old Heliotrope   oldheliotrope    #563C5C   Wikipedia      Maximum Purple   maximumpurple    #733380   Crayola      French Lilac   frenchlilac    #86608E   Wikipedia      Pomp And Power   pompandpower    #86608E   Wikipedia      Purpureus   purpureus    #9A4EAE   Wikipedia      Vivid Mulberry   vividmulberry    #B80CE3   Wikipedia      Medium Orchid   mediumorchid    #BA55D3   CSS      Mediumorchid   mediumorchid    #BA55D3   CSS      Vivid Orchid   vividorchid    #CC00FF   Wikipedia      African Violet   africanviolet    #B284BE   Wikipedia      Glossy Grape   glossygrape    #AB92B3   Wikipedia      Heliotrope   heliotrope    #DF73FF   Wikipedia      Bright Lilac   brightlilac    #D891EF   Wikipedia      Dark Purple   darkpurple    #301934   Wikipedia      Chinese Violet   chineseviolet    #856088   Wikipedia      Phlox   phlox    #DF00FF   Wikipedia      Psychedelic Purple   psychedelicpurple    #DF00FF   Wikipedia      Pastel Purple   pastelpurple    #B39EB5   Wikipedia      Purple Mountains' Majesty   purplemountainsmajesty    #D6AEDD   Crayola      Rich Brilliant Lavender   richbrilliantlavender    #F1A7FE   Wikipedia      Finn   finn    #683068   Wikipedia      Midnight   midnight    #702670   Wikipedia      Patriarch   patriarch    #800080   Wikipedia      Purple   purple    #800080   CSS      Philippine Violet   philippineviolet    #81007F   Wikipedia      Mardi Gras   mardigras    #880085   Wikipedia      Dark Magenta   darkmagenta    #8B008B   CSS      Secret   secret    #764374   Wikipedia      Steel Pink   steelpink    #CC33CC   Wikipedia      Deep Fuchsia   deepfuchsia    #C154C1   Wikipedia      Deep Mauve   deepmauve    #D473D4   Wikipedia      French Mauve   frenchmauve    #D473D4   Wikipedia      Fuchsia   fuchsia    #FF00FF   CSS      Magenta   magenta    #FF00FF   CSS      Orchid   orchid    #DA70D6   CSS      Light Grayish Magenta   lightgrayishmagenta    #CC99CC   Wikipedia      Lilac   lilac    #C8A2C8   Wikipedia      Lavender Magenta   lavendermagenta    #EE82EE   Wikipedia      Violet   violet    #EE82EE   CSS      Pink Flamingo   pinkflamingo    #FC74FD   Crayola      Ultra Pink   ultrapink    #FF6FFF   Wikipedia      Medium Lavender Magenta   mediumlavendermagenta    #DDA0DD   Wikipedia      Pale Plum   paleplum    #DDA0DD   Wikipedia      Plum   plum    #DDA0DD   CSS      Maximum Pink   maximumpink    #F6A5F2   Wikipedia      Thistle   thistle    #D8BFD8   CSS      Pale Purple   palepurple    #FAE6FA   Wikipedia      Japanese Violet   japaneseviolet    #5B3256   Wikipedia      Palatinate Purple   palatinatepurple    #682860   Wikipedia      Razzmic Berry   razzmicberry    #8D4E85   Wikipedia      Old Lavender   oldlavender    #796878   Wikipedia      Red Lilac   redlilac    #8A5A83   RAL      Heliotrope Gray   heliotropegray    #AA98A9   Wikipedia      Light Medium Orchid   lightmediumorchid    #D39BCB   Wikipedia      Light Fuchsia Pink   lightfuchsiapink    #F984EF   Wikipedia      Purple Taupe   purpletaupe    #50404D   Wikipedia      Quartz   quartz    #51484F   Wikipedia      Byzantium   byzantium    #702963   Wikipedia      Maximum Violet   maximumviolet    #892F77   Wikipedia      Signal Violet   signalviolet    #904684   RAL      Byzantine   byzantine    #BD33A4   Wikipedia      Hot Fuchsia   hotfuchsia    #FF00C6   Wikipedia      Hot Magenta   hotmagenta    #FF1DCE   Wikipedia      Medium Rose   mediumrose    #D96CBE   Crayola      Lilac Luster   lilacluster    #AE98AA   Wikipedia      Brilliant Rose   brilliantrose    #E667CE   Crayola      Purple Pizzazz   purplepizzazz    #FE4EDA   Wikipedia      Pale Magenta   palemagenta    #F984E5   Wikipedia      Light Orchid   lightorchid    #E6A8D7   Wikipedia      Pink Lavender   pinklavender    #D8B2D1   Wikipedia      Dark Byzantium   darkbyzantium    #5D3954   Wikipedia      Flirt   flirt    #A2006D   Wikipedia      Traffic Purple   trafficpurple    #992572   RAL      Berry Parfait   berryparfait    #A43482   Wikipedia      Antique Fuchsia   antiquefuchsia    #915C83   Wikipedia      Fandango   fandango    #B53389   Wikipedia      Taupe Gray   taupegray    #8B8589   Wikipedia      Pearly Purple   pearlypurple    #B768A2   Wikipedia      Fashion Fuchsia   fashionfuchsia    #F400A1   Wikipedia      Hollywood Cerise   hollywoodcerise    #F400A1   Wikipedia      Opera Mauve   operamauve    #B784A7   Wikipedia      Shocking Pink   shockingpink    #FC0FC0   Wikipedia      Sky Magenta   skymagenta    #CF71AF   Wikipedia      Razzle Dazzle Rose   razzledazzlerose    #FF33CC   Wikipedia      Rose Pink   rosepink    #FF66CC   Wikipedia      Lavender Rose   lavenderrose    #FBA0E3   Wikipedia      Shampoo   shampoo    #FFCFF1   Wikipedia      Pink Lace   pinklace    #FFDDF4   Wikipedia      Purple Violet   purpleviolet    #4A203B   RAL      Spanish Purple   spanishpurple    #66033C   Wikipedia      Tyrian Purple   tyrianpurple    #66023C   Wikipedia      Sugar Plum   sugarplum    #914E75   Wikipedia      Maximum Red Purple   maximumredpurple    #A63A79   Crayola      Medium Red-violet   mediumredviolet    #BB3385   Wikipedia      Medium Violet Red   mediumvioletred    #C71585   CSS      Medium Violet-red   mediumvioletred    #C71585   CSS      Red-violet   redviolet    #C71585   RAL      Royal Fuchsia   royalfuchsia    #CA2C92   Wikipedia      Barbie Pink   barbiepink    #DA1884   Wikipedia      Mountbatten Pink   mountbattenpink    #997A8D   Wikipedia      Frostbite   frostbite    #E936A7   Wikipedia      Super Pink   superpink    #CF6BA9   Wikipedia      Persian Rose   persianrose    #FE28A2   Wikipedia      Middle Purple   middlepurple    #D982B5   Crayola      Pink Pearl   pinkpearl    #E7ACCF   Wikipedia      Pansy Purple   pansypurple    #78184A   Wikipedia      Eggplant   eggplant    #614051   Crayola      Dark Raspberry   darkraspberry    #872657   Wikipedia      Dark Fuchsia   darkfuchsia    #A00955   Wikipedia      Jazzberry Jam   jazzberryjam    #A50B5E   Crayola      Amaranth Deep Purple   amaranthdeeppurple    #9F2B68   Wikipedia      Twilight Lavender   twilightlavender    #8A496B   Wikipedia      Magenta Haze   magentahaze    #9F4576   Wikipedia      Mystic Maroon   mysticmaroon    #AD4379   Wikipedia      Smitten   smitten    #C84186   Wikipedia      Vivid Cerise   vividcerise    #DA1D81   Wikipedia      Mulberry   mulberry    #C54B8C   Crayola      Red-purple   redpurple    #E40078   Wikipedia      Mexican Pink   mexicanpink    #E4007C   Wikipedia      Deep Cerise   deepcerise    #DA3287   Wikipedia      Royal Pink   royalpink    #E73895   Wikipedia      Bright Pink   brightpink    #FF007F   Wikipedia      Philippine Pink   philippinepink    #FA1A8E   Wikipedia      Rose   rose    #FF007F   RAL      Winter Sky   wintersky    #FF007C   Wikipedia      Pastel Violet   pastelviolet    #A38995   RAL      Deep Pink   deeppink    #FF1493   CSS      Wild Orchid   wildorchid    #D470A2   Wikipedia      Rose Bonbon   rosebonbon    #F9429E   Wikipedia      China Pink   chinapink    #DE6FA1   Wikipedia      Liseran Purple   liseranpurple    #DE6FA1   Wikipedia      Thulian Pink   thulianpink    #DE6FA1   Wikipedia      Wild Strawberry   wildstrawberry    #FF43A4   Crayola      Hot Pink   hotpink    #FF69B4   CSS      Hotpink   hotpink    #FF69B4   CSS      Persian Pink   persianpink    #F77FBE   Wikipedia      Kobi   kobi    #E79FC4   Wikipedia      Claret Violet   claretviolet    #691639   RAL      Old Mauve   oldmauve    #673147   Wikipedia      Wine Dregs   winedregs    #673147   Wikipedia      Quinacridone Magenta   quinacridonemagenta    #8E3A59   Wikipedia      Rich Maroon   richmaroon    #B03060   Wikipedia      Pictorial Carmine   pictorialcarmine    #C30B4E   Wikipedia      Medium Ruby   mediumruby    #AA4069   Wikipedia      Irresistible   irresistible    #B3446C   Wikipedia      Raspberry Rose   raspberryrose    #B3446C   Wikipedia      Rubine Red   rubinered    #D10056   Wikipedia      UA Red   uared    #D9004C   Wikipedia      Dogwood Rose   dogwoodrose    #D71868   Wikipedia      Telemagenta   telemagenta    #CF3476   RAL      Fuchsia Purple   fuchsiapurple    #CC397B   Wikipedia      Fuchsia Rose   fuchsiarose    #C74375   Wikipedia      Ruby   ruby    #E0115F   Wikipedia      Raspberry   raspberry    #E30B5D   Wikipedia      Ruber   ruber    #CE4676   Wikipedia      Razzmatazz   razzmatazz    #E3256B   Crayola      Mystic   mystic    #D65282   Wikipedia      Heather Violet   heatherviolet    #D15B8F   RAL      Fandango Pink   fandangopink    #DE5285   Wikipedia      Vivid Raspberry   vividraspberry    #FF006C   Wikipedia      English Lavender   englishlavender    #B48395   Wikipedia      Neon Pink   neonpink    #FE347E   Wikipedia      French Rose   frenchrose    #F64A8A   Wikipedia      French Fuchsia   frenchfuchsia    #FD3F92   Wikipedia      Violet-red   violetred    #F75394   Crayola      Cyclamen   cyclamen    #F56FA1   Wikipedia      Amaranth Pink   amaranthpink    #F19CBB   Wikipedia      Pastel Magenta   pastelmagenta    #F49AC2   Wikipedia      Metallic Pink   metallicpink    #EDA6C4   Wikipedia      Carnation Pink   carnationpink    #FFA6C9   Crayola      Little Girl Pink   littlegirlpink    #F8B9D4   Wikipedia      Cotton Candy   cottoncandy    #FFBCD9   Crayola      Queen Pink   queenpink    #E8CCD7   Wikipedia      Mimi Pink   mimipink    #FFDAE9   Wikipedia      Light Chocolate Cosmos   lightchocolatecosmos    #551F2F   Wikipedia      Claret   claret    #7F1734   Wikipedia      Amaranth Purple   amaranthpurple    #AB274F   Wikipedia      Rose Red   rosered    #C21E56   Wikipedia      Mauve Taupe   mauvetaupe    #915F6D   Wikipedia      Raspberry Glacé   raspberryglace    #915F6D   Wikipedia      Spanish Carmine   spanishcarmine    #D10047   Wikipedia      Rose Dust   rosedust    #9E5E6F   Wikipedia      Rich Carmine   richcarmine    #D70040   Wikipedia      Cerise   cerise    #DE3163   Crayola      Cinnamon Satin   cinnamonsatin    #CD607E   Wikipedia      Blush   blush    #DE5D83   Crayola      Pale Violet Red   palevioletred    #DB7093   CSS      Watermelon   watermelon    #F05C85   Wikipedia      Strawberry Iced Tea   strawberryicedtea    #FC5A8D   Wikipedia      Light Crimson   lightcrimson    #F56991   Wikipedia      Pale Dogwood   paledogwood    #ED7A9B   Wikipedia      Rose Pompadour   rosepompadour    #ED7A9B   Wikipedia      French Pink   frenchpink    #FD6C9E   Wikipedia      Medium Pink   mediumpink    #FE6E9F   Wikipedia      Charm Pink   charmpink    #E68FAC   Wikipedia      Light Thulian Pink   lightthulianpink    #E68FAC   Wikipedia      Vanilla Ice   vanillaice    #F38FA9   Wikipedia      Tickle Me Pink   ticklemepink    #FC89AC   Crayola      Baker-Miller Pink   bakermillerpink    #FF91AF   Wikipedia      Schauss Pink   schausspink    #FF91AF   Wikipedia      Nadeshiko Pink   nadeshikopink    #F6ADC6   Wikipedia      Cameo Pink   cameopink    #EFBBCC   Wikipedia      Orchid Pink   orchidpink    #F2BDCD   Wikipedia      Piggy Pink   piggypink    #FDDDE6   Crayola      Lavender Blush   lavenderblush    #FFF0F5   CSS      Temptress   temptress    #3C2126   Wikipedia      Burgundy   burgundy    #800020   Wikipedia      Antique Ruby   antiqueruby    #841B2D   Wikipedia      Catawba   catawba    #703642   Wikipedia      Carmine   carmine    #960018   Crayola      Royal Red   royalred    #9B1C31   Wikipedia      University Of Pennsylvania Red   universityofpennsylvaniared    #A50021   Wikipedia      Vivid Burgundy   vividburgundy    #9F1D35   Wikipedia      Big Dip O'ruby   bigdiporuby    #9C2542   Wikipedia      Red Rum   redrum    #973A4A   Wikipedia      Raspberry Red   raspberryred    #B42041   RAL      Cardinal   cardinal    #C41E3A   Wikipedia      Bright Maroon   brightmaroon    #C32148   Wikipedia      Vivid Crimson   vividcrimson    #CC0033   Wikipedia      French Raspberry   frenchraspberry    #C72C48   Wikipedia      Dingy Dungeon   dingydungeon    #C53151   Wikipedia      Crimson   crimson    #DC143C   CSS      Medium Candy Apple Red   mediumcandyapplered    #E2062C   Wikipedia      Popstar   popstar    #BE4F62   Wikipedia      Spanish Red   spanishred    #E60026   Wikipedia      Spanish Crimson   spanishcrimson    #E51A4C   Wikipedia      Amaranth   amaranth    #E52B50   Wikipedia      Paradise Pink   paradisepink    #E63E62   Wikipedia      Turkish Rose   turkishrose    #B57281   Wikipedia      Tractor Red   tractorred    #FD0E35   Wikipedia      Radical Red   radicalred    #FF355E   Wikipedia      Neon Fuchsia   neonfuchsia    #FE4164   Wikipedia      Fiery Rose   fieryrose    #FF5470   Wikipedia      Puce   puce    #CC8899   Wikipedia      Brink Pink   brinkpink    #FB607F   Wikipedia      Shimmering Blush   shimmeringblush    #D98695   Wikipedia      Ultra Red   ultrared    #FC6C85   Wikipedia      Wild Watermelon   wildwatermelon    #FC6C85   Wikipedia      Black Shadows   blackshadows    #BFAFB2   Wikipedia      Pink Sherbet   pinksherbet    #F78FA7   Wikipedia      Mauvelous   mauvelous    #EF98AA   Crayola      Salmon Pink   salmonpink    #FF91A4   RAL      Light Pink   lightpink    #FFB6C1   CSS      Lightpink   lightpink    #FFB6C1   CSS      Cherry Blossom Pink   cherryblossompink    #FFB7C5   Wikipedia      Pink   pink    #FFC0CB   CSS      Black Red   blackred    #402225   RAL      Rosewood   rosewood    #65000B   Wikipedia      Wine Red   winered    #5E2028   RAL      Pearl Ruby Red   pearlrubyred    #711521   RAL      Purple Red   purplered    #701F29   RAL      Puce Red   pucered    #722F37   Wikipedia      Wine   wine    #722F37   Wikipedia      Ruby Red   rubyred    #9B111E   RAL      Solid Pink   solidpink    #893843   Wikipedia      Cordovan   cordovan    #893F45   Wikipedia      Signal Red   signalred    #A02128   RAL      Carmine Red   carminered    #A1232B   RAL      Japanese Carmine   japanesecarmine    #9D2933   Wikipedia      Upsdell Red   upsdellred    #AE2029   Wikipedia      Orient Red   orientred    #AC323B   RAL      Deep Taupe   deeptaupe    #7E5E60   Wikipedia      Traffic Red   trafficred    #C1121C   RAL      Venetian Red   venetianred    #C80815   Crayola      English Red   englishred    #AB4B52   Wikipedia      Lava   lava    #CF1020   Wikipedia      Philippine Red   philippinered    #CE1127   Wikipedia      Stop Red   stopred    #CF142B   Wikipedia      Fire Engine Red   fireenginered    #CE2029   Wikipedia      Red Cola   redcola    #DF0118   Wikipedia      Brick Red   brickred    #CB4154   Crayola      Cadmium Red   cadmiumred    #E30022   Wikipedia      Nintendo Red   nintendored    #E4000F   Wikipedia      Rusty Red   rustyred    #DA2C43   Wikipedia      Alizarin   alizarin    #DB2D43   Wikipedia      Strawberry Red   strawberryred    #D14152   RAL      Rose Madder   rosemadder    #E32636   Wikipedia      Rocket Metallic   rocketmetallic    #8A7F80   Wikipedia      Imperial Red   imperialred    #ED2939   Wikipedia      Vivid Red   vividred    #F70D1A   Wikipedia      Red Salsa   redsalsa    #FD3A4A   Wikipedia      Sizzling Red   sizzlingred    #FF3855   Wikipedia      Antique Pink   antiquepink    #D47479   RAL      Light Carmine Pink   lightcarminepink    #E66771   Wikipedia      Candy Pink   candypink    #E4717A   Wikipedia      Tango Pink   tangopink    #E4717A   Wikipedia      Pale Pink   palepink    #FADADD   Wikipedia      UP Maroon   upmaroon    #7B1113   Wikipedia      OU Crimson Red   oucrimsonred    #841617   Wikipedia      Brown Red   brownred    #7E292C   RAL      Spartan Crimson   spartancrimson    #9E1316   Wikipedia      Medium Red   mediumred    #B10304   Wikipedia      Rose Vale   rosevale    #AB4E52   Wikipedia      Watermelon Red   watermelonred    #BF4147   Wikipedia      Madder Lake   madderlake    #CC3336   Crayola      Bittersweet Shimmer   bittersweetshimmer    #BF4F51   Wikipedia      English Vermilion   englishvermilion    #CC474B   Crayola      English Vermillion   englishvermillion    #CC474B   Wikipedia      Red Strawberry   redstrawberry    #EC0304   Wikipedia      Old Rose   oldrose    #C08081   Wikipedia      Strawberry   strawberry    #FA5053   Wikipedia      Tulip   tulip    #FF878D   Wikipedia      Pale Chestnut   palechestnut    #DDADAF   Wikipedia      Black   black    #000000   CSS      Registration Black   registrationblack    #000000   Wikipedia      Jet Black   jetblack    #0A0A0D   RAL      Eerie Black   eerieblack    #1B1B1B   Wikipedia      Black Brown   blackbrown    #211F20   RAL      Raisin Black   raisinblack    #242124   Wikipedia      Graphite Black   graphiteblack    #292C2F   RAL      Traffic Black   trafficblack    #2A2D2F   RAL      Signal Black   signalblack    #2E3032   RAL      Jet   jet    #343434   Wikipedia      Onyx   onyx    #353839   Wikipedia      Traffic Grey B   trafficgreyb    #4E5451   RAL      Davy's Grey   davysgrey    #555555   Wikipedia      Granite Gray   granitegray    #676767   Wikipedia      Dim Gray   dimgray    #696969   CSS      Dim Grey   dimgrey    #696969   CSS      Nickel   nickel    #727472   Wikipedia      Sonic Silver   sonicsilver    #757575   Wikipedia      Dusty Grey   dustygrey    #7C7F7E   RAL      Gray   gray    #808080   CSS      Grey   grey    #808080   CSS      Neon Gray   neongray    #808080   Wikipedia      Pearl Dark Grey   pearldarkgrey    #7E8182   RAL      Trolley Grey   trolleygrey    #808080   Wikipedia      Battleship Grey   battleshipgrey    #848482   Wikipedia      Old Silver   oldsilver    #848482   Wikipedia      Philippine Gray   philippinegray    #8C8C8C   Wikipedia      Grey Aluminium   greyaluminium    #8F8F8C   RAL      Platinum Grey   platinumgrey    #9A9697   RAL      Spanish Gray   spanishgray    #989898   Wikipedia      Pearl Light Grey   pearllightgrey    #9C9C9C   RAL      Signal Grey   signalgrey    #9EA0A1   RAL      Quick Silver   quicksilver    #A6A6A6   Wikipedia      White Aluminium   whitealuminium    #A5A8A6   RAL      Dark Gray   darkgray    #A9A9A9   CSS      Dark Grey   darkgrey    #A9A9A9   CSS      Metallic Silver   metallicsilver    #A8A9AD   Wikipedia      Silver Chalice   silverchalice    #ACACAC   Wikipedia      Silver Foil   silverfoil    #AFB1AE   Wikipedia      Philippine Silver   philippinesilver    #B3B3B3   Wikipedia      Silver   silver    #C0C0C0   CSS      Silver Sand   silversand    #BFC1C2   Wikipedia      Neon Silver   neonsilver    #CCCCCC   Wikipedia      Telegrey 4   telegreyfour    #CFD0CF   RAL      Light Gray   lightgray    #D3D3D3   CSS      Light Grey   lightgrey    #D3D3D3   CSS      Lightgrey   lightgrey    #D3D3D3   CSS      Light Silver   lightsilver    #D8D8D8   Wikipedia      Gainsboro   gainsboro    #DCDCDC   CSS      Platinum   platinum    #E5E4E2   Wikipedia      Cultured   cultured    #F5F5F5   Wikipedia      Cultured Pearl   culturedpearl    #F5F5F5   Wikipedia      White Smoke   whitesmoke    #F5F5F5   CSS      Zebra White   zebrawhite    #F5F5F5   Wikipedia      Signal White   signalwhite    #F4F8F4   RAL      Lotion   lotion    #FEFDFA   Wikipedia      Baby Powder   babypowder    #FEFEFA   Wikipedia      White   white    #FFFFFF   CSS","ref":"namedcolors.html#hue"},{"type":"extras","title":"Dark - Light - Named Colors","doc":"Name \n         Keyword \n         RGB hex value \n         Source \n         Sample \n       \n     \n     \n        Black   black    #000000   CSS      Registration Black   registrationblack    #000000   Wikipedia      Jet Black   jetblack    #0A0A0D   RAL      Smoky Black   smokyblack    #100C08   Wikipedia      Licorice   licorice    #1A1110   Wikipedia      Root Beer   rootbeer    #290E05   Wikipedia      Eerie Black   eerieblack    #1B1B1B   Wikipedia      Maastricht Blue   maastrichtblue    #001C3D   Wikipedia      Zinnwaldite   zinnwaldite    #2C1608   Wikipedia      Zinnwaldite Brown   zinnwalditebrown    #2C1608   Wikipedia      Black Blue   blackblue    #1D1F2A   RAL      Black Brown   blackbrown    #211F20   RAL      Dark Jungle Green   darkjunglegreen    #1A2421   Wikipedia      Raisin Black   raisinblack    #242124   Wikipedia      Black Bean   blackbean    #3D0C02   Wikipedia      Oxford Blue   oxfordblue    #002147   Wikipedia      Paua   paua    #1F005E   Wikipedia      Dark Purple   darkpurple    #301934   Wikipedia      Dark Sienna   darksienna    #3C1414   Wikipedia      Oxblood   oxblood    #4A0000   Wikipedia      Charleston Green   charlestongreen    #232B2B   Wikipedia      Russian Violet   russianviolet    #32174D   Wikipedia      Graphite Black   graphiteblack    #292C2F   RAL      Navy   navy    #000080   CSS      Navy Blue   navyblue    #000080   Crayola      Temptress   temptress    #3C2126   Wikipedia      Phthalo Green   phthalogreen    #123524   Wikipedia      Traffic Black   trafficblack    #2A2D2F   RAL      Black Red   blackred    #402225   RAL      Midnight Blue   midnightblue    #191970   CSS      Pearl Night Blue   pearlnightblue    #102C54   RAL      Space Cadet   spacecadet    #1D2951   Wikipedia      Medium Jungle Green   mediumjunglegreen    #1C352D   Wikipedia      Sacramento State Green   sacramentostategreen    #043927   Wikipedia      Bottle Green   bottlegreen    #283424   RAL      Dark Blue   darkblue    #00008B   CSS      Prussian Blue   prussianblue    #003153   Wikipedia      Bistre   bistre    #3D2B1F   Wikipedia      Cobalt Blue   cobaltblue    #232D53   RAL      Phthalo Blue   phthaloblue    #000F89   Wikipedia      Signal Black   signalblack    #2E3032   RAL      Black Grey   blackgrey    #2E3234   RAL      Gunmetal   gunmetal    #2a3439   Wikipedia      International Klein Blue   internationalkleinblue    #130a8f   Wikipedia      Fir Green   firgreen    #26392F   RAL      Night Blue   nightblue    #2F2A5A   RAL      Persian Indigo   persianindigo    #32127A   Wikipedia      Purple Violet   purpleviolet    #4A203B   RAL      Vine Green   vinegreen    #164010   Wikipedia      British Racing Green   britishracinggreen    #004225   Wikipedia      Dark Midnight Blue   darkmidnightblue    #003366   Wikipedia      Jet   jet    #343434   Wikipedia      Duke Blue   dukeblue    #00009C   Wikipedia      Outer Space   outerspace    #2D383A   Crayola      Resolution Blue   resolutionblue    #002387   Wikipedia      UP Forest Green   upforestgreen    #014421   Wikipedia      Brown Green   browngreen    #35382E   RAL      Old Burgundy   oldburgundy    #43302E   Wikipedia      Rich Black   richblack    #004040   Wikipedia      Yale Blue   yaleblue    #00356B   Wikipedia      Light Chocolate Cosmos   lightchocolatecosmos    #551F2F   Wikipedia      Onyx   onyx    #353839   Wikipedia      Philippine Brown   philippinebrown    #5D1916   Wikipedia      Rosewood   rosewood    #65000B   Wikipedia      St. Patrick's Blue   stpatricksblue    #23297A   Wikipedia      Warm Black   warmblack    #004242   Wikipedia      Blood Red   bloodred    #660000   Wikipedia      Blue Green   bluegreen    #0E4243   RAL      Blue Ribbon   blueribbon    #0B10A2   Wikipedia      Chocolate Brown   chocolatebrown    #44322D   RAL      Mahogany Brown   mahoganybrown    #4C2F26   RAL      Ocean Blue   oceanblue    #0B4151   RAL      Seal Brown   sealbrown    #59260B   Wikipedia      Grey Blue   greyblue    #313C48   RAL      MSU Green   msugreen    #18453B   Wikipedia      Black Olive   blackolive    #3B3C36   RAL      Café Noir   cafenoir    #4B3621   Wikipedia      Spanish Purple   spanishpurple    #66033C   Wikipedia      Tyrian Purple   tyrianpurple    #66023C   Wikipedia      Wine Red   winered    #5E2028   RAL      Zaffre   zaffre    #0014A8   Wikipedia      Black Green   blackgreen    #31403D   RAL      Grey Brown   greybrown    #3F3A3A   RAL      Indigo   indigo    #4B0082   CSS      Kombu Green   kombugreen    #354230   Wikipedia      Olive-drab/brown Olive   brownolive    #3E3C32   RAL      Picotee Blue   picoteeblue    #2E2787   Wikipedia      Anthracite Grey   anthracitegrey    #373F43   RAL      Indigo Dye   indigodye    #00416A   Wikipedia      Philippine Indigo   philippineindigo    #00416A   Wikipedia      Sepia Brown   sepiabrown    #49392D   RAL      Samsung Blue   samsungblue    #12279E   Wikipedia      Trypan Blue   trypanblue    #1C05B3   Wikipedia      Claret Violet   claretviolet    #691639   RAL      Cosmic Cobalt   cosmiccobalt    #2E2D88   Wikipedia      Dark Lava   darklava    #483C32   Wikipedia      Deep Jungle Green   deepjunglegreen    #004B49   Wikipedia      Midnight Green   midnightgreen    #004953   Wikipedia      Taupe   taupe    #483C32   Wikipedia      Chrome Green   chromegreen    #354733   RAL      Terra Brown   terrabrown    #4E3B2B   RAL      Granite Grey   granitegrey    #374447   RAL      Grey Olive   greyolive    #40433B   RAL      Pearl Ruby Red   pearlrubyred    #711521   RAL      Charcoal   charcoal    #36454F   Wikipedia      Drab Dark Brown   drabdarkbrown    #4A412A   Wikipedia      Persian Plum   persianplum    #701C1C   Wikipedia      Pineapple   pineapple    #563C0D   Wikipedia      Prune   prune    #701C1C   Wikipedia      Royal Brown   royalbrown    #523B35   Wikipedia      Yellow Olive   yellowolive    #444337   RAL      Purple Red   purplered    #701F29   RAL      Barn Red   barnred    #7C0A02   Wikipedia      Dark Liver   darkliver    #543D37   Wikipedia      Gentian Blue   gentianblue    #13447C   RAL      Nut Brown   nutbrown    #5A3A29   RAL      Pearl Green   pearlgreen    #1B542C   RAL      Spanish Violet   spanishviolet    #4C2882   Wikipedia      Egyptian Blue   egyptianblue    #1034A6   Wikipedia      Japanese Violet   japaneseviolet    #5B3256   Wikipedia      Medium Blue   mediumblue    #0000CD   CSS      UA Blue   uablue    #0033AA   Wikipedia      UP Maroon   upmaroon    #7B1113   Wikipedia      Gotham Green   gothamgreen    #00573F   Wikipedia      Lincoln Green   lincolngreen    #195905   Wikipedia      Maroon   maroon    #800000   CSS      Metallic Violet   metallicviolet    #5B0A91   Wikipedia      Burgundy   burgundy    #800020   Wikipedia      Dark Slate Gray   darkslategray    #2F4F4F   CSS      Dark Slate Grey   darkslategrey    #2F4F4F   CSS      KSU Purple   ksupurple    #512888   Wikipedia      Philippine Blue   philippineblue    #0038A7   Wikipedia      Purple Taupe   purpletaupe    #50404D   Wikipedia      Royal Azure   royalazure    #0038A8   Wikipedia      Chestnut Brown   chestnutbrown    #633A34   RAL      Old Mauve   oldmauve    #673147   Wikipedia      Palatinate Purple   palatinatepurple    #682860   Wikipedia      Rifle Green   riflegreen    #444C38   Wikipedia      Wine Dregs   winedregs    #673147   Wikipedia      Dark Byzantium   darkbyzantium    #5D3954   Wikipedia      English Violet   englishviolet    #563C5C   Wikipedia      Falu Red   falured    #801818   Wikipedia      Old Heliotrope   oldheliotrope    #563C5C   Wikipedia      Pansy Purple   pansypurple    #78184A   Wikipedia      Red Brown   redbrown    #673831   RAL      Signal Blue   signalblue    #154889   RAL      Claret   claret    #7F1734   Wikipedia      Graphite Grey   graphitegrey    #474A50   RAL      Puce Red   pucered    #722F37   Wikipedia      Pullman Brown   pullmanbrown    #644117   Wikipedia      Seance   seance    #612086   Wikipedia      UPS Brown   upsbrown    #644117   Wikipedia      Wine   wine    #722F37   Wikipedia      OU Crimson Red   oucrimsonred    #841617   Wikipedia      Philippine Bronze   philippinebronze    #6E3A07   Wikipedia      Dark Brown   darkbrown    #654321   Wikipedia      Dark Red   darkred    #8B0000   CSS      Finn   finn    #683068   Wikipedia      Opal Green   opalgreen    #005D52   RAL      Otter Brown   otterbrown    #654321   Wikipedia      Oxide Red   oxidered    #703731   RAL      Pearl Opal Green   pearlopalgreen    #005D4C   RAL      Quartz   quartz    #51484F   Wikipedia      Royal Green   royalgreen    #136207   Wikipedia      Umbra Grey   umbragrey    #4B4D46   RAL      Van Dyke Brown   vandykebrown    #664228   Crayola      Antique Ruby   antiqueruby    #841B2D   Wikipedia      Brown Red   brownred    #7E292C   RAL      Byzantium   byzantium    #702963   Wikipedia      Catawba   catawba    #703642   Wikipedia      Dark Green   darkgreen    #006400   CSS      Dark Slate Blue   darkslateblue    #483D8B   CSS      Eggplant   eggplant    #614051   Crayola      Garnet   garnet    #733635   Wikipedia      Police Blue   policeblue    #374F6B   Wikipedia      Violin Brown   violinbrown    #674403   Wikipedia      Midnight   midnight    #702670   Wikipedia      Pakistan Green   pakistangreen    #006600   Wikipedia      Persian Blue   persianblue    #1C39BB   Wikipedia      Kobicha   kobicha    #6B4423   Wikipedia      Smokey Topaz   smokeytopaz    #832A0D   Wikipedia      Traffic Blue   trafficblue    #0E518D   RAL      USAFA Blue   usafablue    #004F98   Wikipedia      Hunter Green   huntergreen    #355E3B   Wikipedia      Leaf Green   leafgreen    #276235   RAL      Medium Electric Blue   mediumelectricblue    #035096   Wikipedia      Metallic Blue   metallicblue    #32527B   Wikipedia      Mughal Green   mughalgreen    #306030   Wikipedia      Sepia   sepia    #704214   Crayola      Capri Blue   capriblue    #1A5784   RAL      Cyber Grape   cybergrape    #58427C   Wikipedia      Pearl Copper   pearlcopper    #773C27   RAL      Carmine   carmine    #960018   Crayola      Denim Blue   denimblue    #2243B6   Wikipedia      Eminence   eminence    #6C3082   Wikipedia      Kobe   kobe    #882D17   Wikipedia      Patriarch   patriarch    #800080   Wikipedia      Purple   purple    #800080   CSS      Roast Coffee   roastcoffee    #704241   Wikipedia      Rose Ebony   roseebony    #674846   Wikipedia      Traffic Grey B   trafficgreyb    #4E5451   RAL      YInMn Blue   yinmnblue    #2E5090   Wikipedia      Azure Blue   azureblue    #2E5978   RAL      Dark Moss Green   darkmossgreen    #4A5D23   Wikipedia      Independence   independence    #4C516D   Wikipedia      Philippine Violet   philippineviolet    #81007F   Wikipedia      Absolute Zero   absolutezero    #0048BA   Wikipedia      Brown Grey   browngrey    #555548   RAL      Cadmium Green   cadmiumgreen    #006B3C   Wikipedia      Liver   liver    #674C47   Wikipedia      Medium Taupe   mediumtaupe    #674C47   Wikipedia      Dark Raspberry   darkraspberry    #872657   Wikipedia      Davy's Grey   davysgrey    #555555   Wikipedia      Fawn Brown   fawnbrown    #6F4A2F   RAL      Rebecca Purple   rebeccapurple    #663399   CSS      Blue   blue    #0000FF   CSS      Burnt Umber   burntumber    #8A3324   Crayola      Maximum Purple   maximumpurple    #733380   Crayola      Ruby Red   rubyred    #9B111E   RAL      Umber   umber    #635147   Wikipedia      Vivid Auburn   vividauburn    #922724   Wikipedia      Blue Sapphire   bluesapphire    #126180   Wikipedia      Bole   bole    #79443B   Wikipedia      Coffee   coffee    #6F4E37   Wikipedia      Feldgrau   feldgrau    #4D5D53   Wikipedia      Mardi Gras   mardigras    #880085   Wikipedia      Medium Tuscan Red   mediumtuscanred    #79443B   Wikipedia      Metallic Green   metallicgreen    #296E01   Wikipedia      Olive Brown   olivebrown    #6F4F28   RAL      Purple Navy   purplenavy    #4E5180   Wikipedia      Tuscan Brown   tuscanbrown    #6F4E37   Wikipedia      Violet-blue   violetblue    #324AB2   RAL      B'dazzled Blue   bdazzledblue    #2E5894   Wikipedia      Dartmouth Green   dartmouthgreen    #00703C   Wikipedia      Field Drab   fielddrab    #6C541E   Wikipedia      Spartan Crimson   spartancrimson    #9E1316   Wikipedia      Dark Magenta   darkmagenta    #8B008B   CSS      Ebony   ebony    #555D50   Wikipedia      Royal Red   royalred    #9B1C31   Wikipedia      Russet   russet    #80461B   Wikipedia      Sapphire   sapphire    #0F52BA   Wikipedia      Solid Pink   solidpink    #893843   Wikipedia      Wenge   wenge    #645452   Wikipedia      Fuzzy Wuzzy   fuzzywuzzy    #87421F   Crayola      Pearl Gentian Blue   pearlgentianblue    #296478   RAL      Quincy   quincy    #6A5445   Wikipedia      Antique Bronze   antiquebronze    #665D1E   Wikipedia      Dark Spring Green   darkspringgreen    #177245   Wikipedia      Iron Grey   irongrey    #555D61   RAL      Mud   mud    #70543E   Wikipedia      Palatinate Blue   palatinateblue    #273BE2   Wikipedia      Secret   secret    #764374   Wikipedia      Tarpaulin Grey   tarpaulingrey    #575D57   RAL      Tuscan Red   tuscanred    #7C4848   Wikipedia      University Of Pennsylvania Red   universityofpennsylvaniared    #A50021   Wikipedia      Cordovan   cordovan    #893F45   Wikipedia      Dark Fuchsia   darkfuchsia    #A00955   Wikipedia      Emerald Green   emeraldgreen    #28713E   RAL      Maximum Violet   maximumviolet    #892F77   Wikipedia      New Car   newcar    #214FC6   Wikipedia      Purple Heart   purpleheart    #652DC1   Crayola      Signal Red   signalred    #A02128   RAL      Vivid Burgundy   vividburgundy    #9F1D35   Wikipedia      Big Dip O'ruby   bigdiporuby    #9C2542   Wikipedia      Carmine Red   carminered    #A1232B   RAL      Cerulean Blue   ceruleanblue    #2A52BE   Crayola      Japanese Carmine   japanesecarmine    #9D2933   Wikipedia      La Salle Green   lasallegreen    #087830   Wikipedia      Lapis Lazuli   lapislazuli    #26619C   Wikipedia      Rojo Spanish Red   rojospanishred    #A91101   Wikipedia      Saddle Brown   saddlebrown    #8B4513   CSS      Ultramarine   ultramarine    #3F00FF   Wikipedia      Deep Space Sparkle   deepspacesparkle    #4A646C   Wikipedia      Plump Purple   plumppurple    #5946B2   Wikipedia      Quinacridone Magenta   quinacridonemagenta    #8E3A59   Wikipedia      Rufous   rufous    #A81C07   Wikipedia      Signal Brown   signalbrown    #7B5141   RAL      Basalt Grey   basaltgrey    #596163   RAL      Beige Brown   beigebrown    #79553C   RAL      Green Grey   greengrey    #5B6259   RAL      Sea Blue   seablue    #006994   Wikipedia      Tomato Red   tomatored    #9C322E   RAL      Tropical Rainforest   tropicalrainforest    #00755E   Crayola      Black Coral   blackcoral    #54626F   Wikipedia      Clay Brown   claybrown    #80542F   RAL      Dark Olive Green   darkolivegreen    #556B2F   CSS      Flirt   flirt    #A2006D   Wikipedia      Jazzberry Jam   jazzberryjam    #A50B5E   Crayola      Medium Green   mediumgreen    #037949   Wikipedia      Mordant Red 19   mordantred    #AE0C00   Wikipedia      Traffic Purple   trafficpurple    #992572   RAL      Artichoke Green   artichokegreen    #4B6F44   Wikipedia      Brown   brown    #A52A2A   CSS      Han Purple   hanpurple    #5218FA   Wikipedia      Medium Persian Blue   mediumpersianblue    #0067A5   Wikipedia      Medium Red   mediumred    #B10304   Wikipedia      Red Rum   redrum    #973A4A   Wikipedia      Sapphire Blue   sapphireblue    #0067A5   RAL      Skobeloff   skobeloff    #007474   Wikipedia      Water Blue   waterblue    #07737A   RAL      Denim   denim    #1560BD   Crayola      Flame Red   flamered    #AB2524   RAL      Grass Green   grassgreen    #3E753B   RAL      Green   green    #008000   CSS      Green-blue   greenblue    #1164B4   RAL      Metallic Red   metallicred    #A62C2B   Wikipedia      Office Green   officegreen    #008000   Wikipedia      Pale Brown   palebrown    #755C49   RAL      Pearl Orange   pearlorange    #954527   RAL      Amaranth Deep Purple   amaranthdeeppurple    #9F2B68   Wikipedia      Brilliant Blue   brilliantblue    #41678D   RAL      Cadet   cadet    #536872   Wikipedia      Chestnut   chestnut    #954535   Crayola      Salem   salem    #177B4D   Wikipedia      Tomato Sauce   tomatosauce    #B21807   Wikipedia      Upsdell Red   upsdellred    #AE2029   Wikipedia      Carnelian   carnelian    #B31B1B   Wikipedia      Copper Brown   copperbrown    #8F4E35   RAL      Dark Electric Blue   darkelectricblue    #536878   Wikipedia      Liberty   liberty    #545AA7   Wikipedia      Milk Chocolate   milkchocolate    #84563C   Wikipedia      Patina Green   patinagreen    #327662   RAL      Payne's Grey   paynesgrey    #536878   Wikipedia      Pine Green   pinegreen    #01796F   RAL      Distant Blue   distantblue    #4D668E   RAL      Firebrick   firebrick    #B22222   CSS      Napier Green   napiergreen    #2A8000   Wikipedia      Twilight Lavender   twilightlavender    #8A496B   Wikipedia      Amaranth Purple   amaranthpurple    #AB274F   Wikipedia      Blue Grey   bluegrey    #5D6970   RAL      French Violet   frenchviolet    #8806CE   Wikipedia      Honolulu Blue   honolulublue    #006DB0   Wikipedia      Spanish Viridian   spanishviridian    #007F5C   Wikipedia      Sweet Brown   sweetbrown    #A83731   Wikipedia      Amazon   amazon    #3B7A57   Wikipedia      Chinese Red   chinesered    #AA381E   Wikipedia      Generic Viridian   genericviridian    #007F66   Wikipedia      Granite Gray   granitegray    #676767   Wikipedia      International Orange   internationalorange    #BA160C   Wikipedia      Khaki Grey   khakigrey    #746643   RAL      Ming   ming    #36747D   Wikipedia      Myrtle Green   myrtlegreen    #317873   Wikipedia      Orient Red   orientred    #AC323B   RAL      Queen Blue   queenblue    #436B95   Wikipedia      Coyote Brown   coyotebrown    #81613C   Wikipedia      Neon Dark Green   neondarkgreen    #008443   Wikipedia      Philippine Green   philippinegreen    #008543   Wikipedia      Raspberry Red   raspberryred    #B42041   RAL      Deep Taupe   deeptaupe    #7E5E60   Wikipedia      Dim Gray   dimgray    #696969   CSS      Dim Grey   dimgrey    #696969   CSS      Electric Indigo   electricindigo    #6F00FF   Wikipedia      Fern Green   ferngreen    #4F7942   RAL      India Green   indiagreen    #138808   Wikipedia      Iris   iris    #5A4FCF   Wikipedia      Mustard Green   mustardgreen    #6E6E30   Wikipedia      Quartz Grey   quartzgrey    #6B695F   RAL      Rum   rum    #9A4E40   Wikipedia      Signal Violet   signalviolet    #904684   RAL      Teal Blue   tealblue    #367588   Crayola      Pearl Gold   pearlgold    #80643F   RAL      Sap Green   sapgreen    #507D2A   Wikipedia      Signal Green   signalgreen    #0F8558   RAL      Spanish Blue   spanishblue    #0070B8   Wikipedia      True Blue   trueblue    #2D68C4   Wikipedia      Berry Parfait   berryparfait    #A43482   Wikipedia      Hooker's Green   hookersgreen    #49796B   Wikipedia      Metallic Brown   metallicbrown    #AC4313   Wikipedia      Razzmic Berry   razzmicberry    #8D4E85   Wikipedia      Royal Purple   royalpurple    #7851A9   Crayola      Sugar Plum   sugarplum    #914E75   Wikipedia      Teal   teal    #008080   CSS      Traffic Green   trafficgreen    #008754   RAL      Traffic Red   trafficred    #C1121C   RAL      Charcoal Gray   charcoalgray    #736A62   Crayola      Coral Red   coralred    #AC4034   RAL      Dark Venetian Red   darkvenetianred    #B33B24   Crayola      Dark Violet   darkviolet    #9400D3   CSS      French Blue   frenchblue    #0072BB   Wikipedia      Metallic Seaweed   metallicseaweed    #0A7E8C   Wikipedia      Pearl Blackberry   pearlblackberry    #6B6880   RAL      Raw Umber   rawumber    #826644   Crayola      Rich Maroon   richmaroon    #B03060   Wikipedia      Spicy Mix   spicymix    #8B5f4D   Wikipedia      Teal Green   tealgreen    #00827F   Wikipedia      Coconut   coconut    #965A3E   Wikipedia      Dark Blue-gray   darkbluegray    #666699   Wikipedia      Forest Green   forestgreen    #228B22   CSS      Magenta Haze   magentahaze    #9F4576   Wikipedia      Maximum Red Purple   maximumredpurple    #A63A79   Crayola      Medium Carmine   mediumcarmine    #AF4035   Wikipedia      Pale Carmine   palecarmine    #AF4035   Wikipedia      Sienna   sienna    #A0522D   CSS      Cerulean   cerulean    #007BA7   Crayola      Lemon Iced Tea   lemonicedtea    #BD3000   Wikipedia      Majorelle Blue   majorelleblue    #6050DC   Wikipedia      Pictorial Carmine   pictorialcarmine    #C30B4E   Wikipedia      Poison Purple   poisonpurple    #7F01FE   Wikipedia      Venetian Red   venetianred    #C80815   Crayola      Beige Grey   beigegrey    #756F61   RAL      Cardinal   cardinal    #C41E3A   Wikipedia      Medium Ruby   mediumruby    #AA4069   Wikipedia      Mouse Grey   mousegrey    #6B716F   RAL      Ocean Boat Blue   oceanboatblue    #0077BE   Wikipedia      Old Lavender   oldlavender    #796878   Wikipedia      Pastel Brown   pastelbrown    #836953   Wikipedia      Red Lilac   redlilac    #8A5A83   RAL      Rose Taupe   rosetaupe    #905D5D   Wikipedia      Blue Violet   blueviolet    #8A2BE2   CSS      Blue-violet   blueviolet    #8A2BE2   CSS      Bright Maroon   brightmaroon    #C32148   Wikipedia      Rose Red   rosered    #C21E56   Wikipedia      Rust   rust    #B7410E   Wikipedia      Viridian   viridian    #40826D   Wikipedia      Windsor Tan   windsortan    #A75502   Wikipedia      Blue Yonder   blueyonder    #5072A7   Wikipedia      Chinese Violet   chineseviolet    #856088   Wikipedia      English Red   englishred    #AB4B52   Wikipedia      Medium Violet   mediumviolet    #8F47B3   Crayola      Sea Green   seagreen    #2E8B57   CSS      Star Command Blue   starcommandblue    #007BB8   Wikipedia      Vivid Crimson   vividcrimson    #CC0033   Wikipedia      French Bistre   frenchbistre    #856D4D   Wikipedia      French Lilac   frenchlilac    #86608E   Wikipedia      Golden Brown   goldenbrown    #996515   Wikipedia      Lava   lava    #CF1020   Wikipedia      Mauve Taupe   mauvetaupe    #915F6D   Wikipedia      Middle Red Purple   middleredpurple    #A55353   Crayola      Philippine Red   philippinered    #CE1127   Wikipedia      Pomp And Power   pompandpower    #86608E   Wikipedia      Raspberry Glacé   raspberryglace    #915F6D   Wikipedia      Rose Vale   rosevale    #AB4E52   Wikipedia      Slate Blue   slateblue    #6A5ACD   CSS      Spanish Green   spanishgreen    #009150   Wikipedia      Antique Fuchsia   antiquefuchsia    #915C83   Wikipedia      Bright Navy Blue   brightnavyblue    #1974D2   Wikipedia      Dark Orchid   darkorchid    #9932CC   CSS      Han Blue   hanblue    #446CCF   Wikipedia      Mystic Maroon   mysticmaroon    #AD4379   Wikipedia      Nickel   nickel    #727472   Wikipedia      Spanish Bistre   spanishbistre    #807532   Wikipedia      Stop Red   stopred    #CF142B   Wikipedia      Dark Cyan   darkcyan    #008B8B   CSS      Electric Violet   electricviolet    #8F00FF   Wikipedia      Fandango   fandango    #B53389   Wikipedia      Fire Engine Red   fireenginered    #CE2029   Wikipedia      French Raspberry   frenchraspberry    #C72C48   Wikipedia      Green Brown   greenbrown    #887142   RAL      Mahogany   mahogany    #C04000   Crayola      Pearl Pink   pearlpink    #B24C43   RAL      Philippine Sky Blue   philippineskyblue    #0066FF   Wikipedia      Redwood   redwood    #A45A52   Wikipedia      Rosso Corsa   rossocorsa    #D40000   Wikipedia      Royal Blue   royalblue    #4169E1   CSS      Blue Lilac   bluelilac    #83639D   RAL      Bluetiful   bluetiful    #3C69E7   Crayola      Dingy Dungeon   dingydungeon    #C53151   Wikipedia      Irresistible   irresistible    #B3446C   Wikipedia      Microsoft Edge Blue   microsoftedgeblue    #0078D7   Wikipedia      Orange Brown   orangebrown    #A65E2F   RAL      Raspberry Rose   raspberryrose    #B3446C   Wikipedia      Slimy Green   slimygreen    #299617   Wikipedia      Sonic Silver   sonicsilver    #757575   Wikipedia      Spanish Carmine   spanishcarmine    #D10047   Wikipedia      Gold Fusion   goldfusion    #85754E   Wikipedia      Medium Red-violet   mediumredviolet    #BB3385   Wikipedia      Rubine Red   rubinered    #D10056   Wikipedia      Watermelon Red   watermelonred    #BF4147   Wikipedia      Medium Violet Red   mediumvioletred    #C71585   CSS      Medium Violet-red   mediumvioletred    #C71585   CSS      Middle Green   middlegreen    #4D8C57   Crayola      Ochre Brown   ochrebrown    #9C6B30   RAL      Persian Red   persianred    #CC3333   Wikipedia      Purpureus   purpureus    #9A4EAE   Wikipedia      Red-violet   redviolet    #C71585   RAL      Reseda Green   resedagreen    #68825B   RAL      Rose Dust   rosedust    #9E5E6F   Wikipedia      Ultramarine Blue   ultramarineblue    #4166F5   RAL      Bistre Brown   bistrebrown    #967117   Wikipedia      Copper Rose   copperrose    #996666   Wikipedia      Deep Chestnut   deepchestnut    #B94E48   Wikipedia      Madder Lake   madderlake    #CC3336   Crayola      Maximum Green   maximumgreen    #5E8C31   Crayola      Mode Beige   modebeige    #967117   Wikipedia      Olive   olive    #808000   CSS      Reed Green   reedgreen    #797C5A   RAL      Rich Carmine   richcarmine    #D70040   Wikipedia      Sand Dune   sanddune    #967117   Wikipedia      Sandy Taupe   sandytaupe    #967117   Wikipedia      Illuminating Emerald   illuminatingemerald    #319177   Wikipedia      May Green   maygreen    #4C9141   RAL      Mint Turquoise   mintturquoise    #478A84   RAL      Moss Grey   mossgrey    #7A7B6D   RAL      UA Red   uared    #D9004C   Wikipedia      Green-cyan   greencyan    #009966   Wikipedia      Maximum Red   maximumred    #D92121   Crayola      Neon Blue   neonblue    #4666FF   Wikipedia      Purple Plum   purpleplum    #9C51B6   Wikipedia      Red Cola   redcola    #DF0118   Wikipedia      Rhythm   rhythm    #777696   Wikipedia      Sinopia   sinopia    #CB410B   Wikipedia      Veronica   veronica    #A020F0   Wikipedia      Vivid Violet   vividviolet    #9F00FF   Crayola      Wintergreen Dream   wintergreendream    #56887D   Wikipedia      Crimson   crimson    #DC143C   CSS      Old Moss Green   oldmossgreen    #867E36   Wikipedia      Pigeon Blue   pigeonblue    #6C7C98   RAL      Steel Blue   steelblue    #4682B4   CSS      Bittersweet Shimmer   bittersweetshimmer    #BF4F51   Wikipedia      Byzantine   byzantine    #BD33A4   Wikipedia      Dogwood Rose   dogwoodrose    #D71868   Wikipedia      Olive Drab   olivedrab    #6B8E23   CSS      Olivedrab   olivedrab    #6B8E23   CSS      Shadow   shadow    #8A795D   Crayola      Smoke   smoke    #738276   Wikipedia      Brick Red   brickred    #CB4154   Crayola      Cadmium Red   cadmiumred    #E30022   Wikipedia      Liver Chestnut   liverchestnut    #987456   Wikipedia      Medium Candy Apple Red   mediumcandyapplered    #E2062C   Wikipedia      Nintendo Red   nintendored    #E4000F   Wikipedia      Olive Grey   olivegrey    #817F68   RAL      Popstar   popstar    #BE4F62   Wikipedia      Shamrock Green   shamrockgreen    #009E60   Wikipedia      Slate Gray   slategray    #708090   CSS      Slate Grey   slategrey    #708090   CSS      Slategrey   slategrey    #708090   CSS      Celestial Blue   celestialblue    #7070CC   Crayola      Dusty Grey   dustygrey    #7C7F7E   RAL      Light Brown   lightbrown    #B5651D   Wikipedia      Paolo Veronese Green   paoloveronesegreen    #009B7D   Wikipedia      Royal Fuchsia   royalfuchsia    #CA2C92   Wikipedia      Rusty Red   rustyred    #DA2C43   Wikipedia      Spanish Red   spanishred    #E60026   Wikipedia      Telemagenta   telemagenta    #CF3476   RAL      Viridian Green   viridiangreen    #009698   Wikipedia      Alizarin   alizarin    #DB2D43   Wikipedia      Dirt   dirt    #9B7653   Wikipedia      English Vermilion   englishvermilion    #CC474B   Crayola      English Vermillion   englishvermillion    #CC474B   Wikipedia      Fuchsia Purple   fuchsiapurple    #CC397B   Wikipedia      Fuchsia Rose   fuchsiarose    #C74375   Wikipedia      Pearl Violet   pearlviolet    #8773A1   RAL      Ruby   ruby    #E0115F   Wikipedia      Steel Teal   steelteal    #5F8A8F   Wikipedia      Syracuse Orange   syracuseorange    #D44500   Wikipedia      Vivid Mulberry   vividmulberry    #B80CE3   Wikipedia      Xanadu   xanadu    #738678   Wikipedia      Glaucous   glaucous    #6082B6   Wikipedia      Gray   gray    #808080   CSS      Grey   grey    #808080   CSS      Neon Gray   neongray    #808080   Wikipedia      Pearl Dark Grey   pearldarkgrey    #7E8182   RAL      Permanent Geranium Lake   permanentgeraniumlake    #E12C2C   Crayola      Raspberry   raspberry    #E30B5D   Wikipedia      Smitten   smitten    #C84186   Wikipedia      Strawberry Red   strawberryred    #D14152   RAL      Trolley Grey   trolleygrey    #808080   Wikipedia      Barbie Pink   barbiepink    #DA1884   Wikipedia      Burnt Orange   burntorange    #CC5500   Crayola      Lust   lust    #E62020   Wikipedia      Metallic Bronze   metallicbronze    #A97142   Wikipedia      Metallic Sunburst   metallicsunburst    #9C7C38   Wikipedia      Red Strawberry   redstrawberry    #EC0304   Wikipedia      Rose Madder   rosemadder    #E32636   Wikipedia      Spanish Crimson   spanishcrimson    #E51A4C   Wikipedia      Very Light Blue   verylightblue    #6666FF   Wikipedia      Vivid Cerise   vividcerise    #DA1D81   Wikipedia      Blast-off Bronze   blastoffbronze    #A57164   Wikipedia      Brown Sugar   brownsugar    #AF6E4D   Wikipedia      Concrete Grey   concretegrey    #818479   RAL      Dark Tan   darktan    #918151   Wikipedia      Pearl Mouse Grey   pearlmousegrey    #888175   RAL      Pure Red   purered    #E72512   RAL      Rackley   rackley    #5D8AA8   Wikipedia      Rocket Metallic   rocketmetallic    #8A7F80   Wikipedia      Russian Green   russiangreen    #679267   Wikipedia      Tawny   tawny    #CD5700   Wikipedia      Tenné   tenne    #CD5700   Wikipedia      Alloy Orange   alloyorange    #C46210   Wikipedia      Cerise   cerise    #DE3163   Crayola      Lavender Indigo   lavenderindigo    #9457EB   Wikipedia      Mulberry   mulberry    #C54B8C   Crayola      Navy Purple   navypurple    #9457EB   Wikipedia      Neon Purple   neonpurple    #9457EB   Wikipedia      Philippine Gold   philippinegold    #B17304   Wikipedia      Red-purple   redpurple    #E40078   Wikipedia      Ruber   ruber    #CE4676   Wikipedia      Amaranth   amaranth    #E52B50   Wikipedia      Battleship Grey   battleshipgrey    #848482   Wikipedia      Cedar Chest   cedarchest    #C95A49   Wikipedia      Copper Penny   copperpenny    #AD6F69   Wikipedia      Medium Slate Blue   mediumslateblue    #7B68EE   CSS      Mediumslate Blue   mediumslateblue    #7B68EE   CSS      Mexican Pink   mexicanpink    #E4007C   Wikipedia      Middle Blue Purple   middlebluepurple    #8B72BE   Crayola      Old Silver   oldsilver    #848482   Wikipedia      Razzmatazz   razzmatazz    #E3256B   Crayola      Rich Electric Blue   richelectricblue    #0892D0   Wikipedia      Silver Lake Blue   silverlakeblue    #5D89BA   Wikipedia      Cement Grey   cementgrey    #818979   RAL      Chili Red   chilired    #E23D28   Wikipedia      Deep Cerise   deepcerise    #DA3287   Wikipedia      Light Slate Gray   lightslategray    #778899   CSS      Light Slate Grey   lightslategrey    #778899   CSS      Lightslate Gray   lightslategray    #778899   CSS      Lightslategrey   lightslategrey    #778899   CSS      Pearl Beige   pearlbeige    #908370   RAL      Amethyst   amethyst    #9966CC   Wikipedia      Burnished Brown   burnishedbrown    #A17A74   Wikipedia      Café Au Lait   cafeaulait    #A67B5B   Wikipedia      Curry   curry    #A77F0E   RAL      French Beige   frenchbeige    #A67B5B   Wikipedia      Jade   jade    #00A86B   Wikipedia      Mountbatten Pink   mountbattenpink    #997A8D   Wikipedia      Titanium   titanium    #878681   Wikipedia      Tuscan Tan   tuscantan    #A67B5B   Wikipedia      Bleu De France   bleudefrance    #318CE7   Wikipedia      Cinnabar   cinnabar    #E34234   Wikipedia      Copper   copper    #B87333   Crayola      Electric Purple   electricpurple    #BF00FF   Wikipedia      GO Green   gogreen    #00AB66   Wikipedia      Imperial Red   imperialred    #ED2939   Wikipedia      Luminous Red   luminousred    #F70000   RAL      Middle Grey   middlegrey    #8B8680   Wikipedia      Taupe Gray   taupegray    #8B8589   Wikipedia      Vermilion   vermilion    #E34234   RAL      Cinereous   cinereous    #98817B   Wikipedia      Indian Red   indianred    #CD5C5C   CSS      Squirrel Grey   squirrelgrey    #7E8B92   RAL      Telegrey 2   telegreytwo    #82898E   RAL      Tufts Blue   tuftsblue    #3E8EDE   Wikipedia      Vivid Red   vividred    #F70D1A   Wikipedia      Beaver   beaver    #9F8170   Crayola      Mummy's Tomb   mummystomb    #828E84   Wikipedia      Persian Green   persiangreen    #00A693   Wikipedia      Roman Silver   romansilver    #838996   Wikipedia      Shadow Blue   shadowblue    #778BA5   Wikipedia      Steel Pink   steelpink    #CC33CC   Wikipedia      Oxley   oxley    #6D9A79   Wikipedia      Paradise Pink   paradisepink    #E63E62   Wikipedia      Purple Mountain Majesty   purplemountainmajesty    #9678B6   Wikipedia      Weezy Blue   weezyblue    #189BCC   Wikipedia      Blueberry   blueberry    #4F86F7   Wikipedia      Lavender Purple   lavenderpurple    #967BB6   Wikipedia      Luminous Bright Red   luminousbrightred    #FF0000   RAL      Medium Purple   mediumpurple    #9370DB   CSS      Mediumpurple   mediumpurple    #9370DB   CSS      Neon Brown   neonbrown    #C3732A   Wikipedia      Pearly Purple   pearlypurple    #B768A2   Wikipedia      Red   red    #FF0000   CSS      Traffic Orange   trafficorange    #E15501   RAL      Turkish Rose   turkishrose    #B57281   Wikipedia      Brown Beige   brownbeige    #AF804F   RAL      Candy Apple Red   candyapplered    #FF0800   Wikipedia      Deep Fuchsia   deepfuchsia    #C154C1   Wikipedia      Medium Orchid   mediumorchid    #BA55D3   CSS      Mediumorchid   mediumorchid    #BA55D3   CSS      Mystic   mystic    #D65282   Wikipedia      Pastel Blue   pastelblue    #6A93B0   RAL      Philippine Gray   philippinegray    #8C8C8C   Wikipedia      Signal Orange   signalorange    #D4652F   RAL      Tractor Red   tractorred    #FD0E35   Wikipedia      Zomp   zomp    #39A78E   Wikipedia      Chocolate   chocolate    #D2691E   CSS      Cinnamon Satin   cinnamonsatin    #CD607E   Wikipedia      Cocoa Brown   cocoabrown    #D2691E   Wikipedia      Dodger Blue   dodgerblue    #1E90FF   CSS      Flame   flame    #E25822   Wikipedia      Jungle Green   junglegreen    #29AB87   Crayola      Medium Vermilion   mediumvermilion    #D9603B   Wikipedia      Neon Red   neonred    #FF1818   Wikipedia      Rich Lavender   richlavender    #A76BCF   Wikipedia      Vivid Orchid   vividorchid    #CC00FF   Wikipedia      Cadet Blue   cadetblue    #5F9EA0   CSS      Copper Red   copperred    #CB6D51   Wikipedia      Heather Violet   heatherviolet    #D15B8F   RAL      Luminous Orange   luminousorange    #FF2300   RAL      Neon Scarlet   neonscarlet    #FF2603   Wikipedia      Scarlet   scarlet    #FF2400   Crayola      United Nations Blue   unitednationsblue    #009EDB   Wikipedia      Asparagus   asparagus    #7BA05B   Crayola      Grey Aluminium   greyaluminium    #8F8F8C   RAL      Metallic Orange   metallicorange    #DA680F   Wikipedia      Moss Green   mossgreen    #8A9A5B   RAL      Royal Pink   royalpink    #E73895   Wikipedia      Turtle Green   turtlegreen    #8A9A5B   Wikipedia      Vivid Red-tangelo   vividredtangelo    #DF6124   Wikipedia      Yellow Grey   yellowgrey    #939176   RAL      Dark Goldenrod   darkgoldenrod    #B8860B   CSS      Fandango Pink   fandangopink    #DE5285   Wikipedia      Fashion Fuchsia   fashionfuchsia    #F400A1   Wikipedia      Hollywood Cerise   hollywoodcerise    #F400A1   Wikipedia      Olive Yellow   oliveyellow    #A08F65   RAL      Polished Pine   polishedpine    #5DA493   Wikipedia      Pure Orange   pureorange    #E75B12   RAL      Shiny Shamrock   shinyshamrock    #5FA778   Wikipedia      Vivid Raspberry   vividraspberry    #FF006C   Wikipedia      Frostbite   frostbite    #E936A7   Wikipedia      Microsoft Red   microsoftred    #F04E1F   Wikipedia      Ochre   ochre    #CC7722   Wikipedia      Rich Lilac   richlilac    #B666D2   Wikipedia      Bright Pink   brightpink    #FF007F   Wikipedia      Coquelicot   coquelicot    #FF3800   Wikipedia      Medium Chrome Green   mediumchromegreen    #6CA67C   Crayola      Medium Sea Green   mediumseagreen    #3CB371   CSS      Mediumsea Green   mediumseagreen    #3CB371   CSS      Mustard Brown   mustardbrown    #CD7A00   Wikipedia      Persimmon   persimmon    #EC5800   Wikipedia      Philippine Pink   philippinepink    #FA1A8E   Wikipedia      RAL Orange   ralorange    #FA4402   RAL      Rose   rose    #FF007F   RAL      Stone Grey   stonegrey    #939388   RAL      Vivid Vermilion   vividvermilion    #e56024   Wikipedia      Winter Sky   wintersky    #FF007C   Wikipedia      Blue-gray   bluegray    #6699CC   Crayola      Cool Grey   coolgrey    #8C92AC   Wikipedia      Grey Beige   greybeige    #A48F7A   RAL      Livid   livid    #6699CC   Wikipedia      Pacific Blue   pacificblue    #1CA9C9   Crayola      Pastel Violet   pastelviolet    #A38995   RAL      Red Salsa   redsalsa    #FD3A4A   Wikipedia      Salmon Orange   salmonorange    #DB6A50   RAL      Spanish Orange   spanishorange    #E86100   Wikipedia      Blush   blush    #DE5D83   Crayola      Cerulean Frost   ceruleanfrost    #6D9BC3   Wikipedia      Fire Opal   fireopal    #E95C4B   Wikipedia      Keppel   keppel    #3AB09E   Wikipedia      Microsoft Blue   microsoftblue    #00A2ED   Wikipedia      Moonstone   moonstone    #3AA8C1   Wikipedia      Tangelo   tangelo    #F94D00   Wikipedia      Traffic Grey A   trafficgreya    #8F9695   RAL      Bronze   bronze    #CD7F32   Wikipedia      Carolina Blue   carolinablue    #56A0D3   Wikipedia      Dark Pastel Green   darkpastelgreen    #03C03C   Wikipedia      Deep Pink   deeppink    #FF1493   CSS      English Lavender   englishlavender    #B48395   Wikipedia      Kelly Green   kellygreen    #4CBB17   Wikipedia      Light Sea Green   lightseagreen    #20B2AA   CSS      Lightsea Green   lightseagreen    #20B2AA   CSS      Mint   mint    #3EB489   Wikipedia      Orange Red   orangered    #FF4500   CSS      Phlox   phlox    #DF00FF   Wikipedia      Psychedelic Purple   psychedelicpurple    #DF00FF   Wikipedia      Radical Red   radicalred    #FF355E   Wikipedia      Sizzling Red   sizzlingred    #FF3855   Wikipedia      Telegrey 1   telegreyone    #91969A   RAL      Cornflower Blue   cornflowerblue    #6495ED   CSS      Old Rose   oldrose    #C08081   Wikipedia      Orioles Orange   oriolesorange    #FB4F14   Wikipedia      Twitter Blue   twitterblue    #26A7DE   Wikipedia      Light Gold   lightgold    #B29700   Wikipedia      Neon Fuchsia   neonfuchsia    #FE4164   Wikipedia      Neon Pink   neonpink    #FE347E   Wikipedia      Platinum Grey   platinumgrey    #9A9697   RAL      Silver Grey   silvergrey    #8F999F   RAL      Super Pink   superpink    #CF6BA9   Wikipedia      Tart Orange   tartorange    #FB4D46   Wikipedia      Air Superiority Blue   airsuperiorityblue    #72A0C1   Wikipedia      Antique Pink   antiquepink    #D47479   RAL      Ochre Yellow   ochreyellow    #BA8F4C   RAL      Persian Rose   persianrose    #FE28A2   Wikipedia      Spanish Gray   spanishgray    #989898   Wikipedia      Strawberry   strawberry    #FA5053   Wikipedia      Sunset Orange   sunsetorange    #FE4C40   Crayola      French Rose   frenchrose    #F64A8A   Wikipedia      Light Carmine Pink   lightcarminepink    #E66771   Wikipedia      Maximum Blue   maximumblue    #47ABCC   Crayola      Mountain Meadow   mountainmeadow    #30BA8F   Crayola      Opera Mauve   operamauve    #B784A7   Wikipedia      Peru   peru    #CD853F   CSS      Shocking Pink   shockingpink    #FC0FC0   Wikipedia      Vivid Cerulean   vividcerulean    #00AAEE   Wikipedia      African Violet   africanviolet    #B284BE   Wikipedia      Mystic Red   mysticred    #FF5500   Wikipedia      Sky Magenta   skymagenta    #CF71AF   Wikipedia      Terra Cotta   terracotta    #E2725B   Wikipedia      Tourmaline   tourmaline    #86A1A9   Wikipedia      Verdigris   verdigris    #43B3AE   Wikipedia      Wild Orchid   wildorchid    #D470A2   Wikipedia      Willpower Orange   willpowerorange    #FD5800   Wikipedia      Fern   fern    #63B76C   Crayola      French Fuchsia   frenchfuchsia    #FD3F92   Wikipedia      Honey Yellow   honeyyellow    #CB8E00   RAL      Hot Fuchsia   hotfuchsia    #FF00C6   Wikipedia      Little Boy Blue   littleboyblue    #6CA0DC   Wikipedia      Manatee   manatee    #979AAA   Crayola      Orange Soda   orangesoda    #FA5B3D   Wikipedia      Pale Violet Red   palevioletred    #DB7093   CSS      Red-orange   redorange    #FF5349   RAL      Rose Bonbon   rosebonbon    #F9429E   Wikipedia      Tiffany Blue   tiffanyblue    #0ABAB5   Wikipedia      Antique Brass   antiquebrass    #C88A65   Crayola      Citron   citron    #9FA91F   Wikipedia      Green Sheen   greensheen    #6EAEA1   Wikipedia      Maximum Orange   maximumorange    #FF5B00   Wikipedia      Microsoft Green   microsoftgreen    #7DB700   Wikipedia      Morning Blue   morningblue    #8DA399   Wikipedia      Pearl Light Grey   pearllightgrey    #9C9C9C   RAL      Watermelon   watermelon    #F05C85   Wikipedia      Candy Pink   candypink    #E4717A   Wikipedia      Grullo   grullo    #A99A86   Wikipedia      Hot Magenta   hotmagenta    #FF1DCE   Wikipedia      Light Venetian Red   lightvenetianred    #E6735C   Crayola      Portland Orange   portlandorange    #FF5A36   Wikipedia      Tango Pink   tangopink    #E4717A   Wikipedia      Violet-red   violetred    #F75394   Crayola      Vista Blue   vistablue    #7C9ED9   Wikipedia      Vivid Orange   vividorange    #FF5F00   Wikipedia      Bud Green   budgreen    #7BB661   Wikipedia      Burnt Sienna   burntsienna    #E97451   Crayola      China Pink   chinapink    #DE6FA1   Wikipedia      Fiery Rose   fieryrose    #FF5470   Wikipedia      Glossy Grape   glossygrape    #AB92B3   Wikipedia      Iceberg   iceberg    #71A6D2   Wikipedia      Light Red Ochre   lightredochre    #E97451   Wikipedia      Liseran Purple   liseranpurple    #DE6FA1   Wikipedia      Medium Rose   mediumrose    #D96CBE   Crayola      Moonstone Blue   moonstoneblue    #73A9C2   Wikipedia      Rosy Brown   rosybrown    #BC8F8F   CSS      Thulian Pink   thulianpink    #DE6FA1   Wikipedia      Cadet Grey   cadetgrey    #91A3B0   Wikipedia      Vivid Tangelo   vividtangelo    #F07427   Wikipedia      Wild Strawberry   wildstrawberry    #FF43A4   Crayola      Beige Red   beigered    #CB8D73   RAL      Heliotrope Gray   heliotropegray    #AA98A9   Wikipedia      Lime Green   limegreen    #32CD32   CSS      New York Pink   newyorkpink    #D7837F   Wikipedia      Orange Iced Tea   orangeicedtea    #FF6700   Wikipedia      Razzle Dazzle Rose   razzledazzlerose    #FF33CC   Wikipedia      Signal Grey   signalgrey    #9EA0A1   RAL      Strong Lime Green   stronglimegreen    #33CC33   Wikipedia      Aztec Gold   aztecgold    #C39953   Wikipedia      Bright Red Orange   brightredorange    #F3752C   RAL      Deep Orange   deeporange    #EC7C25   RAL      Fulvous   fulvous    #E48400   Wikipedia      Lilac Luster   lilacluster    #AE98AA   Wikipedia      Pale Taupe   paletaupe    #BC987E   Wikipedia      Picton Blue   pictonblue    #45B1E8   Wikipedia      Puce   puce    #CC8899   Wikipedia      Raw Sienna   rawsienna    #D68A59   Crayola      Strawberry Iced Tea   strawberryicedtea    #FC5A8D   Wikipedia      Tomato   tomato    #FF6347   CSS      Brink Pink   brinkpink    #FB607F   Wikipedia      Camel   camel    #C19A6B   Wikipedia      Deep Mauve   deepmauve    #D473D4   Wikipedia      Desert   desert    #C19A6B   Wikipedia      Fallow   fallow    #C19A6B   Wikipedia      French Mauve   frenchmauve    #D473D4   Wikipedia      Maximum Blue Green   maximumbluegreen    #30BFBF   Crayola      Pewter Blue   pewterblue    #8BA8B7   Wikipedia      Vivid Amber   vividamber    #cc9900   Wikipedia      Window Grey   windowgrey    #9DA3A6   RAL      Wood Brown   woodbrown    #C19A6B   Wikipedia      Blue Jeans   bluejeans    #5DADEC   Wikipedia      Harvest Gold   harvestgold    #DA9100   Wikipedia      Pale Copper   palecopper    #DA8A67   Wikipedia      Pastel Turquoise   pastelturquoise    #7FB0B2   RAL      Brilliant Rose   brilliantrose    #E667CE   Crayola      Emerald   emerald    #50C878   Wikipedia      Fuchsia   fuchsia    #FF00FF   CSS      Light Crimson   lightcrimson    #F56991   Wikipedia      Magenta   magenta    #FF00FF   CSS      Mandarin   mandarin    #F37A48   Wikipedia      Orchid   orchid    #DA70D6   CSS      Paris Green   parisgreen    #50C878   Wikipedia      Pastel Red   pastelred    #FF6961   Wikipedia      Caribbean Green   caribbeangreen    #00CC99   Crayola      Outrageous Orange   outrageousorange    #FF6E4A   Wikipedia      Persian Orange   persianorange    #D99058   Wikipedia      Philippine Orange   philippineorange    #FF7300   Wikipedia      Shimmering Blush   shimmeringblush    #D98695   Wikipedia      Tiger's Eye   tigerseye    #E08D3C   Wikipedia      Bittersweet   bittersweet    #FE6F5E   Crayola      Daffodil Yellow   daffodilyellow    #E88C00   RAL      Lemon Curry   lemoncurry    #CCA01D   Wikipedia      Maize Yellow   maizeyellow    #E29000   RAL      Mantis   mantis    #74C365   Wikipedia      Princeton Orange   princetonorange    #F58025   Wikipedia      Pumpkin   pumpkin    #FF7518   Wikipedia      Quick Silver   quicksilver    #A6A6A6   Wikipedia      Tuscany   tuscany    #C09999   Wikipedia      Cadmium Orange   cadmiumorange    #ED872D   Wikipedia      Medium Orange   mediumorange    #FF7802   Wikipedia      Middle Purple   middlepurple    #D982B5   Crayola      Pastel Purple   pastelpurple    #B39EB5   Wikipedia      Safety Orange   safetyorange    #FF7800   Wikipedia      Satin Sheen Gold   satinsheengold    #CBA135   Wikipedia      Shamrock   shamrock    #33CC99   Crayola      Tangerine   tangerine    #F28500   Wikipedia      Ultra Red   ultrared    #FC6C85   Wikipedia      White Aluminium   whitealuminium    #A5A8A6   RAL      Wild Watermelon   wildwatermelon    #FC6C85   Wikipedia      Blue Bell   bluebell    #A2A2D0   Crayola      Cyclamen   cyclamen    #F56FA1   Wikipedia      Heat Wave   heatwave    #FF7A00   Wikipedia      Pale Dogwood   paledogwood    #ED7A9B   Wikipedia      Purple Pizzazz   purplepizzazz    #FE4EDA   Wikipedia      Rose Pompadour   rosepompadour    #ED7A9B   Wikipedia      Dark Gray   darkgray    #A9A9A9   CSS      Dark Grey   darkgrey    #A9A9A9   CSS      Light Cobalt Blue   lightcobaltblue    #88ACE0   Wikipedia      Light Coral   lightcoral    #F08080   CSS      Lightcoral   lightcoral    #F08080   CSS      Malachite   malachite    #0BDA51   Wikipedia      Metallic Silver   metallicsilver    #A8A9AD   Wikipedia      Olivine   olivine    #9AB973   Wikipedia      Big Foot Feet   bigfootfeet    #E88E5A   Wikipedia      Deep Sky Blue   deepskyblue    #00BFFF   CSS      French Pink   frenchpink    #FD6C9E   Wikipedia      Light Pastel Purple   lightpastelpurple    #B19CD9   Wikipedia      Middle Red   middlered    #E58E73   Crayola      Mocha   mocha    #BEA493   Wikipedia      Carrot Orange   carrotorange    #ED9121   Wikipedia      Dark Sea Green   darkseagreen    #8FBC8F   CSS      Medium Pink   mediumpink    #FE6E9F   Wikipedia      Neon Tangerine   neontangerine    #F6890A   Wikipedia      Pastel Orange   pastelorange    #FA842B   RAL      Robin Egg Blue   robineggblue    #00CCCC   Wikipedia      Robin's Egg Blue   robinseggblue    #00CCCC   Crayola      Coral   coral    #FF7F50   CSS      Gamboge   gamboge    #E49B0F   Wikipedia      Hot Pink   hotpink    #FF69B4   CSS      Hotpink   hotpink    #FF69B4   CSS      Limerick   limerick    #9DC209   Wikipedia      Olive Green   olivegreen    #B5B35C   RAL      Silver Chalice   silverchalice    #ACACAC   Wikipedia      Sun Yellow   sunyellow    #F09200   RAL      Dark Turquoise   darkturquoise    #00CED1   CSS      Heliotrope   heliotrope    #DF73FF   Wikipedia      Mango Tango   mangotango    #FF8243   Crayola      Neon Gold   neongold    #CFAA01   Wikipedia      Salmon   salmon    #FA8072   CSS      Congo Pink   congopink    #F88379   Wikipedia      Coral Pink   coralpink    #F88379   Wikipedia      Goldenrod   goldenrod    #DAA520   CSS      Rose Pink   rosepink    #FF66CC   Wikipedia      Wild Blue Yonder   wildblueyonder    #A2ADD0   Wikipedia      Acid Green   acidgreen    #B0BF1A   Wikipedia      Pistachio   pistachio    #93C572   Wikipedia      Aero   aero    #7CB9E8   Wikipedia      Broom Yellow   broomyellow    #E2A300   RAL      Dark Orange   darkorange    #FF8C00   CSS      Dark Salmon   darksalmon    #E9967A   CSS      French Sky Blue   frenchskyblue    #77B5FE   Wikipedia      Light Grayish Magenta   lightgrayishmagenta    #CC99CC   Wikipedia      Medium Aquamarine   mediumaquamarine    #66CDAA   CSS      Misty Moss   mistymoss    #BBB477   Wikipedia      Silver Foil   silverfoil    #AFB1AE   Wikipedia      Charm Pink   charmpink    #E68FAC   Wikipedia      Light French Beige   lightfrenchbeige    #C8AD7F   Wikipedia      Light Thulian Pink   lightthulianpink    #E68FAC   Wikipedia      Middle Green Yellow   middlegreenyellow    #ACBF60   Crayola      Salmon Rose   salmonrose    #E7968B   Wikipedia      Sand Yellow   sandyellow    #D2AA6D   RAL      Vegas Gold   vegasgold    #C5B358   Wikipedia      Android Green   androidgreen    #3DDC84   Wikipedia      Dark Khaki   darkkhaki    #BDB76B   CSS      Ecru   ecru    #C2B280   Wikipedia      Eucalyptus   eucalyptus    #44D7A8   Wikipedia      Laurel Green   laurelgreen    #A9BA9D   Wikipedia      Metallic Gold   metallicgold    #D3AF37   Wikipedia      Pastel Yellow   pastelyellow    #EB9C52   RAL      Persian Pink   persianpink    #F77FBE   Wikipedia      Pure Green   puregreen    #25E712   RAL      Royal Orange   royalorange    #F99245   Wikipedia      Sand   sand    #C2B280   Wikipedia      Very Light Azure   verylightazure    #74BBFB   Wikipedia      Vivid Sky Blue   vividskyblue    #00CCFF   Wikipedia      Light Medium Orchid   lightmediumorchid    #D39BCB   Wikipedia      Lilac   lilac    #C8A2C8   Wikipedia      Marigold   marigold    #EAA221   Wikipedia      Medium Turquoise   mediumturquoise    #48D1CC   CSS      Mediumturquoise   mediumturquoise    #48D1CC   CSS      Philippine Silver   philippinesilver    #B3B3B3   Wikipedia      Yellow Green   yellowgreen    #9ACD32   CSS      Yellow-green   yellowgreen    #9ACD32   CSS      Black Shadows   blackshadows    #BFAFB2   Wikipedia      Dahlia Yellow   dahliayellow    #F99A1C   RAL      Dark Sky Blue   darkskyblue    #8CBED6   Wikipedia      Maximum Blue Purple   maximumbluepurple    #ACACE6   Crayola      Old Gold   oldgold    #CFB53B   Wikipedia      Sheen Green   sheengreen    #8FD400   Wikipedia      Tulip   tulip    #FF878D   Wikipedia      Bright Lilac   brightlilac    #D891EF   Wikipedia      Earth Yellow   earthyellow    #E1A95F   Wikipedia      Indian Yellow   indianyellow    #E3A857   Wikipedia      Mustard Yellow   mustardyellow    #E1AD01   Wikipedia      Sage   sage    #BCB88A   Wikipedia      Silver Pink   silverpink    #C4AEAD   Wikipedia      Urobilin   urobilin    #E1AD21   Wikipedia      Vanilla Ice   vanillaice    #F38FA9   Wikipedia      Wisteria   wisteria    #C9A0DC   Crayola      Agate Grey   agategrey    #B4B8B0   RAL      Cambridge Blue   cambridgeblue    #A3C1AD   Wikipedia      Eton Blue   etonblue    #96C8A2   Wikipedia      Maya Blue   mayablue    #73C2FB   Wikipedia      Strawberry Blonde   strawberryblonde    #FF9361   Wikipedia      Vivid Gamboge   vividgamboge    #FF9900   Wikipedia      Deep Saffron   deepsaffron    #FF9933   Wikipedia      Lavender Magenta   lavendermagenta    #EE82EE   Wikipedia      Melon Yellow   melonyellow    #FF9B00   RAL      Pale Violet   paleviolet    #CC99FF   Wikipedia      Pebble Grey   pebblegrey    #B9B9A8   RAL      Pink Sherbet   pinksherbet    #F78FA7   Wikipedia      Sunray   sunray    #E3AB57   Wikipedia      Tickle Me Pink   ticklemepink    #FC89AC   Crayola      Violet   violet    #EE82EE   CSS      Mauvelous   mauvelous    #EF98AA   Crayola      Pastel Pink   pastelpink    #DEA5A4   Wikipedia      Tumbleweed   tumbleweed    #DEAA88   Crayola      Ash Gray   ashgray    #B2BEB5   Wikipedia      Atomic Tangerine   atomictangerine    #FF9966   Wikipedia      Fawn   fawn    #E5AA70   Wikipedia      Orange Peel   orangepeel    #FF9F00   Wikipedia      Pink Flamingo   pinkflamingo    #FC74FD   Crayola      Ultra Pink   ultrapink    #FF6FFF   Wikipedia      Mona Lisa   monalisa    #FF948E   Wikipedia      Pale Magenta   palemagenta    #F984E5   Wikipedia      Sandy Brown   sandybrown    #F4A460   CSS      Tan   tan    #D2B48C   CSS      Vivid Orange Peel   vividorangepeel    #FFA000   Wikipedia      Green Beige   greenbeige    #CDBA88   RAL      Opal   opal    #A8C3BC   Wikipedia      Salmon Pink   salmonpink    #FF91A4   RAL      Signal Yellow   signalyellow    #F9A800   RAL      Vivid Lime Green   vividlimegreen    #a6d608   Wikipedia      Baker-Miller Pink   bakermillerpink    #FF91AF   Wikipedia      Kobi   kobi    #E79FC4   Wikipedia      Light Fuchsia Pink   lightfuchsiapink    #F984EF   Wikipedia      Luminous Bright Orange   luminousbrightorange    #FFA421   RAL      Medium Lavender Magenta   mediumlavendermagenta    #DDA0DD   Wikipedia      Orange   orange    #FFA500   CSS      Pale Plum   paleplum    #DDA0DD   Wikipedia      Plum   plum    #DDA0DD   CSS      Schauss Pink   schausspink    #FF91AF   Wikipedia      Silk Grey   silkgrey    #BDBDB2   RAL      Amaranth Pink   amaranthpink    #F19CBB   Wikipedia      Light Salmon Pink   lightsalmonpink    #FF9999   Wikipedia      Luminous Green   luminousgreen    #00F700   RAL      Pale Cerulean   palecerulean    #9BC4E2   Wikipedia      Pale Chestnut   palechestnut    #DDADAF   Wikipedia      Saffron Yellow   saffronyellow    #F6A950   RAL      Turquoise   turquoise    #40E0D0   CSS      Light Salmon   lightsalmon    #FFA07A   CSS      Lightsalmon   lightsalmon    #FFA07A   CSS      Pastel Magenta   pastelmagenta    #F49AC2   Wikipedia      Pink Sherbert   pinksherbert    #F7A38E   Crayola      Bright Yellow   brightyellow    #FFAA1D   Wikipedia      Middle Yellow Red   middleyellowred    #ECB176   Crayola      Sky Blue   skyblue    #87CEEB   CSS      Vivid Tangerine   vividtangerine    #FFA089   Crayola      Xanthous   xanthous    #F1B42F   Wikipedia      Burlywood   burlywood    #DEB887   CSS      Lanzones   lanzones    #E0BC5B   Wikipedia      Purple Mountains' Majesty   purplemountainsmajesty    #D6AEDD   Crayola      Rajah   rajah    #FBAB60   Wikipedia      Silver   silver    #C0C0C0   CSS      Very Light Malachite Green   verylightmalachitegreen    #64E986   Wikipedia      Baby Blue   babyblue    #89CFF0   Wikipedia      Bright Turquoise   brightturquoise    #08E8DE   Wikipedia      Cornflower   cornflower    #93CCEA   Crayola      Light Cornflower Blue   lightcornflowerblue    #93CCEA   Wikipedia      Light Steel Blue   lightsteelblue    #B0C4DE   CSS      Lightsteel Blue   lightsteelblue    #B0C4DE   CSS      Metallic Pink   metallicpink    #EDA6C4   Wikipedia      Middle Blue   middleblue    #7ED4E6   Crayola      Pearl Aqua   pearlaqua    #88D8C0   Wikipedia      Silver Sand   silversand    #BFC1C2   Wikipedia      Spanish Yellow   spanishyellow    #F6B511   Wikipedia      Colza Yellow   colzayellow    #F6B600   RAL      Dark Vanilla   darkvanilla    #D1BEA8   Wikipedia      Light Orchid   lightorchid    #E6A8D7   Wikipedia      Light Sky Blue   lightskyblue    #87CEFA   CSS      Lightsky Blue   lightskyblue    #87CEFA   CSS      Pale Silver   palesilver    #C9C0BB   Wikipedia      Pink Lavender   pinklavender    #D8B2D1   Wikipedia      Traffic Yellow   trafficyellow    #F7B500   RAL      Yellow Orange   yelloworange    #FFAE42   RAL      Chinese Yellow   chineseyellow    #FFB200   Wikipedia      Lime   lime    #00FF00   CSS      Pink Pearl   pinkpearl    #E7ACCF   Wikipedia      Baby Blue Eyes   babyblueeyes    #A1CAF1   Wikipedia      Maximum Yellow Red   maximumyellowred    #F2BA49   Crayola      Middle Blue Green   middlebluegreen    #8DD9CC   Crayola      Pale Cyan   palecyan    #87D3F8   Wikipedia      Turquoise Green   turquoisegreen    #A0D6B4   RAL      Erin   erin    #00FF40   Wikipedia      Lavender Gray   lavendergray    #C4C3D0   Wikipedia      Harlequin   harlequin    #3FFF00   Wikipedia      Medium Sky Blue   mediumskyblue    #80DAEB   Wikipedia      Medium Spring Green   mediumspringgreen    #00FA9A   CSS      Mediumspring Green   mediumspringgreen    #00FA9A   CSS      Microsoft Yellow   microsoftyellow    #FDB900   Wikipedia      Neon Green   neongreen    #39FF14   Wikipedia      Orange-yellow   orangeyellow    #F5BD1F   Crayola      Pale Gold   palegold    #E6BE8A   Wikipedia      Very Light Tangelo   verylighttangelo    #FFB077   Wikipedia      June Bud   junebud    #BDDA57   Wikipedia      Lavender Rose   lavenderrose    #FBA0E3   Wikipedia      Selective Yellow   selectiveyellow    #FFBA00   Wikipedia      Mellow Apricot   mellowapricot    #F8B878   Wikipedia      Nadeshiko Pink   nadeshikopink    #F6ADC6   Wikipedia      Pale Cornflower Blue   palecornflowerblue    #ABCDEF   Wikipedia      Spring Green   springgreen    #00FF7F   CSS      Carnation Pink   carnationpink    #FFA6C9   Crayola      Mango   mango    #FDBE02   Wikipedia      Mauve   mauve    #E0B0FF   Wikipedia      Amber   amber    #FFBF00   Wikipedia      Citrine   citrine    #E4D00A   Wikipedia      Maximum Pink   maximumpink    #F6A5F2   Wikipedia      Pale Robin Egg Blue   palerobineggblue    #96DED1   Wikipedia      Prairie Gold   prairiegold    #E1CA7A   Wikipedia      Saffron   saffron    #F4C430   Wikipedia      Thistle   thistle    #D8BFD8   CSS      Bright Green   brightgreen    #66FF00   Wikipedia      Deep Lemon   deeplemon    #F5C71A   Wikipedia      Golden Poppy   goldenpoppy    #FCC200   Wikipedia      Pastel Green   pastelgreen    #B7D9B1   RAL      Rich Brilliant Lavender   richbrilliantlavender    #F1A7FE   Wikipedia      Bitter Lemon   bitterlemon    #CAE00D   Wikipedia      Fluorescent Blue   fluorescentblue    #15F4EE   Wikipedia      Jonquil   jonquil    #F4CA16   Wikipedia      Light Green   lightgreen    #90EE90   CSS      Light Moss Green   lightmossgreen    #ADDFAD   Wikipedia      Light Periwinkle   lightperiwinkle    #C5CBE1   Wikipedia      Lotion Blue   lotionblue    #15F2FD   Wikipedia      Neon Silver   neonsilver    #CCCCCC   Wikipedia      Teal Deer   tealdeer    #99E6B3   Wikipedia      Celadon   celadon    #ACE1AF   Wikipedia      Granny Smith Apple   grannysmithapple    #A8E4A0   Crayola      Lawn Green   lawngreen    #7CFC00   CSS      Lion   lion    #DECC9C   Wikipedia      Mikado Yellow   mikadoyellow    #FFC40C   Wikipedia      Ripe Mango   ripemango    #FFC324   Wikipedia      Cameo Pink   cameopink    #EFBBCC   Wikipedia      Light Blue   lightblue    #ADD8E6   CSS      Light Chrome Green   lightchromegreen    #BEE64B   Crayola      Macaroni And Cheese   macaroniandcheese    #FFBD88   Crayola      Medium Spring Bud   mediumspringbud    #C9DC87   Wikipedia      Pastel Gray   pastelgray    #CFCFC4   Wikipedia      Screamin' Green   screamingreen    #66FF66   Wikipedia      Technobotanica   technobotanica    #00FFBF   Wikipedia      Beau Blue   beaublue    #BCD4E6   Wikipedia      Chartreuse   chartreuse    #7FFF00   CSS      Melon   melon    #FEBAAD   Crayola      Pale Aqua   paleaqua    #BED3E5   Wikipedia      Safety Yellow   safetyyellow    #EED202   Wikipedia      Soap   soap    #CEC8EF   Wikipedia      Zinc Yellow   zincyellow    #FACA30   RAL      Inchworm   inchworm    #B2EC5D   Wikipedia      Languid Lavender   languidlavender    #D6CADD   Wikipedia      Light Pink   lightpink    #FFB6C1   CSS      Lightpink   lightpink    #FFB6C1   CSS      Non-photo Blue   nonphotoblue    #A4DDED   Wikipedia      Orchid Pink   orchidpink    #F2BDCD   Wikipedia      Pear   pear    #D1E231   Wikipedia      Telegrey 4   telegreyfour    #CFD0CF   RAL      Cherry Blossom Pink   cherryblossompink    #FFB7C5   Wikipedia      Green Lizard   greenlizard    #A7F432   Wikipedia      Little Girl Pink   littlegirlpink    #F8B9D4   Wikipedia      Metallic Yellow   metallicyellow    #FDCC0D   Wikipedia      Papyrus White   papyruswhite    #CFD3CD   RAL      Philippine Yellow   philippineyellow    #FECB00   Wikipedia      Spanish Pink   spanishpink    #F7BFBE   Wikipedia      Spring Frost   springfrost    #87FF2A   Wikipedia      Tangerine Yellow   tangerineyellow    #FFCC00   Wikipedia      Baby Pink   babypink    #F4C2C2   Wikipedia      Columbia Blue   columbiablue    #B9D9EB   Wikipedia      Desert Sand   desertsand    #EDC9AF   Crayola      Lavender Blue   lavenderblue    #CCCCFF   Wikipedia      Periwinkle   periwinkle    #CCCCFF   Crayola      Sunglow   sunglow    #FFCC33   Wikipedia      Tea Rose   tearose    #F4C2C2   Wikipedia      Uranian Blue   uranianblue    #AFDBF5   Wikipedia      Arylide Yellow   arylideyellow    #E9D66B   Wikipedia      Buff   buff    #FFC680   Wikipedia      Hansa Yellow   hansayellow    #E9D66B   Wikipedia      Light Gray   lightgray    #D3D3D3   CSS      Light Grey   lightgrey    #D3D3D3   CSS      Lightgrey   lightgrey    #D3D3D3   CSS      Straw   straw    #E4D96F   Wikipedia      Topaz   topaz    #FFC87C   Wikipedia      Turquoise Blue   turquoiseblue    #00FFEF   RAL      Crayellow   crayellow    #F1D651   Crayola      Mango Green   mangogreen    #96FF00   Wikipedia      Neon Cyan   neoncyan    #00FEFC   Wikipedia      Powder Blue   powderblue    #B0E0E6   CSS      Cotton Candy   cottoncandy    #FFBCD9   Crayola      Cyber Yellow   cyberyellow    #FFD300   Wikipedia      French Lime   frenchlime    #9EFD38   Wikipedia      Light Ivory   lightivory    #E6D2B5   RAL      Spanish Sky Blue   spanishskyblue    #00FFFE   Wikipedia      Aqua   aqua    #00FFFF   CSS      Booger Buster   boogerbuster    #DDE26A   Wikipedia      Cyan   cyan    #00FFFF   CSS      Maximum Green Yellow   maximumgreenyellow    #D9E650   Crayola      Peridot   peridot    #E6E200   Wikipedia      Pink   pink    #FFC0CB   CSS      Queen Pink   queenpink    #E8CCD7   Wikipedia      Spring Bud   springbud    #A7FC00   Wikipedia      Blizzard Blue   blizzardblue    #ACE5EE   Wikipedia      Sulfur Yellow   sulfuryellow    #F1DD38   RAL      Gold   gold    #FFD700   CSS      Light Silver   lightsilver    #D8D8D8   Wikipedia      Lotion Pink   lotionpink    #ECCFCF   Wikipedia      Pale Green   palegreen    #98FB98   CSS      School Bus Yellow   schoolbusyellow    #FFD800   Wikipedia      Timberwolf   timberwolf    #DBD7D2   Crayola      Flax   flax    #EEDC82   Wikipedia      Oatmeal   oatmeal    #D9DAD2   Crayola      Pale Lavender   palelavender    #DCD0FF   Wikipedia      Apricot   apricot    #FBCEB1   Crayola      Dandelion   dandelion    #FED85D   Crayola      Green Yellow   greenyellow    #ADFF2F   CSS      Greenyellow   greenyellow    #ADFF2F   CSS      Magic Mint   magicmint    #AAF0D1   Wikipedia      Mint Green   mintgreen    #98FF98   RAL      Naples Yellow   naplesyellow    #FADA5E   Wikipedia      Neon Carrot   neoncarrot    #AAF0D1   Wikipedia      Oyster White   oysterwhite    #E3D9C6   RAL      Royal Yellow   royalyellow    #FADA5E   Wikipedia      Sizzling Sunrise   sizzlingsunrise    #FFDB00   Wikipedia      Stil De Grain Yellow   stildegrainyellow    #FADA5E   Wikipedia      Aquamarine   aquamarine    #7FFFD4   CSS      Bone   bone    #E3DAC9   Wikipedia      Minion Yellow   minionyellow    #F5E050   Wikipedia      Titanium Yellow   titaniumyellow    #EEE600   Wikipedia      Electric Blue   electricblue    #7DF9FF   Wikipedia      Gainsboro   gainsboro    #DCDCDC   CSS      Light Red   lightred    #FFCCCB   Wikipedia      Mustard   mustard    #FFDB58   Wikipedia      Almond   almond    #EED9C4   Crayola      Deep Champagne   deepchampagne    #FAD6A5   Wikipedia      Golden Yellow   goldenyellow    #FFDF00   RAL      Grey White   greywhite    #DDDED4   RAL      Pale Blue   paleblue    #AFEEEE   Wikipedia      Pale Turquoise   paleturquoise    #AFEEEE   CSS      Paleturquoise   paleturquoise    #AFEEEE   CSS      Philippine Golden Yellow   philippinegoldenyellow    #FFDF00   Wikipedia      Sunset   sunset    #FAD6A5   Wikipedia      Tuscan   tuscan    #FAD6A5   Wikipedia      Jasmine   jasmine    #F8DE7E   Wikipedia      Mellow Yellow   mellowyellow    #F8DE7E   Wikipedia      Medium Yellow   mediumyellow    #FFE302   Wikipedia      Vivid Yellow   vividyellow    #FFE302   Wikipedia      Xanthic   xanthic    #EEED09   Wikipedia      Dutch White   dutchwhite    #EFDFBB   Wikipedia      Light Orange   lightorange    #FED8B1   Wikipedia      Pearl   pearl    #EAE0C8   Wikipedia      Waterspout   waterspout    #A4F4F9   Wikipedia      White Coffee   whitecoffee    #E6E0D4   Wikipedia      Electric Lime   electriclime    #CCFF00   Wikipedia      Khaki   khaki    #F0E68C   CSS      Menthol   menthol    #C1F9A2   Wikipedia      Wheat   wheat    #F5DEB3   CSS      Arctic Lime   arcticlime    #D0FF14   Wikipedia      Champagne Pink   champagnepink    #F1DDCF   Wikipedia      Peach Puff   peachpuff    #FFDAB9   CSS      Peachpuff   peachpuff    #FFDAB9   CSS      Shampoo   shampoo    #FFCFF1   Wikipedia      Tea Green   teagreen    #D0F0C0   Wikipedia      Volt   volt    #CEFF00   Wikipedia      Medium Champagne   mediumchampagne    #F3E5AB   Wikipedia      Middle Yellow   middleyellow    #FFEB00   Crayola      Navajo White   navajowhite    #FFDEAD   CSS      Pale Goldenrod   palegoldenrod    #EEE8AA   CSS      Pale Pink   palepink    #FADADD   Wikipedia      Palegoldenrod   palegoldenrod    #EEE8AA   CSS      Platinum   platinum    #E5E4E2   Wikipedia      Shandy   shandy    #FFE670   Wikipedia      Vanilla   vanilla    #F3E5AB   Wikipedia      Aureolin   aureolin    #FDEE00   Wikipedia      Corn   corn    #FBEC5D   Wikipedia      Maize   maize    #FBEC5D   Crayola      Canary Yellow   canaryyellow    #FFEF00   Wikipedia      Unbleached Silk   unbleachedsilk    #FFDDCA   Wikipedia      Very Pale Orange   verypaleorange    #FFDFBF   Wikipedia      White Chocolate   whitechocolate    #EDE6D6   Wikipedia      Cool Mint   coolmint    #DDEBEC   Crayola      Key Lime   keylime    #E8F48C   Wikipedia      Lemon Lime   lemonlime    #E3FF00   Wikipedia      Mimi Pink   mimipink    #FFDAE9   Wikipedia      Pale Spring Bud   palespringbud    #ECEBBD   Wikipedia      Yellow Rose   yellowrose    #FFF000   Wikipedia      Banana Mania   bananamania    #FAE7B5   Crayola      Lavender   lavender    #E6E6FA   CSS      Lavender Mist   lavendermist    #E6E6FA   Wikipedia      Mindaro   mindaro    #E3F988   Wikipedia      Moccasin   moccasin    #FFE4B5   CSS      Peach   peach    #FFE5B4   Crayola      Petal   petal    #F5E2E2   Wikipedia      Piggy Pink   piggypink    #FDDDE6   Crayola      Bisque   bisque    #FFE4C4   CSS      Champagne   champagne    #F7E7CE   Wikipedia      Lemon Meringue   lemonmeringue    #F6EABE   Wikipedia      Magnolia   magnolia    #F2E8D7   Wikipedia      Parchment   parchment    #F1E9D2   Wikipedia      Cadmium Yellow   cadmiumyellow    #FFF600   Wikipedia      Eggshell   eggshell    #F0EAD6   Wikipedia      Lumber   lumber    #FFE4CD   Wikipedia      Pink Lace   pinklace    #FFDDF4   Wikipedia      Water   water    #D4F1F9   Wikipedia      Celeste   celeste    #B2FFFF   Wikipedia      Italian Sky Blue   italianskyblue    #B2FFFF   Wikipedia      Lemon   lemon    #FFF700   Wikipedia      Lemon Yellow   lemonyellow    #FFF44F   RAL      Neon Yellow   neonyellow    #FFF700   Wikipedia      Watermelon Yellow   watermelonyellow    #EEFF1B   Wikipedia      Yellow Sunshine   yellowsunshine    #FFF700   Wikipedia      Icterine   icterine    #FCF75E   Wikipedia      Maximum Yellow   maximumyellow    #FAFA37   Crayola      Misty Rose   mistyrose    #FFE4E1   CSS      Mistyrose   mistyrose    #FFE4E1   CSS      Antique White   antiquewhite    #FAEBD7   CSS      Blanched Almond   blanchedalmond    #FFEBCD   CSS      Pale Purple   palepurple    #FAE6FA   Wikipedia      Alabaster   alabaster    #F2F0E6   Wikipedia      Lemon Glacier   lemonglacier    #FDFF00   Wikipedia      Luminous Yellow   luminousyellow    #FFFF00   RAL      Yellow   yellow    #FFFF00   CSS      Isabelline   isabelline    #F4F0EC   Wikipedia      Papaya Whip   papayawhip    #FFEFD5   CSS      Beige   beige    #F5F5DC   CSS      Laser Lemon   laserlemon    #FFFF66   Wikipedia      Linen   linen    #FAF0E6   CSS      Unmellow Yellow   unmellowyellow    #FFFF66   Wikipedia      Cultured   cultured    #F5F5F5   Wikipedia      Cultured Pearl   culturedpearl    #F5F5F5   Wikipedia      Lavender Blush   lavenderblush    #FFF0F5   CSS      Nyanza   nyanza    #E9FFDB   Wikipedia      White Smoke   whitesmoke    #F5F5F5   CSS      Zebra White   zebrawhite    #F5F5F5   Wikipedia      Alice Blue   aliceblue    #F0F8FF   CSS      Canary   canary    #FFFF99   Crayola      Light Cyan   lightcyan    #E0FFFF   CSS      Light Goldenrod Yellow   lightgoldenrodyellow    #FAFAD2   CSS      Lightcyan   lightcyan    #E0FFFF   CSS      Old Lace   oldlace    #FDF5E6   CSS      Oldlace   oldlace    #FDF5E6   CSS      Signal White   signalwhite    #F4F8F4   RAL      Cornsilk   cornsilk    #FFF8DC   CSS      Lemon Chiffon   lemonchiffon    #FFFACD   CSS      Pure White   purewhite    #F7F9EF   RAL      Seashell   seashell    #FFF5EE   CSS      Cosmic Latte   cosmiclatte    #FFF8E7   Wikipedia      Cream   cream    #FFFDD0   RAL      Ghost White   ghostwhite    #F8F8FF   CSS      Honeydew   honeydew    #F0FFF0   CSS      Traffic White   trafficwhite    #F7FBF5   RAL      Very Pale Yellow   verypaleyellow    #FFFFBF   Wikipedia      Floral White   floralwhite    #FFFAF0   CSS      Azure   azure    #F0FFFF   CSS      Clean Room White   cleanroomwhite    #FFFDE6   RAL      Mint Cream   mintcream    #F5FFFA   CSS      Light Yellow   lightyellow    #FFFFE0   CSS      Snow   snow    #FFFAFA   CSS      Tooth   tooth    #FFFAFA   Wikipedia      Ivory   ivory    #FFFFF0   CSS      Lotion   lotion    #FEFDFA   Wikipedia      Milk   milk    #FDFFF5   Wikipedia      Baby Powder   babypowder    #FEFEFA   Wikipedia      White   white    #FFFFFF   CSS    \n     \n   \n \n\n\n<!-- tabs-close -->","ref":"namedcolors.html#dark-light"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}